@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name></name>
     <message>
@@ -17,11 +19,11 @@
     <name>QObject</name>
     <message>
         <source>Couldn&apos;t initialize QSql driver!</source>
-        <translation>Greidde ikkje setja opp QSql-drivaren!</translation>
+        <translation type="obsolete">Greidde ikkje setja opp QSql-drivaren!</translation>
     </message>
     <message>
         <source>Couldn&apos;t open mySQL connection!</source>
-        <translation>Greidde ikkje kopla til mySQL-databasen!</translation>
+        <translation type="obsolete">Greidde ikkje kopla til mySQL-databasen!</translation>
     </message>
     <message>
         <source>Sequentially</source>
@@ -527,6 +529,242 @@
         <source>No such service!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No such group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No free cart available in group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open database</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Database version mismatch, should be</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Max. in a Row/Min. Wait for </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Do not schedule </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>after</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Do not schedule</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is overscheduled by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is underscheduled by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is not playable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Couldn&apos;t initialize MySql driver!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Couldn&apos;t open MySQL connection on</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DB connection re-established</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Could not re-establish DB connection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid arguments specified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Specified configuration was not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>One or more Rivendell modules are active</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No running as root</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>systemctl(8) crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service shutdown failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio store unmount failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio store mount failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service startup failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Current configuration was not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Synlink creation failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid configuration name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>mount(8) crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>does not have a Hosts entry in the database.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open RDAdmin-&gt;ManageHosts-&gt;Add to create one.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to update automounter configuration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PCM8</source>
+        <translation type="unfinished">PCM8</translation>
+    </message>
+    <message>
+        <source>PCM16</source>
+        <translation type="unfinished">PCM16</translation>
+    </message>
+    <message>
+        <source>Float32</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer I</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer II (MP2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer III (MP3)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Dolby AC2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Dolby AC3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OggVorbis</source>
+        <translation type="unfinished">Ogg Vorbis</translation>
+    </message>
+    <message>
+        <source>PCM24</source>
+        <translation type="unfinished">PCM24</translation>
+    </message>
+    <message>
+        <source>RIFF/WAVE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Raw MPEG Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ogg Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ATX</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TMC</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Raw FLAC Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>AM-BOS Hybrid</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>AIFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MP4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Title separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> with sched code(s): </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Artist separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No carts found in group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>-- End of List --</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CounterPoint Traffic Reconciliation v2</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -610,6 +848,10 @@
         <source>The cart title must be unique!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Add Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddLog</name>
@@ -646,51 +888,70 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>RDApplication</name>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>systemctl(1) crashed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>systemctl(1) returned exit code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service is not active.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDAudioSettingsDialog</name>
     <message>
         <source>Edit Settings</source>
-        <translation>Rediger innstillingar</translation>
+        <translation type="obsolete">Rediger innstillingar</translation>
     </message>
     <message>
         <source>Default &amp;Format:</source>
-        <translation>Standard&amp;format:</translation>
+        <translation type="obsolete">Standard&amp;format:</translation>
     </message>
     <message>
         <source>Default &amp;Channels:</source>
-        <translation>Standard tal på &amp;kanalar:</translation>
+        <translation type="obsolete">Standard tal på &amp;kanalar:</translation>
     </message>
     <message>
         <source>Default &amp;Sample Rate:</source>
-        <translation>Standard &amp;punktprøverate:</translation>
+        <translation type="obsolete">Standard &amp;punktprøverate:</translation>
     </message>
     <message>
         <source>Default &amp;Bitrate:</source>
-        <translation>Standard &amp;bitrate:</translation>
+        <translation type="obsolete">Standard &amp;bitrate:</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Avbryt</translation>
+        <translation type="obsolete">&amp;Avbryt</translation>
     </message>
     <message>
         <source>PCM16</source>
-        <translation>PCM16</translation>
+        <translation type="obsolete">PCM16</translation>
     </message>
     <message>
         <source>OggVorbis</source>
-        <translation>Ogg Vorbis</translation>
+        <translation type="obsolete">Ogg Vorbis</translation>
     </message>
     <message>
         <source>MPEG Layer 2</source>
-        <translation>MPEG lag 2</translation>
+        <translation type="obsolete">MPEG lag 2</translation>
     </message>
     <message>
         <source>MPEG Layer 3</source>
-        <translation>MPEG lag 3</translation>
+        <translation type="obsolete">MPEG lag 3</translation>
     </message>
 </context>
 <context>
@@ -814,43 +1075,43 @@ farge</translation>
     </message>
     <message>
         <source>NUMBER</source>
-        <translation>NUMMER</translation>
+        <translation type="obsolete">NUMMER</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>LENGD</translation>
+        <translation type="obsolete">LENGD</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITTEL</translation>
+        <translation type="obsolete">TITTEL</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTIST</translation>
+        <translation type="obsolete">ARTIST</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>KLIENT</translation>
+        <translation type="obsolete">KLIENT</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENT</translation>
+        <translation type="obsolete">AGENT</translation>
     </message>
     <message>
         <source>USER DEF</source>
-        <translation>BRUKARDEFINERT</translation>
+        <translation type="obsolete">BRUKARDEFINERT</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>START</translation>
+        <translation type="obsolete">START</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>SLUTT</translation>
+        <translation type="obsolete">SLUTT</translation>
     </message>
     <message>
         <source>Send to
@@ -894,10 +1155,6 @@ farge</translation>
         <source>Unable to create temporary cart for import!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Unable to get temporary cart number for import!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Import Error</source>
         <translation type="unfinished"></translation>
@@ -915,28 +1172,75 @@ farge</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>COMPOSER</source>
+        <source>Number</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>CONDUCTOR</source>
+        <source>Length</source>
+        <translation type="unfinished">Lengd</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Composer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Conductor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User Def</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Slutten</translation>
+    </message>
+    <message>
+        <source>Open Audio File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>RDCddbLookup</name>
+    <message>
+        <source>CDDB Query</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="obsolete">OK</translation>
+    </message>
+</context>
 <context>
     <name>RDCueEdit</name>
-    <message>
-        <source>&amp;Audition</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Pause</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Stop</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Start</source>
         <translation type="unfinished"></translation>
@@ -997,15 +1301,15 @@ farge</translation>
     </message>
     <message>
         <source>NUMBER</source>
-        <translation>NUMMER</translation>
+        <translation type="obsolete">NUMMER</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITTEL</translation>
+        <translation type="obsolete">TITTEL</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>Cuts</source>
@@ -1013,7 +1317,7 @@ farge</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>SKILDRING</translation>
+        <translation type="obsolete">SKILDRING</translation>
     </message>
     <message>
         <source>&amp;Add New
@@ -1048,6 +1352,22 @@ Cart</source>
         <source>Scheduler Code:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDDateDialog</name>
@@ -1095,6 +1415,33 @@ Cart</source>
         <translation>Su</translation>
     </message>
 </context>
+<context>
+    <name>RDDiscLookup</name>
+    <message>
+        <source>Multiple Matches Found!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to read CD.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="obsolete">Ukjent</translation>
+    </message>
+</context>
 <context>
     <name>RDEditAudio</name>
     <message>
@@ -1112,13 +1459,13 @@ Cart</source>
     <message>
         <source>Zoom
 In</source>
-        <translation>Zoom
+        <translation type="obsolete">Zoom
 inn</translation>
     </message>
     <message>
         <source>Zoom
 Out</source>
-        <translation>Zoom
+        <translation type="obsolete">Zoom
 ut</translation>
     </message>
     <message>
@@ -1354,51 +1701,51 @@ Are you sure you want to save?</source>
     <name>RDExceptionDialog</name>
     <message>
         <source>Rivendell Exception Report</source>
-        <translation>Unntaksrapport frå Rivendell</translation>
+        <translation type="obsolete">Unntaksrapport frå Rivendell</translation>
     </message>
     <message>
         <source>&amp;Save</source>
-        <translation>&amp;Lagre</translation>
+        <translation type="obsolete">&amp;Lagre</translation>
     </message>
     <message>
         <source>&amp;Close</source>
-        <translation>Lu&amp;kk</translation>
+        <translation type="obsolete">Lu&amp;kk</translation>
     </message>
     <message>
         <source>Text (*.txt *.TXT)
 All Files (*.*)</source>
-        <translation>Tekst (*.txt *.TXT)
+        <translation type="obsolete">Tekst (*.txt *.TXT)
 Alle filer (*.*)</translation>
     </message>
     <message>
         <source>Export File</source>
-        <translation>Eksporter fil</translation>
+        <translation type="obsolete">Eksporter fil</translation>
     </message>
     <message>
         <source>The file</source>
-        <translation>Fila</translation>
+        <translation type="obsolete">Fila</translation>
     </message>
     <message>
         <source>already exists!
 Overwrite?</source>
-        <translation>finst frå før!
+        <translation type="obsolete">finst frå før!
 Skriv over?</translation>
     </message>
     <message>
         <source>File Exists</source>
-        <translation>Fila finst</translation>
+        <translation type="obsolete">Fila finst</translation>
     </message>
     <message>
         <source>Unable to open file</source>
-        <translation>Greier ikkje opna fila</translation>
+        <translation type="obsolete">Greier ikkje opna fila</translation>
     </message>
     <message>
         <source>for writing!</source>
-        <translation>for skriving!</translation>
+        <translation type="obsolete">for skriving!</translation>
     </message>
     <message>
         <source>File Error</source>
-        <translation>Filfeil</translation>
+        <translation type="obsolete">Filfeil</translation>
     </message>
 </context>
 <context>
@@ -1821,46 +2168,35 @@ Sjekk eksportoppsettet ditt og prøv att.</translation>
         <source>Abort</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select Audio File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save Audio File</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDIntegerDialog</name>
-    <message>
-        <source>Set Value</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished">&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished">&amp;Avbryt</translation>
-    </message>
-</context>
-<context>
-    <name>RDIntegerEdit</name>
-    <message>
-        <source>Set Value</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Add</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">&amp;Avbryt</translation>
     </message>
 </context>
 <context>
     <name>RDLicense</name>
     <message>
         <source>&amp;Close</source>
-        <translation>Lu&amp;kk</translation>
+        <translation type="obsolete">Lu&amp;kk</translation>
     </message>
     <message>
         <source>GNU Public License v2</source>
-        <translation>GNU Public-lisensen, versjon 2</translation>
+        <translation type="obsolete">GNU Public-lisensen, versjon 2</translation>
     </message>
 </context>
 <context>
@@ -1888,17 +2224,9 @@ Sjekk eksportoppsettet ditt og prøv att.</translation>
 </context>
 <context>
     <name>RDListLogs</name>
-    <message>
-        <source>NAME</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation type="unfinished">SKILDRING</translation>
-    </message>
-    <message>
-        <source>SERVICE</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">SKILDRING</translation>
     </message>
     <message>
         <source>OK</source>
@@ -1916,6 +2244,18 @@ Sjekk eksportoppsettet ditt og prøv att.</translation>
         <source>ALL</source>
         <translation type="obsolete">ALLE</translation>
     </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDListSelector</name>
@@ -2054,6 +2394,49 @@ Sjekk eksportoppsettet ditt og prøv att.</translation>
         <translation type="obsolete">Sporleggjar</translation>
     </message>
 </context>
+<context>
+    <name>RDMbLookup</name>
+    <message>
+        <source>Connection Exception</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Result</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LastHTTPCode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LastErrorMessage</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timeout Exception</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Authentication Exception</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fetch Exception</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Request Exception</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lookup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resource Not Found</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDPanelButton</name>
     <message>
@@ -2098,6 +2481,25 @@ prøv ein gong til!</translation>
         <translation>OK</translation>
     </message>
 </context>
+<context>
+    <name>RDProcess</name>
+    <message>
+        <source>no such program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ok</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>process crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>process returned exit code</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDRecording</name>
     <message>
@@ -2325,11 +2727,11 @@ prøv ein gong til!</translation>
     <name>RDSqlDatabaseStatus</name>
     <message>
         <source>Database connection restored.</source>
-        <translation>Databasetilkoplinga er gjenoppretta.</translation>
+        <translation type="obsolete">Databasetilkoplinga er gjenoppretta.</translation>
     </message>
     <message>
         <source>Database connection failed : </source>
-        <translation>Feil med databasetilkoplinga: </translation>
+        <translation type="obsolete">Feil med databasetilkoplinga: </translation>
     </message>
 </context>
 <context>
@@ -2370,5 +2772,13 @@ prøv ein gong til!</translation>
 </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Log in use by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import failed</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
