@@ -2,9 +2,7 @@
 //
 // Abstract a Rivendell Audio Port
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdaudio_port.h,v 1.9.8.1 2012/08/03 16:52:39 cvs Exp $
+//   (C) Copyright 2002-2003,2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,7 +28,7 @@ class RDAudioPort
 {
   public:
    enum PortType {Analog=0,AesEbu=1,SpDiff=2};
-   RDAudioPort(QString station,int card,bool create=false);
+   RDAudioPort(QString station,int card);
    QString station() const;
    int card() const;
    RDCae::ClockSource clockSource();
@@ -45,10 +43,12 @@ class RDAudioPort
    void setOutputPortLevel(int port,int level);
 
   private:
-   int GetIntValue(QString field);
-   void SetRow(QString param,int value);
    QString port_station;
    int port_card;
+   int audio_input_port_level[RD_MAX_PORTS];
+   int audio_output_port_level[RD_MAX_PORTS];
+   RDAudioPort::PortType audio_input_port_type[RD_MAX_PORTS];
+   RDCae::ChannelMode audio_input_port_mode[RD_MAX_PORTS];
 };
 
 
