@@ -2,9 +2,7 @@
 //
 // Connect to the Rivendell Netcatcher Daemon.
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdcatch_connect.h,v 1.15 2008/10/02 18:52:11 fredg Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,14 +18,14 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qsqldatabase.h>
-#include <qstring.h>
-#include <qobject.h>
-#include <qsocket.h>
 #include <qlabel.h>
+#include <qobject.h>
+#include <qstring.h>
+#include <qtcpsocket.h>
 
 #include <rd.h>
 #include <rddeck.h>
+#include <rdrecording.h>
 
 #ifndef RDCATCH_CONNECT_H
 #define RDCATCH_CONNECT_H
@@ -36,12 +34,11 @@
 #define CC_MAX_LENGTH 256
 #define CC_HEARTBEAT_INTERVAL 15000
 
-
 class RDCatchConnect : public QObject
 {
  Q_OBJECT;
  public:
-  RDCatchConnect(int serial,QObject *parent=0,const char *name=0);
+  RDCatchConnect(int serial,QObject *parent=0);
   ~RDCatchConnect();
   void connectHost(QString hostname,Q_UINT16 hostport,QString password);
   RDDeck::Status status(unsigned chan) const;
@@ -51,9 +48,6 @@ class RDCatchConnect : public QObject
   void reloadDropboxes();
   
  public slots:
-  void addEvent(int id);
-  void removeEvent(int id);
-  void updateEvent(int id);
   void reset();
   void reload();
   void refresh();
@@ -61,6 +55,7 @@ class RDCatchConnect : public QObject
   void stop(int deck);
   void monitor(int deck,bool state);
   void toggleMonitor(int deck);
+  void setExitCode(int id,RDRecording::ExitCode code,const QString &msg);
 
  signals:
   void connected(int serial,bool state);
@@ -70,18 +65,18 @@ class RDCatchConnect : public QObject
   void meterLevel(int serial,int deck,int chan,int level);
   void eventUpdated(int id);
   void eventPurged(int id);
+  void deckEventSent(int serial,int chan,int number);
   void heartbeatFailed(int id);
   
  private slots:
   void connectedData();
-  void errorData(int errorcode);
   void readyData();
   void heartbeatTimeoutData();
   
  private:
   void SendCommand(QString cmd);
   void DispatchCommand();
-  QSocket *cc_socket;
+  QTcpSocket *cc_socket;
   QString cc_password;
   bool debug;
   char args[CC_MAX_ARGS][CC_MAX_LENGTH];
@@ -99,4 +94,4 @@ class RDCatchConnect : public QObject
 };
 
 
-#endif 
+#endif  // RDCATCH_CONNECT_H
