@@ -2,7 +2,7 @@
 //
 // Abstract a Rivendell Cut
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -59,6 +59,10 @@ class RDCut
   void setIsrc(const QString &isrc) const;
   QString isci() const;
   void setIsci(const QString &isci) const;
+  QString recordingMbId() const;
+  void setRecordingMbId(const QString &mbid);
+  QString releaseMbId() const;
+  void setReleaseMbId(const QString &mbid);
   QString sha1Hash() const;
   void setSha1Hash(const QString &str);
   unsigned length() const;
