@@ -2,9 +2,7 @@
 //
 // Decode Rivendell Date Macros
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rddatedecode.h,v 1.4 2007/02/14 21:48:41 fredg Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,15 +18,19 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdatetime.h>
-
-
 #ifndef RDDATEDECODE_H
 #define RDDATEDECODE_H
 
+#include <qdatetime.h>
 
-QString RDDateDecode(QString str,QDate date);
-QString RDDateTimeDecode(QString str,QDateTime datetime);
+#include <rdstation.h>
+#include <rdconfig.h>
+
+QString RDDateDecode(QString str,const QDate &date,RDStation *station,
+		     RDConfig *config,const QString &svcname="");
+QString RDDateTimeDecode(QString str,const QDateTime &datetime,
+			 RDStation *station,RDConfig *config,
+			 const QString &svcname="");
 
 
 #endif  // RDDATEDECODE
