@@ -2,7 +2,7 @@
 //
 // Download a File
 //
-//   (C) Copyright 2010,2016-2017 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2010-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,6 +31,7 @@
 #include <qfileinfo.h>
 
 #include <rd.h>
+#include <rdapplication.h>
 #include <rdsystemuser.h>
 #include <rddownload.h>
 
@@ -63,7 +64,7 @@ int DownloadErrorCallback(CURL *curl,curl_infotype type,char *msg,size_t size,
   }
   memset(&str,0,size+1);
   memcpy(str,msg,size);
-  syslog(LOG_DEBUG,"CURL MSG: %s",str);
+  rda->syslog(LOG_DEBUG,"CURL MSG: %s",str);
   return 0;
 }
 
@@ -106,7 +107,7 @@ RDDownload::ErrorCode RDDownload::runDownload(const QString &username,
   long response_code=0;
   RDDownload::ErrorCode ret=RDDownload::ErrorOk;
   RDSystemUser *user=NULL;
-  char url[1024];
+  //  char url[1024];
   char userpwd[256];
 
   //
@@ -127,16 +128,21 @@ RDDownload::ErrorCode RDDownload::runDownload(const QString &username,
     curl_easy_cleanup(curl);
     return RDDownload::ErrorNoDestination;
   }
+
   //
-  // Write out URL as a C string before passing to curl_easy_setopt(), 
-  // otherwise some versions of LibCurl will throw a 'bad/illegal format' 
-  // error.
+  // Write out an encoded URL
   //
-  strncpy(url,conv_src_url.
-	  toString(conv_src_url.protocol().lower().left(4)=="http"),1024);
-  curl_easy_setopt(curl,CURLOPT_URL,url);
+  QByteArray url=conv_src_url.toEncoded(QUrl::RemoveUserInfo);
+
+  //
+  // An URL anchor element will never occur here, so treat any '#' 
+  // characters as part of the path.
+  //
+  url.replace("#","%23");
+
+  curl_easy_setopt(curl,CURLOPT_URL,(const char *)url);
   curl_easy_setopt(curl,CURLOPT_WRITEDATA,f);
-  strncpy(userpwd,username+":"+password,256);
+  strncpy(userpwd,(username+":"+password).utf8(),256);
   curl_easy_setopt(curl,CURLOPT_USERPWD,userpwd);
   curl_easy_setopt(curl,CURLOPT_TIMEOUT,RD_CURL_TIMEOUT);
   curl_easy_setopt(curl,CURLOPT_FOLLOWLOCATION,1);
@@ -144,7 +150,7 @@ RDDownload::ErrorCode RDDownload::runDownload(const QString &username,
   curl_easy_setopt(curl,CURLOPT_PROGRESSDATA,this);
   curl_easy_setopt(curl,CURLOPT_NOPROGRESS,0);
   curl_easy_setopt(curl,CURLOPT_USERAGENT,
-		   (const char *)conv_config->userAgent());
+		   (const char *)conv_config->userAgent().utf8());
   if(log_debug) {
     curl_easy_setopt(curl,CURLOPT_VERBOSE,1);
     curl_easy_setopt(curl,CURLOPT_DEBUGFUNCTION,DownloadErrorCallback);
@@ -189,8 +195,8 @@ RDDownload::ErrorCode RDDownload::runDownload(const QString &username,
     break;
 
   default:
-    syslog(LOG_ERR,"Unknown CURL Error [%d]: %s",
-	   curl_err,curl_easy_strerror(curl_err));
+    rda->syslog(LOG_ERR,"Unknown CURL Error [%d]: %s",
+		curl_err,curl_easy_strerror(curl_err));
     ret=RDDownload::ErrorUnspecified;
   }
   if(user!=NULL) {
@@ -199,9 +205,9 @@ RDDownload::ErrorCode RDDownload::runDownload(const QString &username,
     delete user;
   }
   if((curl_err!=CURLE_OK)&&log_debug) {
-    syslog(LOG_WARNING,"CURL download failed: url: %s  username: %s",
-	   (const char *)conv_src_url.toString(),
-	   (const char *)username);
+    rda->syslog(LOG_WARNING,"CURL download failed: url: %s  username: %s",
+		(const char *)conv_src_url.toString(),
+		(const char *)username);
   }
   curl_easy_cleanup(curl);
   fclose(f);
