@@ -34,8 +34,8 @@ RDDropbox::RDDropbox(int id,const QString &stationname)
   box_id=id;
 
   if(id<0) {
-    sql=QString().sprintf("insert into DROPBOXES set STATION_NAME=\"%s\"",
-			  (const char *)stationname);
+    sql=QString("insert into DROPBOXES set ")+
+      "STATION_NAME=\""+RDEscapeString(stationname)+"\"";
     q=new RDSqlQuery(sql);
     delete q;
     sql="select ID from DROPBOXES order by ID desc";
@@ -54,6 +54,43 @@ int RDDropbox::id() const
 }
 
 
+int RDDropbox::duplicate() const
+{
+  int new_box_id;
+
+  RDDropbox *new_box=new RDDropbox(-1,stationName());
+  new_box_id=new_box->id();
+
+  new_box->setStationName(stationName());
+  new_box->setGroupName(groupName());
+  new_box->setPath(path());
+  new_box->setNormalizationLevel(normalizationLevel());
+  new_box->setAutotrimLevel(autotrimLevel());
+  new_box->setSingleCart(singleCart());
+  new_box->setForceToMono(forceToMono());
+  new_box->setToCart(toCart());
+  new_box->setUseCartchunkId(useCartchunkId());
+  new_box->setTitleFromCartchunkId(titleFromCartchunkId());
+  new_box->setDeleteCuts(deleteCuts());
+  new_box->setDeleteSource(deleteSource());
+  new_box->setMetadataPattern(metadataPattern());
+  new_box->setUserDefined(userDefined());
+  new_box->setStartdateOffset(startdateOffset());
+  new_box->setEnddateOffset(enddateOffset());
+  new_box->setFixBrokenFormats(fixBrokenFormats());
+  new_box->setLogPath(logPath());
+  new_box->setCreateDates(createDates());
+  new_box->setCreateStartdateOffset(createStartdateOffset());
+  new_box->setCreateEnddateOffset(createEnddateOffset());
+  new_box->setSegueLevel(segueLevel());
+  new_box->setSegueLength(segueLength());
+
+  delete new_box;
+
+  return new_box_id;
+}
+
+
 QString RDDropbox::stationName() const
 {
   return RDGetSqlValue("DROPBOXES","ID",box_id,"STATION_NAME").toString();
@@ -263,6 +300,19 @@ void RDDropbox::setFixBrokenFormats(bool state) const
 }
 
 
+bool RDDropbox::logToSyslog() const
+{
+  return RDBool(RDGetSqlValue("DROPBOXES","ID",box_id,"LOG_TO_SYSLOG").
+		toString());  
+}
+
+
+void RDDropbox::setLogToSyslog(bool state) const
+{
+  SetRow("LOG_TO_SYSLOG",state);
+}
+
+
 QString RDDropbox::logPath() const
 {
   return RDGetSqlValue("DROPBOXES","ID",box_id,"LOG_PATH").toString();
@@ -338,8 +388,9 @@ void RDDropbox::SetRow(const QString &param,int value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("update DROPBOXES set %s=%d where ID=%d",
-			(const char *)param,value,box_id);
+  sql=QString("update DROPBOXES set ")+
+    param+QString().sprintf("=%d where ",value)+
+    QString().sprintf("ID=%d",box_id);
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -350,8 +401,9 @@ void RDDropbox::SetRow(const QString &param,unsigned value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("update DROPBOXES set %s=%u where ID=%d",
-			(const char *)param,value,box_id);
+  sql=QString("update DROPBOXES set ")+
+    param+QString().sprintf("=%u where ",value)+
+    QString().sprintf("ID=%d",box_id);
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -362,10 +414,9 @@ void RDDropbox::SetRow(const QString &param,const QString &value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("update DROPBOXES set %s=\"%s\" where ID=%d",
-			(const char *)param,
-			(const char *)RDEscapeString(value),
-			box_id);
+  sql=QString("update DROPBOXES set ")+
+    param+"=\""+RDEscapeString(value)+"\" where "+
+    QString().sprintf("ID=%d",box_id);
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -376,9 +427,9 @@ void RDDropbox::SetRow(const QString &param,bool value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("update DROPBOXES set %s=\"%s\" where ID=%d",
-			(const char *)param,(const char *)RDYesNo(value),
-			box_id);
+  sql=QString("update DROPBOXES set ")+
+    param+"=\""+RDYesNo(value)+"\" where "+
+    QString().sprintf("ID=%d",box_id);
   q=new RDSqlQuery(sql);
   delete q;
 }
