@@ -4,8 +4,6 @@
 //
 //   (C) Copyright 2009 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdformpost.cpp,v 1.3.2.1 2012/12/13 22:33:44 cvs Exp $
-//
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
 //   published by the Free Software Foundation.
@@ -26,22 +24,30 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <syslog.h>
 
-#include <rdconf.h>
-#include <rdweb.h>
+#include "rdconf.h"
+#include "rddatetime.h"
+#include "rdweb.h"
 
 #include <rdformpost.h>
 
 RDFormPost::RDFormPost(RDFormPost::Encoding encoding,unsigned maxsize,
 		       bool auto_delete)
 {
-  char tempdir[PATH_MAX];
   bool ok=false;
 
   post_encoding=encoding;
   post_error=RDFormPost::ErrorNotInitialized;
   post_auto_delete=auto_delete;
+  post_data=NULL;
+  post_tempdir=NULL;
+
+  //
+  // Client Info
+  //
+  if(getenv("REMOTE_ADDR")!=NULL) {
+    post_client_address.setAddress(getenv("REMOTE_ADDR"));
+  }
 
   //
   // Verify Transfer Type
@@ -69,17 +75,18 @@ RDFormPost::RDFormPost(RDFormPost::Encoding encoding,unsigned maxsize,
   }
 
   //
-  // Initialize Temp Directory Path
+  // Get Content Type
   //
-  if(getenv("TMPDIR")!=NULL) {
-    strcpy(tempdir,getenv("TMPDIR"));
+  if(getenv("CONTENT_TYPE")!=NULL) {
+    post_content_type=getenv("CONTENT_TYPE");
   }
-  else {
-    strcpy(tempdir,"/tmp");
-  }
-  strcat(tempdir,"/rivendellXXXXXX");
-  post_tempdir=mkdtemp(tempdir);
-  if(post_tempdir.isNull()) {
+
+  //
+  // Initialize Temp Directory
+  //
+  post_tempdir=new RDTempDirectory("rdformpost");
+  QString err_msg;
+  if(!post_tempdir->create(&err_msg)) {
     post_error=RDFormPost::ErrorNoTempDir;
     return;
   }
@@ -119,11 +126,14 @@ RDFormPost::~RDFormPost()
     for(std::map<QString,bool>::const_iterator ci=post_filenames.begin();
 	ci!=post_filenames.end();ci++) {
       if(ci->second) {
-	unlink(post_values[ci->first].toString());
+	unlink(post_values.at(ci->first).toString());
       }
     }
-    if(!post_tempdir.isNull()) {
-      rmdir(post_tempdir);
+    if(post_tempdir!=NULL) {
+      delete post_tempdir;
+    }
+    if(post_data!=NULL) {
+      delete post_data;
     }
   }
 }
@@ -135,6 +145,12 @@ RDFormPost::Error RDFormPost::error() const
 }
 
 
+QHostAddress RDFormPost::clientAddress() const
+{
+  return post_client_address;
+}
+
+
 QStringList RDFormPost::names() const
 {
   QStringList list;
@@ -150,7 +166,7 @@ QVariant RDFormPost::value(const QString &name,bool *ok)
 {
   QVariant v;
   if(post_values.count(name)>0) {
-    v=post_values[name];
+    v=post_values.at(name);
   }
   if(ok!=NULL) {
     *ok=(post_values.count(name)>0);
@@ -159,42 +175,45 @@ QVariant RDFormPost::value(const QString &name,bool *ok)
 }
 
 
-bool RDFormPost::getValue(const QString &name,QHostAddress *addr)
+bool RDFormPost::getValue(const QString &name,QHostAddress *addr,bool *ok)
 {
   QString str;
-  bool ok=getValue(name,&str);
-  if(!ok) {
+  bool lok=getValue(name,&str);
+  if(!lok) {
     return false;
   }
   addr->setAddress(str);
+  if(ok!=NULL) {
+    *ok=addr->isNull();
+  }
   return true;
 }
 
 
-bool RDFormPost::getValue(const QString &name,QString *str)
+bool RDFormPost::getValue(const QString &name,QString *str,bool *ok)
 {
   if(post_values.count(name)>0) {
-    *str=post_values[name].toString();
+    *str=post_values.at(name).toString();
     return true;
   }
   return false;
 }
 
 
-bool RDFormPost::getValue(const QString &name,int *n)
+bool RDFormPost::getValue(const QString &name,int *n,bool *ok)
 {
   if(post_values.count(name)>0) {
-    *n=post_values[name].toInt();
+    *n=post_values.at(name).toInt(ok);
     return true;
   }
   return false;
 }
 
 
-bool RDFormPost::getValue(const QString &name,long *n)
+bool RDFormPost::getValue(const QString &name,long *n,bool *ok)
 {
   if(post_values.count(name)>0) {
-    *n=post_values[name].toLongLong();
+    *n=post_values.at(name).toLongLong(ok);
     return true;
   }
   *n=0;
@@ -202,33 +221,86 @@ bool RDFormPost::getValue(const QString &name,long *n)
 }
 
 
-bool RDFormPost::getValue(const QString &name,QDateTime *datetime)
+bool RDFormPost::getValue(const QString &name,QDateTime *datetime,bool *ok)
 {
   QString str;
-  if(!getValue(name,&str)) {
-    return false;
+
+  if(ok!=NULL) {
+    *ok=false;
   }
-  *datetime=RDGetWebDateTime(str);
-  return true;
-}
-
-
-bool RDFormPost::getValue(const QString &name,QTime *time)
-{
-  QString str;
   if(!getValue(name,&str)) {
     return false;
   }
   if(str.length()==0) {
+    *datetime=QDateTime();
+    if(ok!=NULL) {
+      *ok=true;
+    }
+  }
+  else {
+    *datetime=RDParseDateTime(str,ok);
+  }
+  return true;
+}
+
+
+bool RDFormPost::getValue(const QString &name,QDate *date,bool *ok)
+{
+  QString str;
+
+  if(ok!=NULL) {
+    *ok=false;
+  }
+  if(!getValue(name,&str)) {
+    return false;
+  }
+  if(str.length()==0) {
+    if(ok!=NULL) {
+      *ok=true;
+    }    
+    *date=QDate();
+  }
+  else {
+    *date=RDParseXmlDate(str,ok);
+  }
+  return true;
+}
+
+
+bool RDFormPost::getValue(const QString &name,QTime *time,bool *ok)
+{
+  QString str;
+
+  if(ok!=NULL) {
+    *ok=false;
+  }
+  if(!getValue(name,&str)) {
+    return false;
+  }
+  if(str.length()==0) {
+    if(ok!=NULL) {
+      *ok=true;
+    }    
     *time=QTime();
   }
   else {
-    *time=QTime().addMSecs(RDSetTimeLength(str));
+    *time=RDParseXmlTime(str,ok);
   }
   return true;
 }
 
 
+bool RDFormPost::getValue(const QString &name,bool *state,bool *ok)
+{
+  if(post_values.count(name)>0) {
+    *state=post_values.at(name).toInt(ok);
+    return true;
+  }
+  return false;
+  
+}
+
+
 bool RDFormPost::isFile(const QString &name)
 {
   return post_filenames[name];
@@ -237,7 +309,19 @@ bool RDFormPost::isFile(const QString &name)
 
 QString RDFormPost::tempDir() const
 {
-  return post_tempdir;
+  return post_tempdir->path();
+}
+
+
+unsigned RDFormPost::headerContentLength() const
+{
+  return post_content_length;
+}
+
+
+QString RDFormPost::headerContentType() const
+{
+  return post_content_type;
 }
 
 
@@ -258,9 +342,9 @@ void RDFormPost::dump()
   for(std::map<QString,QVariant>::const_iterator ci=post_values.begin();
       ci!=post_values.end();ci++) {
     printf("<tr>\n");
-    printf("<td align=\"left\">|%s|</td>\n",(const char *)ci->first);
+    printf("<td align=\"left\">|%s|</td>\n",(const char *)ci->first.utf8());
     printf("<td align=\"left\">|%s|</td>\n",
-	   (const char *)ci->second.toString());
+	   (const char *)ci->second.toString().utf8());
     if(post_filenames[ci->first]) {
       printf("<td align=\"center\">Yes</td>\n");
     }
@@ -274,6 +358,14 @@ void RDFormPost::dump()
 }
 
 
+void RDFormPost::dumpRawPost()
+{
+  printf("Content-type: text/html\n\n");
+  printf("%s",post_data);
+  fflush(stdout);
+}
+
+
 QString RDFormPost::errorString(RDFormPost::Error err)
 {
   QString str="Unknown error";
@@ -315,7 +407,7 @@ QString RDFormPost::urlEncode(const QString &str)
 {
   QString ret;
 
-  for(unsigned i=0;i<str.length();i++) {
+  for(int i=0;i<str.length();i++) {
     if(str.at(i).isLetterOrNumber()) {
       ret+=str.mid(i,1);
     }
@@ -336,7 +428,7 @@ QString RDFormPost::urlDecode(const QString &str)
   QString ret;
   bool ok=false;
 
-  for(unsigned i=0;i<str.length();i++) {
+  for(int i=0;i<str.length();i++) {
     switch(istate) {
     case 0:
       if(str.at(i)==QChar('+')) {
@@ -379,32 +471,25 @@ QString RDFormPost::urlDecode(const QString &str)
 
 void RDFormPost::LoadUrlEncoding(char first)
 {
-  char *data=new char[post_content_length+1];
+  post_data=new char[post_content_length+1];
   int n;
+  unsigned total_read=0;
   QStringList lines;
   QStringList line;
 
-  data[0]=first;
-  if((n=read(0,data+1,post_content_length-1))<0) {
-    post_error=RDFormPost::ErrorMalformedData;
-    return;
+  post_data[0]=first;
+  while(total_read<(post_content_length-1)) {
+    if((n=read(0,post_data+1+total_read,post_content_length-1-total_read))<0) {
+      post_error=RDFormPost::ErrorMalformedData;
+      return;
+    }
+    total_read+=n;
   }
-  data[post_content_length]=0;
 
-  /*
-   * Uncomment this to dump the raw post data to "/tmp/output.dat".
-   */
-  /*
-  int out=open("/tmp/output.dat",O_WRONLY|O_CREAT);
-  write(out,data,post_content_length);
-  ::close(out);
-  printf("Content-type: text/html\n\n");
-  printf("POST DUMPED TO \"/tmp/output.dat\"!\n");
-  exit(0);
-  */
-  lines=lines.split("&",data);
-  for(unsigned i=0;i<lines.size();i++) {
-    line=line.split("=",lines[i]);
+  post_data[post_content_length]=0;
+  lines=QString(post_data).split("&");
+  for(int i=0;i<lines.size();i++) {
+    line=lines[i].split("=");
     switch(line.size()) {
     case 1:
       post_values[line[0]]="";
@@ -419,114 +504,135 @@ void RDFormPost::LoadUrlEncoding(char first)
   }
 
   post_error=RDFormPost::ErrorOk;
-  delete data;
 }
 
 
 void RDFormPost::LoadMultipartEncoding(char first)
 {
-  std::map<QString,QString> headers;
-  bool header=true;
-  char *data=NULL;
-  FILE *f=NULL;
-  ssize_t n=0;
-  QString sep;
-  QString name;
-  QString filename;
-  QString tempdir;
-  int fd=-1;
-
-  if((f=fdopen(0,"r"))==NULL) {
+  //
+  // Create Stream Reader
+  //
+  if((post_stream=fdopen(0,"r"))==NULL) {
     post_error=RDFormPost::ErrorInternal;
     return;
   }
 
   /*
-   * Uncomment this to dump the raw post data to "/tmp/output.dat".
-   */
-  /*
-  int out=open("/tmp/output.dat",O_WRONLY|O_CREAT);
-  while((n=getline(&data,(size_t *)&n,f))>0) {
-    write(out,data,n);
+   * Uncomment to save raw post to disc
+   *
+  FILE *f;
+  QString dumpfile=QString("/var/snd/post-")+
+    QTime::currentTime().toString("hhmmsszzz")+".dat";
+  if((f=fopen(dumpfile.toUtf8(),"w"))!=NULL) {
+    char data[1025];
+    int n;
+
+    while((n=fread(data,1,1024,post_stream))>0) {
+      fwrite(data,1,n,f);
+    }
+    fclose(f);
+    printf("Content-type: text/html\n\n");
+    printf("Raw post written to \"%s\"\n",(const char *)dumpfile.toUtf8());
+    exit(0);
   }
-  ::close(out);
-  printf("Content-type: text/html\n\n");
-  printf("POST DUMPED TO \"/tmp/output.dat\"!\n");
-  exit(0);
   */
 
-  if((n=getline(&data,(size_t *)&n,f))<=0) {
-    post_error=RDFormPost::ErrorMalformedData;
-    return;
-  }
-  sep=QString(data).simplifyWhiteSpace();
+  //
+  // Get Separator Line
+  //
+  post_separator=first+QString::fromUtf8(GetLine()).trimmed();
 
   //
-  // Get message parts
+  // Read Mime Parts
   //
-  while((n=getline(&data,(size_t *)&n,f))>0) {
-    if(QString(data).simplifyWhiteSpace().contains(sep)>0) {  // End of part
-      if(fd>=0) {
-	ftruncate(fd,lseek(fd,0,SEEK_CUR)-2);  // Remove extraneous final CR/LF
-	::close(fd);
-	fd=-1;
-      }
-      name="";
-      filename="";
-      headers.clear();
-      header=true;
-      continue;
-    }
-    if(header) {  // Read header
-      if(QString(data).simplifyWhiteSpace().isEmpty()) {
-	if(!headers["content-disposition"].isNull()) {
-	  QStringList fields;
-	  fields=fields.split(";",headers["content-disposition"]);
-	  if(fields.size()>0) {
-	    if(fields[0].lower().simplifyWhiteSpace()=="form-data") {
-	      for(unsigned i=1;i<fields.size();i++) {
-		QStringList pairs;
-		pairs=pairs.split("=",fields[i]);
-		if(pairs[0].lower().simplifyWhiteSpace()=="name") {
-		  name=pairs[1].simplifyWhiteSpace();
-		  name.replace("\"","");
-		}
-		if(pairs[0].lower().simplifyWhiteSpace()=="filename") {
-		  filename=post_tempdir+"/"+pairs[1].simplifyWhiteSpace();
-		  filename.replace("\"","");
-		  fd=open(filename,O_WRONLY|O_CREAT,S_IRUSR|S_IWUSR);
-		}
-	      }
+  QString name;
+  QString value;
+  bool is_file;
+  bool again=false;
+
+  do {
+    again=GetMimePart(&name,&value,&is_file);
+    post_values[name]=value;
+    post_filenames[name]=is_file;
+  } while(again);
+  post_error=RDFormPost::ErrorOk;
+}
+
+
+bool RDFormPost::GetMimePart(QString *name,QString *value,bool *is_file)
+{
+  QString line;
+  int fd=-1;
+
+  *name="";
+  *value="";
+  *is_file=false;
+
+  //
+  // Headers
+  //
+  do {
+    //    line=post_text_reader->readLine();
+    line=QString::fromUtf8(GetLine());
+    QStringList f0=line.split(":");
+    if(f0.size()==2) {
+      if(f0[0].lower()=="content-disposition") {
+	QStringList f1=f0[1].split(";");
+	for(int i=0;i<f1.size();i++) {
+	  QStringList f2=f1[i].trimmed().split("=");
+	  if(f2.size()==2) {
+	    if(f2[0]=="name") {
+	      *name=f2[1].replace("\"","");
+	    }
+	    if(f2[0]=="filename") {
+	      *value=post_tempdir->path()+"/"+f2[1].replace("\"","");
+	      fd=open(value->utf8(),O_WRONLY|O_CREAT,S_IRUSR|S_IWUSR);
+	      *is_file=true;
 	    }
 	  }
 	}
-	header=false;
-      }
-      else {
-	QStringList hdr;
-	hdr=hdr.split(":",QString(data).simplifyWhiteSpace());
-	// Reconcaternate trailing sections so we don't split on the 
-	// useless M$ drive letter supplied by IE
-	for(unsigned i=2;i<hdr.size();i++) {
-	  hdr[1]+=hdr[i];
-	}
-	headers[hdr[0].lower()]=hdr[1];
       }
     }
-    else {  // Read data
-      if(filename.isEmpty()) {
-	QString str=post_values[name].toString();
-	str+=QString(data);
-	post_filenames[name]=false;
-	post_values[name]=str.simplifyWhiteSpace();
-      }
-      else {
-	post_filenames[name]=true;
-	post_values[name]=filename;
-	write(fd,data,n);
-      }
+  } while(!line.trimmed().isEmpty());
+
+  //
+  // Value
+  //
+  if(*is_file) {
+    QByteArray data;
+    data=GetLine();
+    line=QString::fromUtf8(data).trimmed();
+    while(!line.contains(post_separator)) {
+      write(fd,data,data.length());
+      data=GetLine();
+      line=QString::fromUtf8(data).trimmed();
     }
   }
+  else {
+    line=QString::fromUtf8(GetLine());
+    while((!line.isEmpty())&&(!line.contains(post_separator))) {
+      *value+=line;
+      line=QString::fromUtf8(GetLine());
+    }
+    *value=value->trimmed();
+  }
+
+  if(fd>=0) {
+    ftruncate(fd,lseek(fd,0,SEEK_CUR)-2);  // Remove extraneous final CR/LF
+    close(fd);
+  }
+
+  return line.trimmed().right(2)!="--";
+}
+
+
+QByteArray RDFormPost::GetLine() const
+{
+  char *data=NULL;
+  size_t n=0;
+
+  n=getline(&data,&n,post_stream);
+  QByteArray ret(data,n);
   free(data);
-  post_error=RDFormPost::ErrorOk;
+  return ret;
 }
