@@ -2,7 +2,7 @@
 //
 // Get an Agreggate Tuning Hours (ATH) Figure.
 //
-//   (C) Copyright 2006,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2006-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,15 +21,15 @@
 #ifndef GET_ATH_H
 #define GET_ATH_H
 
-#include <qdialog.h>
 #include <qlineedit.h>
 
-class RDGetAth : public QDialog
+#include <rddialog.h>
+
+class RDGetAth : public RDDialog
 {
   Q_OBJECT
   public:
    RDGetAth(double *ath,QWidget *parent=0);
-   ~RDGetAth();
    QSize sizeHint() const;
    QSizePolicy sizePolicy() const;
 
