@@ -2,7 +2,7 @@
 //
 // A widget to select a Rivendell Group.
 //
-//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,21 +21,22 @@
 #ifndef RDLIST_GROUPS_H
 #define RDLIST_GROUPS_H
 
-#include <qdialog.h>
-#include <qlistview.h>
+#include <q3listview.h>
+
 #include <qpushbutton.h>
 
-class RDListGroups : public QDialog
+#include <rddialog.h>
+
+class RDListGroups : public RDDialog
 {
  Q_OBJECT
  public:
  RDListGroups(QString *groupname,const QString &username,QWidget *parent=0);
- ~RDListGroups();
  QSize sizeHint() const;
  QSizePolicy sizePolicy() const;
 
  private slots:
-  void doubleClickedData(QListViewItem *item,const QPoint &pt,int col);
+  void doubleClickedData(Q3ListViewItem *item,const QPoint &pt,int col);
   void okData();
   void cancelData();
 
@@ -45,7 +46,7 @@ class RDListGroups : public QDialog
  private:
   void BuildGroupList(const QString &username);
   QString *group_name;
-  QListView *group_group_list;
+  Q3ListView *group_group_list;
 };
 
 
