@@ -2,9 +2,7 @@
 //
 // Install-Dependent Path Values for Rivendell
 //
-//   (C) Copyright 2008 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdpaths.h.in,v 1.6 2011/03/26 01:37:33 cvs Exp $
+//   (C) Copyright 2008,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -46,5 +44,16 @@ extern "C" {
  */
 #define RD_PREFIX "/usr/local"
 
+/*
+ * PyPAD
+ */
+#define RD_PYPAD_PYTHON_PATH "/usr/bin/python3"
+#define RD_PYPAD_SCRIPT_DIR "${exec_prefix}/lib/rivendell/pypad"
+
+/*
+ * runuser(1)
+ */
+#define RD_RUNUSER "/usr/sbin/runuser"
+
 
 #endif  // RDPATHS_H
