@@ -276,6 +276,41 @@ QString RDSettings::pathName(const QString &stationname,QString pathname,
 }
 
 
+QString RDSettings::defaultExtension(RDSettings::Format fmt)
+{
+  QString ret="dat";
+
+  switch(fmt) {
+  case RDSettings::Pcm16:
+  case RDSettings::Pcm24:
+  case RDSettings::MpegL2Wav:
+    ret="wav";
+    break;
+
+  case RDSettings::MpegL1:
+    ret="mp1";
+    break;
+
+  case RDSettings::MpegL2:
+    ret="mp2";
+    break;
+
+  case RDSettings::MpegL3:
+    ret="mp3";
+    break;
+
+  case RDSettings::Flac:
+    ret="flac";
+    break;
+
+  case RDSettings::OggVorbis:
+    ret="ogg";
+    break;
+  }
+  return ret;
+}
+
+
 QString RDSettings::defaultExtension(const QString &stationname,
 				     RDSettings::Format fmt)
 {
@@ -308,9 +343,9 @@ QString RDSettings::defaultExtension(const QString &stationname,
   RDSqlQuery *q;
   QString ret;
 
-  sql=QString().sprintf("select DEFAULT_EXTENSION from ENCODERS \
-                         where (ID=%d)&&(STATION_NAME=\"%s\")",
-			fmt,(const char *)RDEscapeString(stationname));
+  sql=QString("select DEFAULT_EXTENSION from ENCODERS where ")+
+    QString().sprintf("ID=%d)&&",fmt)+
+    "(STATION_NAME=\""+RDEscapeString(stationname)+"\")";
   q=new RDSqlQuery(sql);
   if(q->first()) {
     ret=q->value(0).toString();
