@@ -2,7 +2,7 @@
 //
 // The sound panel widget for RDAirPlay
 //
-//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,28 +19,30 @@
 //
 
 #include <qsignalmapper.h>
-#include <rddb.h>
-#include <rdlog_line.h>
-#include <rdsound_panel.h>
-#include <rdbutton_dialog.h>
-#include <rdmacro.h>
-#include <rdcut.h>
-#include <rdedit_panel_name.h>
-#include <rdescape_string.h>
-#include <rdconf.h>
+
+#include "rdapplication.h"
+#include "rdbutton_dialog.h"
+#include "rdcut.h"
+#include "rdconf.h"
+#include "rddb.h"
+#include "rdedit_panel_name.h"
+#include "rdescape_string.h"
+#include "rdlog_line.h"
+#include "rdmacro.h"
+#include "rdsound_panel.h"
 
 RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
-			   int user_panels,bool flash,
+			   int user_panels,bool flash,const QString &caption,
 			   const QString &label_template,bool extended,
-			   RDEventPlayer *player,RDRipc *ripc,RDCae *cae,
-			   RDStation *station,RDCartDialog *cart_dialog,
+			   RDEventPlayer *player,RDCartDialog *cart_dialog,
 			   QWidget *parent)
-  : QWidget(parent)
+  : RDWidget(parent)
 {
   panel_playmode_box=NULL;
   panel_button_columns=cols;
   panel_button_rows=rows;
   panel_cue_port=-1;
+  panel_caption=caption;
   if(extended) {
     panel_tablename="EXTENDED_PANELS";
     panel_name_tablename="EXTENDED_PANEL_NAMES";
@@ -56,10 +58,6 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
   panel_setup_mode=false;
   panel_reset_mode=false;
   panel_parent=parent;
-  panel_cae=cae;
-  panel_user=NULL;
-  panel_ripc=ripc;
-  panel_station=station;
   panel_station_panels=station_panels;
   panel_user_panels=user_panels;
   panel_event_player=player;
@@ -82,12 +80,6 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
   }
   panel_onair_flag=false;
 
-  //
-  // Create Fonts
-  //
-  QFont button_font=QFont("Helvetica",14,QFont::Bold);
-  button_font.setPixelSize(14);
-
   //
   // Load Buttons
   //
@@ -100,7 +92,7 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
   // Panel Selector
   //
   panel_selector_box=new RDComboBox(this);
-  panel_selector_box->setFont(button_font);
+  panel_selector_box->setFont(buttonFont());
   panel_selector_box->addIgnoredKey(Qt::Key_Space);
   panel_selector_box->
     setGeometry((15+PANEL_BUTTON_SIZE_X)*(panel_button_columns-5),
@@ -131,7 +123,7 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
   // Play Mode Box
   //
   panel_playmode_box=new QComboBox(this);
-  panel_playmode_box->setFont(button_font);
+  panel_playmode_box->setFont(buttonFont());
   panel_playmode_box->
     setGeometry((15+PANEL_BUTTON_SIZE_X)*(panel_button_columns-3)-5,
 		(15+PANEL_BUTTON_SIZE_Y)*panel_button_rows,
@@ -149,10 +141,10 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
     setGeometry((15+PANEL_BUTTON_SIZE_X)*(panel_button_columns-2),
 		(15+PANEL_BUTTON_SIZE_Y)*panel_button_rows,
 		PANEL_BUTTON_SIZE_X,50);
-  panel_reset_button->setFont(button_font);
+  panel_reset_button->setFont(buttonFont());
   panel_reset_button->setText(tr("Reset"));
   panel_reset_button->setFlashColor(QColor(RDPANEL_RESET_FLASH_COLOR));
-  panel_reset_button->setFocusPolicy(QWidget::NoFocus);
+  panel_reset_button->setFocusPolicy(Qt::NoFocus);
   connect(panel_reset_button,SIGNAL(clicked()),this,SLOT(resetClickedData()));
 
   //
@@ -163,10 +155,10 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
     setGeometry((15+PANEL_BUTTON_SIZE_X)*(panel_button_columns-1),
 		(15+PANEL_BUTTON_SIZE_Y)*panel_button_rows,
 		PANEL_BUTTON_SIZE_X,50);
-  panel_all_button->setFont(button_font);
+  panel_all_button->setFont(buttonFont());
   panel_all_button->setText(tr("All"));
   panel_all_button->setFlashColor(QColor(RDPANEL_RESET_FLASH_COLOR));
-  panel_all_button->setFocusPolicy(QWidget::NoFocus);
+  panel_all_button->setFocusPolicy(Qt::NoFocus);
   panel_all_button->hide();
   connect(panel_all_button,SIGNAL(clicked()),this,SLOT(allClickedData()));
 
@@ -178,29 +170,30 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
     setGeometry((15+PANEL_BUTTON_SIZE_X)*(panel_button_columns-1),
 		(15+PANEL_BUTTON_SIZE_Y)*panel_button_rows,
 		PANEL_BUTTON_SIZE_X,50);
-  panel_setup_button->setFont(button_font);
+  panel_setup_button->setFont(buttonFont());
   panel_setup_button->setText(tr("Setup"));
   panel_setup_button->setFlashColor(QColor(RDPANEL_SETUP_FLASH_COLOR));
-  panel_setup_button->setFocusPolicy(QWidget::NoFocus);
+  panel_setup_button->setFocusPolicy(Qt::NoFocus);
   connect(panel_setup_button,SIGNAL(clicked()),this,SLOT(setupClickedData()));
 
   //
   // Button Dialog Box
   //
   panel_button_dialog=
-    new RDButtonDialog(panel_station->name(),panel_label_template,
-		       panel_cart_dialog,panel_svcname,this);
+    new RDButtonDialog(rda->station()->name(),panel_caption,
+		       panel_label_template,panel_cart_dialog,panel_svcname,
+		       this);
 
   //
   // CAE Setup
   //
-  connect(panel_cae,SIGNAL(timescalingSupported(int,bool)),
+  connect(rda->cae(),SIGNAL(timescalingSupported(int,bool)),
 	  this,SLOT(timescalingSupportedData(int,bool)));
 
   //
   // RIPC Setup
   //
-  connect(panel_ripc,SIGNAL(onairFlagChanged(bool)),
+  connect(rda->ripc(),SIGNAL(onairFlagChanged(bool)),
 	  this,SLOT(onairFlagChangedData(bool)));
 
   //
@@ -210,7 +203,7 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
   QString sql;
   sql=QString("select PANEL_NO,NAME from ")+panel_name_tablename+" where "+
     QString().sprintf("(TYPE=%d)&&",RDAirPlayConf::StationPanel)+
-    "(OWNER=\""+RDEscapeString(panel_station->name())+"\") "+
+    "(OWNER=\""+RDEscapeString(rda->station()->name())+"\") "+
     "order by PANEL_NO";
   RDSqlQuery *q=new RDSqlQuery(sql);
   q->first();
@@ -268,7 +261,7 @@ int RDSoundPanel::card(int outnum) const
 void RDSoundPanel::setCard(int outnum,int card)
 {
   panel_card[outnum]=card;
-  panel_cae->requestTimescale(card);
+  rda->cae()->requestTimescale(card);
 }
 
 
@@ -304,12 +297,6 @@ void RDSoundPanel::setRmls(int outnum,const QString &start_rml,
 }
 
 
-void RDSoundPanel::setLogName(const QString &logname)
-{
-  panel_logname=logname;
-}
-
-
 void RDSoundPanel::setSvcName(const QString &svcname)
 {
   panel_svcname=svcname;
@@ -317,12 +304,6 @@ void RDSoundPanel::setSvcName(const QString &svcname)
 }
 
 
-void RDSoundPanel::setLogfile(QString filename)
-{
-  panel_logfile=filename;
-}
-
-
 void RDSoundPanel::play(RDAirPlayConf::PanelType type,int panel,
 			int row, int col,RDLogLine::StartSource src,int mport,
                         bool pause_when_finished)
@@ -429,25 +410,25 @@ void RDSoundPanel::setActionMode(RDAirPlayConf::ActionMode mode)
     return;
   }
   switch(mode) {
-      case RDAirPlayConf::CopyFrom:
-	mode=RDAirPlayConf::CopyFrom;
-	break;
+  case RDAirPlayConf::CopyFrom:
+    mode=RDAirPlayConf::CopyFrom;
+    break;
 
-      case RDAirPlayConf::CopyTo:
-	mode=RDAirPlayConf::CopyTo;
-	break;
+  case RDAirPlayConf::CopyTo:
+    mode=RDAirPlayConf::CopyTo;
+    break;
 
-      case RDAirPlayConf::AddTo:
-	mode=RDAirPlayConf::AddTo;
-	break;
+  case RDAirPlayConf::AddTo:
+    mode=RDAirPlayConf::AddTo;
+    break;
 
-      case RDAirPlayConf::DeleteFrom:
-	mode=RDAirPlayConf::DeleteFrom;
-	break;
+  case RDAirPlayConf::DeleteFrom:
+    mode=RDAirPlayConf::DeleteFrom;
+    break;
 
-      default:
-	mode=RDAirPlayConf::Normal;
-	break;
+  default:
+    mode=RDAirPlayConf::Normal;
+    break;
   }
   if(mode!=panel_action_mode) {
     panel_action_mode=mode;
@@ -572,11 +553,7 @@ void RDSoundPanel::acceptCartDrop(int row,int col,unsigned cartnum,
 
 void RDSoundPanel::changeUser()
 {
-  if(panel_user!=NULL) {
-    delete panel_user;
-  }
-  panel_user=new RDUser(panel_ripc->user());
-  panel_config_panels=panel_user->configPanels();
+  panel_config_panels=rda->user()->configPanels();
   LoadPanels();
   panel_buttons[PanelOffset(panel_type,panel_number)]->show();
 
@@ -594,7 +571,7 @@ void RDSoundPanel::changeUser()
   QString sql;
   sql=QString("select PANEL_NO,NAME from ")+panel_name_tablename+" where "+
     QString().sprintf("(TYPE=%d)&&",RDAirPlayConf::UserPanel)+
-    "(OWNER=\""+RDEscapeString(panel_user->name())+"\") "+
+    "(OWNER=\""+RDEscapeString(rda->user()->name())+"\") "+
     "order by PANEL_NO";
   RDSqlQuery *q=new RDSqlQuery(sql);
   q->first();
@@ -685,7 +662,7 @@ void RDSoundPanel::setupClickedData()
     panel_reset_button->setDisabled(true);
     panel_playmode_box->setDisabled(true);
   }
-  if(panel_station->enableDragdrop()&&(panel_station->enforcePanelSetup())) {
+  if(rda->station()->enableDragdrop()&&(rda->station()->enforcePanelSetup())) {
     for(unsigned i=0;i<panel_buttons.size();i++) {
       if(panel_buttons[i]!=NULL) {
 	panel_buttons[i]->setAcceptDrops(panel_setup_mode);
@@ -703,85 +680,85 @@ void RDSoundPanel::buttonMapperData(int id)
   unsigned cartnum;
 
   switch(panel_action_mode) {
-      case RDAirPlayConf::CopyFrom:
-	if((cartnum=panel_buttons[PanelOffset(panel_type,panel_number)]->
-	    panelButton(row,col)->cart())>0) {
-	  emit selectClicked(cartnum,0,0);
-	}
-	break;
+  case RDAirPlayConf::CopyFrom:
+    if((cartnum=panel_buttons[PanelOffset(panel_type,panel_number)]->
+	panelButton(row,col)->cart())>0) {
+      emit selectClicked(cartnum,0,0);
+    }
+    break;
 	
-      case RDAirPlayConf::CopyTo:
-         if(panel_buttons[PanelOffset(panel_type,panel_number)]->
-	    panelButton(row,col)->playDeck()==NULL
-             && ((panel_type==RDAirPlayConf::UserPanel) || 
-		 panel_config_panels)) { 
-	   emit selectClicked(0,row,col);
-           }
-	break;
+  case RDAirPlayConf::CopyTo:
+    if(panel_buttons[PanelOffset(panel_type,panel_number)]->
+       panelButton(row,col)->playDeck()==NULL
+       && ((panel_type==RDAirPlayConf::UserPanel) || 
+	   panel_config_panels)) { 
+      emit selectClicked(0,row,col);
+    }
+    break;
 	
-      case RDAirPlayConf::AddTo:
-         if(panel_buttons[PanelOffset(panel_type,panel_number)]->
-	    panelButton(row,col)->playDeck()==NULL
-             && ((panel_type==RDAirPlayConf::UserPanel) || 
-		 panel_config_panels)) { 
-	   emit selectClicked(0,row,col);
-           }
-	break;
+  case RDAirPlayConf::AddTo:
+    if(panel_buttons[PanelOffset(panel_type,panel_number)]->
+       panelButton(row,col)->playDeck()==NULL
+       && ((panel_type==RDAirPlayConf::UserPanel) || 
+	   panel_config_panels)) { 
+      emit selectClicked(0,row,col);
+    }
+    break;
 	
-      case RDAirPlayConf::DeleteFrom:
-         if(panel_buttons[PanelOffset(panel_type,panel_number)]->
-	    panelButton(row,col)->playDeck()==NULL
-             && ((panel_type==RDAirPlayConf::UserPanel) || 
-		 panel_config_panels)) { 
-	   emit selectClicked(0,row,col);
-           }
-	break;
+  case RDAirPlayConf::DeleteFrom:
+    if(panel_buttons[PanelOffset(panel_type,panel_number)]->
+       panelButton(row,col)->playDeck()==NULL
+       && ((panel_type==RDAirPlayConf::UserPanel) || 
+	   panel_config_panels)) { 
+      emit selectClicked(0,row,col);
+    }
+    break;
 	
-      default:
-	if(panel_setup_mode) {
-	  if((panel_type==RDAirPlayConf::StationPanel)&&
-	     (!panel_config_panels)) {
-	    ClearReset();
-	    return;
-	  }
-	  if(panel_button_dialog->
-	     exec(panel_buttons[PanelOffset(panel_type,panel_number)]->
-		  panelButton(row,col),panel_playmode_box->currentItem()==1,
-		  panel_user->name(),panel_user->password())
-	     ==0) {
-	    SaveButton(panel_type,panel_number,row,col);
-	  }
+  default:
+    if(panel_setup_mode) {
+      if((panel_type==RDAirPlayConf::StationPanel)&&
+	 (!panel_config_panels)) {
+	ClearReset();
+	return;
+      }
+      if(panel_button_dialog->
+	 exec(panel_buttons[PanelOffset(panel_type,panel_number)]->
+	      panelButton(row,col),panel_playmode_box->currentItem()==1,
+	      rda->user()->name(),rda->user()->password())
+	 ==0) {
+	SaveButton(panel_type,panel_number,row,col);
+      }
+    }
+    else {
+      RDPanelButton *button=
+	panel_buttons[PanelOffset(panel_type,panel_number)]->
+	panelButton(row,col);
+      RDPlayDeck *deck=button->playDeck();
+      if(panel_reset_mode) {
+	StopButton(panel_type,panel_number,row,col);
+      }
+      else {
+	if(deck==NULL) {
+	  PlayButton(panel_type,panel_number,row,col,
+		     RDLogLine::StartManual,
+		     panel_playmode_box->currentItem()==1);
 	}
 	else {
-	  RDPanelButton *button=
-	    panel_buttons[PanelOffset(panel_type,panel_number)]->
-	    panelButton(row,col);
-	  RDPlayDeck *deck=button->playDeck();
-	  if(panel_reset_mode) {
-	    StopButton(panel_type,panel_number,row,col);
-	  }
-	  else {
-	    if(deck==NULL) {
-	      PlayButton(panel_type,panel_number,row,col,
-			 RDLogLine::StartManual,
-			 panel_playmode_box->currentItem()==1);
+	  if(panel_pause_enabled) {
+	    if(deck->state()!=RDPlayDeck::Paused) {
+	      PauseButton(panel_type,panel_number,row,col);
 	    }
 	    else {
-	      if(panel_pause_enabled) {
-		if(deck->state()!=RDPlayDeck::Paused) {
-		  PauseButton(panel_type,panel_number,row,col);
-		}
-		else {
-		  PlayButton(panel_type,panel_number,row,col,
-			     RDLogLine::StartManual,button->hookMode());
-		}
-	      }
-	      else {
-		StopButton(panel_type,panel_number,row,col);
-	      }
+	      PlayButton(panel_type,panel_number,row,col,
+			 RDLogLine::StartManual,button->hookMode());
 	    }
 	  }
+	  else {
+	    StopButton(panel_type,panel_number,row,col);
+	  }
 	}
+      }
+    }
   }
   ClearReset();
 }
@@ -790,21 +767,21 @@ void RDSoundPanel::buttonMapperData(int id)
 void RDSoundPanel::stateChangedData(int id,RDPlayDeck::State state)
 {
   switch(state) {
-      case RDPlayDeck::Playing:
-	Playing(id);
-	break;
+  case RDPlayDeck::Playing:
+    Playing(id);
+    break;
 
-      case RDPlayDeck::Stopped:
-      case RDPlayDeck::Finished:
-        Stopped(id);
-	break;
+  case RDPlayDeck::Stopped:
+  case RDPlayDeck::Finished:
+    Stopped(id);
+    break;
 
-      case RDPlayDeck::Paused:
-	Paused(id);
-	break;
+  case RDPlayDeck::Paused:
+    Paused(id);
+    break;
 
-      default:
-	break;
+  default:
+    break;
   }
 }
 
@@ -818,13 +795,13 @@ void RDSoundPanel::hookEndData(int id)
   RDPlayDeck *deck=button->playDeck();
   if(deck!=NULL) {
     switch(deck->state()) {
-	case RDPlayDeck::Playing:
-	case RDPlayDeck::Paused:
-	  StopButton(id);
-	  break;
+    case RDPlayDeck::Playing:
+    case RDPlayDeck::Paused:
+      StopButton(id);
+      break;
 	  
-	default:
-	  break;
+    default:
+      break;
     }
   }
 }
@@ -842,7 +819,7 @@ void RDSoundPanel::timescalingSupportedData(int card,bool state)
 
 void RDSoundPanel::panelSetupData()
 {
-  if(panel_user->configPanels()||(panel_type==RDAirPlayConf::UserPanel)) {
+  if(rda->user()->configPanels()||(panel_type==RDAirPlayConf::UserPanel)) {
     QString sql;
     RDSqlQuery *q;
     int cutpt=panel_selector_box->currentText().find(" ");
@@ -922,13 +899,13 @@ void RDSoundPanel::PlayButton(RDAirPlayConf::PanelType type,int panel,
     deck->play(deck->currentPosition());
     if(button->hookMode()) {
       button->setStartTime(QTime::currentTime().
-			   addMSecs(panel_station->timeOffset()).
+			   addMSecs(rda->station()->timeOffset()).
 			   addMSecs(-deck->currentPosition()+
 				    deck->cut()->hookStartPoint()));
     }
     else {
       button->setStartTime(QTime::currentTime().
-			   addMSecs(panel_station->timeOffset()).
+			   addMSecs(rda->station()->timeOffset()).
 			   addMSecs(-deck->currentPosition()));
     }
     return;
@@ -955,16 +932,16 @@ void RDSoundPanel::PlayButton(RDAirPlayConf::PanelType type,int panel,
     button->setPauseWhenFinished(false);
     }
   switch(cart->type()) {
-      case RDCart::Audio:
-	PlayAudio(button,cart,hookmode,mport);
-	break;
+  case RDCart::Audio:
+    PlayAudio(button,cart,hookmode,mport);
+    break;
 
-      case RDCart::Macro:
-	PlayMacro(button,cart);
-	break;
+  case RDCart::Macro:
+    PlayMacro(button,cart);
+    break;
 
-      default:
-	break;
+  default:
+    break;
   }
   delete cart;
 }
@@ -990,7 +967,7 @@ bool RDSoundPanel::PlayAudio(RDPanelButton *button,RDCart *cart,bool hookmode,in
     }
   button->setOutputText(panel_output_text[button->output()]);
   button->setHookMode(hookmode);
-  button->setPlayDeck(new RDPlayDeck(panel_cae,button_deck,this));
+  button->setPlayDeck(new RDPlayDeck(rda->cae(),button_deck,this));
   button->playDeck()->setCard(panel_card[button->output()]);
   button->playDeck()->setPort(panel_port[button->output()]);
   button->playDeck()->duckVolume(button->duckVolume(),0);
@@ -1035,7 +1012,7 @@ bool RDSoundPanel::PlayAudio(RDPanelButton *button,RDCart *cart,bool hookmode,in
   // Start Playout
   //
   button->
-    setStartTime(QTime::currentTime().addMSecs(panel_station->timeOffset()));
+    setStartTime(QTime::currentTime().addMSecs(rda->station()->timeOffset()));
   if(hookmode&&(button->playDeck()->cut()->hookStartPoint()>=0)) {
     button->setActiveLength(button->playDeck()->cut()->hookEndPoint()-
       button->playDeck()->cut()->hookStartPoint());
@@ -1061,12 +1038,11 @@ void RDSoundPanel::PlayMacro(RDPanelButton *button,RDCart *cart)
 {
   RDMacro rml;
   rml.setRole(RDMacro::Cmd);
-  rml.setAddress(panel_station->address());
+  rml.setAddress(rda->station()->address());
   rml.setEchoRequested(false);
   rml.setCommand(RDMacro::EX);
-  rml.setArgQuantity(1);
-  rml.setArg(0,cart->number());
-  panel_ripc->sendRml(&rml);
+  rml.addArg(cart->number());
+  rda->ripc()->sendRml(&rml);
   if(!panel_svcname.isEmpty()) {
     LogTrafficMacro(button);
   }
@@ -1126,17 +1102,17 @@ void RDSoundPanel::StopButton(RDAirPlayConf::PanelType type,int panel,
                     setPauseWhenFinished(false);
               }
             switch(deck->state()) {
-	        case RDPlayDeck::Playing:
-	          deck->stop(fade_out,RD_FADE_DEPTH);
-	          break;
+	    case RDPlayDeck::Playing:
+	      deck->stop(fade_out,RD_FADE_DEPTH);
+	      break;
 
-  	        case RDPlayDeck::Paused:
-	          deck->clear();
-	          break;
+	    case RDPlayDeck::Paused:
+	      deck->clear();
+	      break;
 
-	        default:
-	          deck->clear();
-	          break;
+	    default:
+	      deck->clear();
+	      break;
             }
           }
         }
@@ -1169,16 +1145,16 @@ void RDSoundPanel::StopButton(RDPlayDeck *deck)
 {
   if(deck!=NULL) {
     switch(deck->state()) {
-	case RDPlayDeck::Playing:
-	  deck->stop();
-	  break;
+    case RDPlayDeck::Playing:
+      deck->stop();
+      break;
 
-	case RDPlayDeck::Paused:
-	  deck->clear();
-	  break;
+    case RDPlayDeck::Paused:
+      deck->clear();
+      break;
 
-	default:
-	  break;
+    default:
+      break;
     }
   }    
 }
@@ -1197,7 +1173,7 @@ void RDSoundPanel::LoadPanels()
   for(int i=0;i<panel_station_panels;i++) {
     panel_buttons.push_back(new RDButtonPanel(panel_type,i,panel_button_columns,
 					      panel_button_rows,
-					      panel_station,panel_flash,this));
+					      rda->station(),panel_flash,this));
     for(int j=0;j<panel_button_rows;j++) {
       for(int k=0;k<panel_button_columns;k++) {
 	connect(panel_buttons.back()->panelButton(j,k),SIGNAL(clicked()),
@@ -1207,12 +1183,12 @@ void RDSoundPanel::LoadPanels()
       }
     }
     LoadPanel(RDAirPlayConf::StationPanel,i);
-    panel_buttons.back()->setAllowDrags(panel_station->enableDragdrop());
+    panel_buttons.back()->setAllowDrags(rda->station()->enableDragdrop());
   }
   for(int i=0;i<panel_user_panels;i++) {
     panel_buttons.push_back(new RDButtonPanel(panel_type,i,panel_button_columns,
 					      panel_button_rows,
-					      panel_station,panel_flash,this));
+					      rda->station(),panel_flash,this));
     for(int j=0;j<panel_button_rows;j++) {
       for(int k=0;k<panel_button_columns;k++) {
 	connect(panel_buttons.back()->panelButton(j,k),SIGNAL(clicked()),
@@ -1221,7 +1197,7 @@ void RDSoundPanel::LoadPanels()
 			   j*panel_button_columns+k);
       }
     }
-    panel_buttons.back()->setAllowDrags(panel_station->enableDragdrop());
+    panel_buttons.back()->setAllowDrags(rda->station()->enableDragdrop());
     LoadPanel(RDAirPlayConf::UserPanel,i);
   }
 }
@@ -1233,18 +1209,15 @@ void RDSoundPanel::LoadPanel(RDAirPlayConf::PanelType type,int panel)
   int offset=0;
 
   switch(type) {
-      case RDAirPlayConf::UserPanel:
-	if(panel_user==NULL) {
-	  return;
-	}
-	owner=panel_user->name();
-	offset=panel_station_panels+panel;
-	break;
+  case RDAirPlayConf::UserPanel:
+    owner=rda->user()->name();
+    offset=panel_station_panels+panel;
+    break;
 
-      case RDAirPlayConf::StationPanel:
-	owner=panel_station->name();
-	offset=panel;
-	break;
+  case RDAirPlayConf::StationPanel:
+    owner=rda->station()->name();
+    offset=panel;
+    break;
   }
 
   QString sql=QString("select ")+panel_tablename+".ROW_NO,"+
@@ -1331,15 +1304,15 @@ void RDSoundPanel::SaveButton(RDAirPlayConf::PanelType type,
   int offset=0;
 
   switch(type) {
-      case RDAirPlayConf::UserPanel:
-	owner=panel_user->name();
-	offset=panel_station_panels+panel;
-	break;
+  case RDAirPlayConf::UserPanel:
+    owner=rda->user()->name();
+    offset=panel_station_panels+panel;
+    break;
 
-      case RDAirPlayConf::StationPanel:
-	owner=panel_station->name();
-	offset=panel;
-	break;
+  case RDAirPlayConf::StationPanel:
+    owner=rda->station()->name();
+    offset=panel;
+    break;
   }
 
   //
@@ -1404,13 +1377,13 @@ void RDSoundPanel::SaveButton(RDAirPlayConf::PanelType type,
 int RDSoundPanel::PanelOffset(RDAirPlayConf::PanelType type,int panel)
 {
   switch(type) {
-      case RDAirPlayConf::StationPanel:
-	return panel;
-	break;
+  case RDAirPlayConf::StationPanel:
+    return panel;
+    break;
 
-      case RDAirPlayConf::UserPanel:
-	return panel_station_panels+panel;
-	break;
+  case RDAirPlayConf::UserPanel:
+    return panel_station_panels+panel;
+    break;
   }
   return 0;
 }
@@ -1463,7 +1436,7 @@ void RDSoundPanel::LogTraffic(RDPanelButton *button)
 
   QString sql;
   RDSqlQuery *q;
-  QDateTime datetime(QDate::currentDate(),QTime::currentTime());
+  QDateTime now=QDateTime::currentDateTime();
 
   sql=QString("select ")+
     "CART.TITLE,"+         // 00
@@ -1485,19 +1458,14 @@ void RDSoundPanel::LogTraffic(RDPanelButton *button)
     "CUTS.CUT_NAME=\""+RDEscapeString(button->cutName())+"\"";
   q=new RDSqlQuery(sql);
   if(q->first()) {
-
-    QString eventDateTimeSQL = "NULL";
-
-    if(datetime.isValid() && button->startTime().isValid())
-      eventDateTimeSQL = RDCheckDateTime(QDateTime(datetime.date(),
-            button->startTime()), "yyyy-MM-dd hh:mm:ss");
-
-    sql=QString("insert into `")+panel_svcname+"_SRT` set "+
-      QString().sprintf("LENGTH=%d,",button->startTime().
-			msecsTo(datetime.time()))+
+    sql=QString("insert into ELR_LINES set ")+
+      "SERVICE_NAME=\""+RDEscapeString(panel_svcname)+"\","+
+      QString().sprintf("LENGTH=%d,",button->startTime().msecsTo(now.time()))+
       QString().sprintf("CART_NUMBER=%u,",button->cart())+
-      "STATION_NAME=\""+RDEscapeString(panel_station->name().utf8())+"\","+
-      "EVENT_DATETIME="+eventDateTimeSQL+","+
+      "STATION_NAME=\""+RDEscapeString(rda->station()->name().utf8())+"\","+
+      "EVENT_DATETIME="+
+      RDCheckDateTime(QDateTime(now.date(),button->startTime()),
+		      "yyyy-MM-dd hh:mm:ss")+","+
       QString().sprintf("EVENT_TYPE=%d,",RDAirPlayConf::TrafficStop)+
       QString().sprintf("EVENT_SOURCE=%d,",RDLogLine::SoundPanel)+
       QString().sprintf("PLAY_SOURCE=%d,",RDLogLine::SoundPanel)+
@@ -1536,10 +1504,11 @@ void RDSoundPanel::LogTrafficMacro(RDPanelButton *button)
     QString().sprintf("NUMBER=%u",button->cart());
   q=new RDSqlQuery(sql);
   if(q->first()) {
-    sql=QString("insert into `")+panel_svcname+"_SRT` set "+
+    sql=QString("insert into ELR_LINES set ")+
+      "SERVICE_NAME=\""+RDEscapeString(panel_svcname)+"\","+
       QString().sprintf("LENGTH=%d,",q->value(5).toUInt())+
       QString().sprintf("CART_NUMBER=%u,",button->cart())+
-      "STATION_NAME=\""+RDEscapeString(panel_station->name().utf8())+"\","+
+      "STATION_NAME=\""+RDEscapeString(rda->station()->name().utf8())+"\","+
       "EVENT_DATETIME=\""+datetime.toString("yyyy-MM-dd hh:mm:ss")+"\","+
       QString().sprintf("EVENT_TYPE=%d,",RDAirPlayConf::TrafficMacro)+
       QString().sprintf("EVENT_SOURCE=%d,",RDLogLine::SoundPanel)+
@@ -1653,7 +1622,7 @@ void RDSoundPanel::Stopped(int id)
 void RDSoundPanel::ClearChannel(int id)
 {
   RDPlayDeck *playdeck=panel_active_buttons[id]->playDeck();
-  if(panel_cae->
+  if(rda->cae()->
      playPortActive(playdeck->card(),playdeck->port(),playdeck->stream())) {
     return;
   }
@@ -1683,13 +1652,11 @@ QString RDSoundPanel::PanelTag(int index)
 QString RDSoundPanel::PanelOwner(RDAirPlayConf::PanelType type)
 {
   switch(type) {
-      case RDAirPlayConf::StationPanel:
-	return panel_station->name();
+  case RDAirPlayConf::StationPanel:
+    return rda->station()->name();
 
-      case RDAirPlayConf::UserPanel:
-	if(panel_user!=NULL) {
-	  return panel_user->name();
-	}
+  case RDAirPlayConf::UserPanel:
+    return rda->user()->name();
   }
   return QString();
 }
