@@ -2,9 +2,7 @@
 //
 //   A URL Handling Class with Support for SMB URLs.
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//    $Id: rdurl.cpp,v 1.4 2010/07/29 19:32:34 cvs Exp $
+//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -19,19 +17,17 @@
 //   License along with this program; if not, write to the Free Software
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-//
 
 #include <rdurl.h>
 
-
 RDUrl::RDUrl()
-  : QUrl()
+  : Q3Url()
 {
 }
 
 
 RDUrl::RDUrl(const QString &url)
-  : QUrl(url)
+  : Q3Url(url)
 {
 }
 
@@ -48,9 +44,7 @@ QString RDUrl::smbShare() const
   if((offset=path().right(path().length()-1).find("/"))<0) {
     offset=path().length();
   }
-  return QString().sprintf("//%s%s",
-			   (const char *)host(),
-			   (const char *)path().left(offset+1));
+  return QString("//")+host()+path().left(offset+1);
 }
 
 
