@@ -1,8 +1,8 @@
 // add_feed.cpp
 //
-// Add a Rivendell Service
+// Add a Rivendell RSS Feed
 //
-//   (C) Copyright 2002,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,18 +26,20 @@
 #include <qdatetime.h>
 
 #include <rddb.h>
-#include <rdtextvalidator.h>
+#include <rdapplication.h>
 #include <rdescape_string.h>
-#include <rdcreateauxfieldstable.h>
 #include <rdfeedlog.h>
+#include <rdtextvalidator.h>
 
 #include "add_feed.h"
 #include "edit_feed.h"
 #include "globals.h"
 
 AddFeed::AddFeed(unsigned *id,QString *keyname,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   feed_keyname=keyname;
   feed_id=id;
 
@@ -49,15 +51,7 @@ AddFeed::AddFeed(unsigned *id,QString *keyname,QWidget *parent)
   setMinimumHeight(sizeHint().height());
   setMaximumHeight(sizeHint().height());
 
-  setCaption(tr("Add Feed"));
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-  QFont user_font=QFont("Helvetica",12,QFont::Normal);
-  user_font.setPixelSize(12);
+  setWindowTitle("RDADmin - "+tr("Add RSS Feed"));
 
   //
   // Enable Users Checkbox
@@ -67,8 +61,7 @@ AddFeed::AddFeed(unsigned *id,QString *keyname,QWidget *parent)
   feed_users_box->setChecked(true);
   QLabel *label=new QLabel(feed_users_box,tr("Enable Feed for All Users"),this);
   label->setGeometry(60,38,sizeHint().width()-60,19);
-  label->setFont(user_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Text Validator
@@ -84,8 +77,8 @@ AddFeed::AddFeed(unsigned *id,QString *keyname,QWidget *parent)
   feed_keyname_edit->setValidator(validator);
   label=new QLabel(feed_keyname_edit,tr("&New Feed Name:"),this);
   label->setGeometry(10,11,130,19);
-  label->setFont(font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   //  Ok Button
@@ -93,7 +86,7 @@ AddFeed::AddFeed(unsigned *id,QString *keyname,QWidget *parent)
   QPushButton *ok_button=new QPushButton(this);
   ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   ok_button->setDefault(true);
-  ok_button->setFont(font);
+  ok_button->setFont(buttonFont());
   ok_button->setText(tr("&OK"));
   connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -103,7 +96,7 @@ AddFeed::AddFeed(unsigned *id,QString *keyname,QWidget *parent)
   QPushButton *cancel_button=new QPushButton(this);
   cancel_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
 			     80,50);
-  cancel_button->setFont(font);
+  cancel_button->setFont(buttonFont());
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 }
@@ -133,8 +126,8 @@ void AddFeed::okData()
   RDSqlQuery *q;
   RDSqlQuery *q1;
 
-  sql=QString().sprintf("select KEY_NAME from FEEDS where KEY_NAME=\"%s\"",
-			(const char *)feed_keyname_edit->text());
+  sql=QString("select KEY_NAME from FEEDS where ")+
+    "KEY_NAME=\""+RDEscapeString(feed_keyname_edit->text())+"\"";
   q=new RDSqlQuery(sql);
   if(q->first()) {
     QMessageBox::warning(this,tr("Add Feed Error"),
@@ -148,14 +141,13 @@ void AddFeed::okData()
   // Create Default Feed Perms
   //
   if(feed_users_box->isChecked()) {
-    sql="select LOGIN_NAME from USERS \
-         where (ADMIN_USERS_PRIV='N')&&(ADMIN_CONFIG_PRIV='N')";
+    sql=QString("select LOGIN_NAME from USERS where ")+
+      "(ADMIN_USERS_PRIV='N')&&(ADMIN_CONFIG_PRIV='N')";
     q=new RDSqlQuery(sql);
     while(q->next()) {
-      sql=QString().sprintf("insert into FEED_PERMS set USER_NAME=\"%s\",\
-                             KEY_NAME=\"%s\"",
-			    (const char *)q->value(0).toString(),
-			    (const char *)feed_keyname_edit->text());
+      sql=QString("insert into FEED_PERMS set ")+
+	"USER_NAME=\""+RDEscapeString(q->value(0).toString())+"\","+
+	"KEY_NAME=\""+RDEscapeString(feed_keyname_edit->text())+"\"";
       q1=new RDSqlQuery(sql);
       delete q1;
     }
@@ -165,23 +157,16 @@ void AddFeed::okData()
   //
   // Create Feed
   //
-  sql=QString().sprintf("insert into FEEDS set KEY_NAME=\"%s\",\
-                         ORIGIN_DATETIME=\"%s %s\",HEADER_XML=\"%s\",\
-                         CHANNEL_XML=\"%s\",ITEM_XML=\"%s\"",
-			(const char *)feed_keyname_edit->text(),
-			(const char *)QDate::currentDate().
-			toString("yyyy-MM-dd"),
-			(const char *)QTime::currentTime().
-			toString("hh:mm:ss"),
-			(const char *)RDEscapeString(DEFAULT_HEADER_XML),
-			(const char *)RDEscapeString(DEFAULT_CHANNEL_XML),
-			(const char *)RDEscapeString(DEFAULT_ITEM_XML));
+  sql=QString("insert into FEEDS set ")+
+    "KEY_NAME=\""+RDEscapeString(feed_keyname_edit->text())+"\","+
+    "ORIGIN_DATETIME=now(),"+
+    "HEADER_XML=\""+RDEscapeString(DEFAULT_HEADER_XML)+"\","+
+    "CHANNEL_XML=\""+RDEscapeString(DEFAULT_CHANNEL_XML)+"\","+
+    "ITEM_XML=\""+RDEscapeString(DEFAULT_ITEM_XML)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
-  RDCreateFeedLog(feed_keyname_edit->text());
-  RDCreateAuxFieldsTable(feed_keyname_edit->text(),admin_config);
-  sql=QString().sprintf("select ID from FEEDS where KEY_NAME=\"%s\"",
-			(const char *)feed_keyname_edit->text());
+  sql=QString("select ID from FEEDS where ")+
+    "KEY_NAME=\""+RDEscapeString(feed_keyname_edit->text())+"\"";
   q=new RDSqlQuery(sql);
   if(q->first()) {
     *feed_id=q->value(0).toUInt();
