@@ -2,7 +2,7 @@
 //
 // Add a Rivendell Report
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,14 +21,13 @@
 #ifndef ADD_REPORT_H
 #define ADD_REPORT_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
-#include <qlineedit.h>
 #include <qcombobox.h>
+#include <qlineedit.h>
 
+#include <rddialog.h>
 #include <rdreport.h>
 
-class AddReport : public QDialog
+class AddReport : public RDDialog
 {
  Q_OBJECT
  public:
