@@ -2,7 +2,7 @@
 //
 // Edit a Rivendell Endpoint
 //
-//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,8 +28,10 @@ EditEndpoint::EditEndpoint(RDMatrix::Type type,RDMatrix::Endpoint endpoint,
 			   int pointnum,QString *pointname,QString *feedname,
 			   RDMatrix::Mode *mode,int *enginenum,int *devicenum,
 			   QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   edit_type=type;
   edit_endpoint=endpoint;
   edit_pointnum=pointnum;
@@ -40,15 +42,15 @@ EditEndpoint::EditEndpoint(RDMatrix::Type type,RDMatrix::Endpoint endpoint,
   edit_devicenum=devicenum;
 
   switch(edit_endpoint) {
-      case RDMatrix::Input:
-	edit_table="INPUTS";
-	setCaption(tr("Edit Input"));
-	break;
+  case RDMatrix::Input:
+    edit_table="INPUTS";
+    setWindowTitle("RDAdmin - "+tr("Edit Input"));
+    break;
 
-      case RDMatrix::Output:
-	edit_table="OUTPUTS";
-	setCaption(tr("Edit Output"));
-	break;
+  case RDMatrix::Output:
+    edit_table="OUTPUTS";
+    setWindowTitle("RDAdmin - "+tr("Edit Output"));
+    break;
   }
 
   //
@@ -59,14 +61,6 @@ EditEndpoint::EditEndpoint(RDMatrix::Type type,RDMatrix::Endpoint endpoint,
   setMinimumHeight(sizeHint().height());
   setMaximumHeight(sizeHint().height());
 
-  //
-  // Create Fonts
-  //
-  QFont bold_font=QFont("Helvetica",12,QFont::Bold);
-  bold_font.setPixelSize(12);
-  QFont font=QFont("Helvetica",12,QFont::Normal);
-  font.setPixelSize(12);
-
   //
   // Text Validator
   //
@@ -80,8 +74,8 @@ EditEndpoint::EditEndpoint(RDMatrix::Type type,RDMatrix::Endpoint endpoint,
   edit_endpoint_edit->setValidator(validator);
   QLabel *label=new QLabel(edit_endpoint_edit,tr("Name: "),this);
   label->setGeometry(10,13,60,20);
-  label->setFont(bold_font);
-  label->setAlignment(AlignRight);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight);
 
   //
   // Unity Feed
@@ -91,8 +85,8 @@ EditEndpoint::EditEndpoint(RDMatrix::Type type,RDMatrix::Endpoint endpoint,
   edit_feed_edit->setValidator(validator);
   label=new QLabel(edit_feed_edit,tr("Feed: "),this);
   label->setGeometry(10,43,60,20);
-  label->setFont(bold_font);
-  label->setAlignment(AlignRight);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight);
   if((edit_type!=RDMatrix::Unity4000)||(edit_endpoint!=RDMatrix::Input)) {
     edit_feed_edit->hide();
     label->hide();
@@ -111,8 +105,8 @@ EditEndpoint::EditEndpoint(RDMatrix::Type type,RDMatrix::Endpoint endpoint,
     edit_mode_box->setGeometry(195,40,85,24);
     label->setGeometry(130,43,60,20);
   }
-  label->setFont(bold_font);
-  label->setAlignment(AlignRight);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight);
   if(((edit_type!=RDMatrix::Unity4000)&&(edit_type!=RDMatrix::StarGuideIII))||
      (edit_endpoint!=RDMatrix::Input)) {
     edit_mode_box->hide();
@@ -132,8 +126,8 @@ EditEndpoint::EditEndpoint(RDMatrix::Type type,RDMatrix::Endpoint endpoint,
     label->setText(tr("Provider ID:"));
   }
   label->setGeometry(10,36,120,20);
-  label->setFont(bold_font);
-  label->setAlignment(AlignRight|AlignVCenter);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   if((edit_type!=RDMatrix::LogitekVguest)&&
      ((edit_type!=RDMatrix::StarGuideIII)||(edit_endpoint!=RDMatrix::Input))) {
     edit_enginenum_edit->hide();
@@ -150,8 +144,8 @@ EditEndpoint::EditEndpoint(RDMatrix::Type type,RDMatrix::Endpoint endpoint,
     label->setText(tr("Service ID:"));
   }
   label->setGeometry(10,62,120,20);
-  label->setFont(bold_font);
-  label->setAlignment(AlignRight|AlignVCenter);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   if((edit_type!=RDMatrix::LogitekVguest)&&
      ((edit_type!=RDMatrix::StarGuideIII)||(edit_endpoint!=RDMatrix::Input))) {
     edit_devicenum_edit->hide();
@@ -164,7 +158,7 @@ EditEndpoint::EditEndpoint(RDMatrix::Type type,RDMatrix::Endpoint endpoint,
   QPushButton *button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   button->setDefault(true);
-  button->setFont(bold_font);
+  button->setFont(buttonFont());
   button->setText(tr("&OK"));
   connect(button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -173,7 +167,7 @@ EditEndpoint::EditEndpoint(RDMatrix::Type type,RDMatrix::Endpoint endpoint,
   //
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
-  button->setFont(bold_font);
+  button->setFont(buttonFont());
   button->setText(tr("&Cancel"));
   connect(button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
