@@ -1,10 +1,8 @@
 // edit_hostvar.cpp
 //
-// Edit a Rivendell Workstation Configuration
+// Edit a Rivendell Host Variable
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_hostvar.cpp,v 1.8 2010/07/29 19:32:34 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,18 +18,16 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
 #include <qstring.h>
 #include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
+#include <q3listbox.h>
+#include <q3textedit.h>
 #include <qlabel.h>
 #include <qpainter.h>
 #include <qevent.h>
 #include <qmessagebox.h>
 #include <qcheckbox.h>
-#include <qbuttongroup.h>
-#include <qsqldatabase.h>
+#include <q3buttongroup.h>
 
 #include <rdcatch_connect.h>
 
@@ -44,21 +40,15 @@
 #include <list_matrices.h>
 #include <list_hostvars.h>
 
-
 EditHostvar::EditHostvar(QString station,QString var,QString *varvalue,
-			 QString *remark,QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+			 QString *remark,QWidget *parent)
+  : RDDialog(parent)
 {
+  setModal(true);
   edit_varvalue=varvalue;
   edit_remark=remark;
 
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-
-  setCaption(tr("Edit Host Variable"));
+  setWindowTitle("RDAdmin - "+tr("Edit Host Variable"));
 
   //
   // Fix the Window Size
@@ -71,55 +61,53 @@ EditHostvar::EditHostvar(QString station,QString var,QString *varvalue,
   //
   // Variable Name
   //
-  edit_name_edit=new QLineEdit(this,"edit_name_edit");
+  edit_name_edit=new QLineEdit(this);
   edit_name_edit->setGeometry(125,11,120,19);
   edit_name_edit->setReadOnly(true);
-  QLabel *label=new QLabel(edit_name_edit,tr("Variable Name:"),
-			   this,"edit_name_label");
+  QLabel *label=new QLabel(edit_name_edit,tr("Variable Name:"),this);
   label->setGeometry(10,11,110,19);
-  label->setFont(font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Variable Value
   //
-  edit_varvalue_edit=new QLineEdit(this,"edit_varvalue_edit");
+  edit_varvalue_edit=new QLineEdit(this);
   edit_varvalue_edit->setGeometry(125,33,sizeHint().width()-135,19);
   edit_varvalue_edit->setMaxLength(255);
-  label=new QLabel(edit_varvalue_edit,tr("Variable Value:"),
-		   this,"edit_varvalue_label");
+  label=new QLabel(edit_varvalue_edit,tr("Variable Value:"),this);
   label->setGeometry(10,33,110,19);
-  label->setFont(font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Remark
   //
-  edit_remark_edit=new QLineEdit(this,"edit_remark_edit");
+  edit_remark_edit=new QLineEdit(this);
   edit_remark_edit->setGeometry(125,55,sizeHint().width()-135,19);
   edit_remark_edit->setMaxLength(255);
-  label=new QLabel(edit_remark_edit,tr("Remark:"),this,"edit_remark_label");
+  label=new QLabel(edit_remark_edit,tr("Remark:"),this);
   label->setGeometry(10,55,110,19);
-  label->setFont(font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   //  Ok Button
   //
-  QPushButton *ok_button=new QPushButton(this,"ok_button");
+  QPushButton *ok_button=new QPushButton(this);
   ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   ok_button->setDefault(true);
-  ok_button->setFont(font);
+  ok_button->setFont(buttonFont());
   ok_button->setText(tr("&OK"));
   connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
   //
   //  Cancel Button
   //
-  QPushButton *cancel_button=new QPushButton(this,"cancel_button");
-  cancel_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
-			     80,50);
-  cancel_button->setFont(font);
+  QPushButton *cancel_button=new QPushButton(this);
+  cancel_button->
+    setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
+  cancel_button->setFont(buttonFont());
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
