@@ -2,7 +2,7 @@
 //
 // Edit an RDAirPlay Configuration
 //
-//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,19 +18,19 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qradiobutton.h>
+#include <q3buttongroup.h>
 #include <q3listbox.h>
 #include <q3textedit.h>
-#include <qpainter.h>
-#include <qevent.h>
-#include <qmessagebox.h>
+
 #include <qcheckbox.h>
-#include <q3buttongroup.h>
+#include <qdialog.h>
+#include <qevent.h>
+#include <qfiledialog.h>
+#include <qmessagebox.h>
 #include <qpainter.h>
-#include <q3filedialog.h>
+#include <qpushbutton.h>
+#include <qradiobutton.h>
+#include <qstring.h>
 
 #include <rd.h>
 #include <rddb.h>
@@ -1188,8 +1188,9 @@ void EditRDAirPlay::editHotKeys()
 void EditRDAirPlay::selectSkinData()
 {
   QString filename=air_skin_edit->text();
-  filename=Q3FileDialog::getOpenFileName(filename,RD_IMAGE_FILE_FILTER,this,"",
-					tr("Select Image File"));
+  filename=QFileDialog::getOpenFileName(this,"RDAdmin - "+
+					tr("Select Image File"),filename,
+					RD_IMAGE_FILE_FILTER);
   if(!filename.isNull()) {
     air_skin_edit->setText(filename);
   }
