@@ -2,7 +2,7 @@
 //
 // Edit an RDLogedit Configuration
 //
-//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,31 +18,23 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qstring.h>
 #include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qlabel.h>
-#include <qpainter.h>
-#include <qevent.h>
 #include <qmessagebox.h>
-#include <qcheckbox.h>
-#include <qbuttongroup.h>
-#include <qsqldatabase.h>
 
 #include <rd.h>
-
-#include <globals.h>
-#include <edit_rdlogedit.h>
-#include <rdtextvalidator.h>
+#include <rdapplication.h>
 #include <rdcart_dialog.h>
+#include <rdtextvalidator.h>
 
+#include "edit_rdlogedit.h"
+#include "globals.h"
 
 EditRDLogedit::EditRDLogedit(RDStation *station,RDStation *cae_station,
 			     QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   //
   // Fix the Window Size
   //
@@ -53,132 +45,134 @@ EditRDLogedit::EditRDLogedit(RDStation *station,RDStation *cae_station,
 
   lib_lib=new RDLogeditConf(station->name());
 
-  //
-  // Create Fonts
-  //
-  QFont small_font=QFont("Helvetica",12,QFont::Bold);
-  small_font.setPixelSize(12);
-  QFont big_font=QFont("Helvetica",14,QFont::Bold);
-  big_font.setPixelSize(14);
-
   //
   // Dialog Name
   //
-  setCaption(tr("Configure RDLogedit"));
+  setWindowTitle("RDAdmin - "+tr("Configure RDLogedit"));
 
   //
   // Input Configuration
   //
   lib_input_card=new RDCardSelector(this);
-  lib_input_card->setGeometry(10,29,120,117);
-  QLabel *label=new QLabel(lib_input_card,tr("INPUT"),this);
-  label->setGeometry(10,10,110,19);
-  label->setFont(big_font);
-  label->setAlignment(AlignCenter);
+  lib_input_card->setGeometry(sizeHint().width()/5,29,120,117);
+  QLabel *label=new QLabel(lib_input_card,tr("Input"),this);
+  label->setGeometry(sizeHint().width()/5,10,120,19);
+  label->setFont(sectionLabelFont());
+  label->setAlignment(Qt::AlignCenter|Qt::AlignVCenter);
 
   //
   // Output Configuration
   //
   lib_output_card=new RDCardSelector(this);
-  lib_output_card->setGeometry(170,29,120,87);
-  label=new QLabel(lib_output_card,tr("OUTPUT"),this);
-  label->setGeometry(170,10,110,19);
-  label->setFont(big_font);
-  label->setAlignment(AlignCenter);
+  lib_output_card->setGeometry(4*sizeHint().width()/5-120,29,120,87);
+  label=new QLabel(lib_output_card,tr("Output"),this);
+  label->setGeometry(4*sizeHint().width()/5-120,10,120,19);
+  label->setFont(sectionLabelFont());
+  label->setAlignment(Qt::AlignCenter);
 
   //
   // Settings
   //
   QLabel *setting_label=new QLabel(tr("Voice Tracker Settings"),this);
-  setting_label->setGeometry(70,79,sizeHint().width()-80,19);
-  setting_label->setFont(big_font);
-  setting_label->setAlignment(AlignLeft|ShowPrefix);
+  setting_label->setGeometry(70,80,sizeHint().width()-80,19);
+  setting_label->setFont(sectionLabelFont());
+  setting_label->setAlignment(Qt::AlignLeft);
 
   //
   // Maximum Record Length
   //
-  lib_maxlength_time=new QTimeEdit(this);
-  lib_maxlength_time->setGeometry(160,100,85,19);
+  lib_maxlength_time=new Q3TimeEdit(this);
+  lib_maxlength_time->setGeometry(180,100,85,19);
   QLabel *lib_maxlength_label=
     new QLabel(lib_maxlength_time,tr("&Max Record Time:"),this);
-  lib_maxlength_label->setGeometry(25,101,130,19);
-  lib_maxlength_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  lib_maxlength_label->setFont(labelFont());
+  lib_maxlength_label->setGeometry(25,101,150,19);
+  lib_maxlength_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Autotrim Level
   //
   lib_threshold_spin=new QSpinBox(this);
-  lib_threshold_spin->setGeometry(160,124,50,19);
+  lib_threshold_spin->setGeometry(180,124,50,19);
   lib_threshold_spin->setMinValue(-99);
   lib_threshold_spin->setMaxValue(0);
   label=new QLabel(lib_threshold_spin,tr("&AutoTrim Threshold:"),this);
-  label->setGeometry(25,124,130,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setGeometry(25,124,150,19);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   label=new QLabel(tr("dbFS"),this);
-  label->setGeometry(215,124,120,19);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setGeometry(235,124,120,19);
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Normalization Level
   //
   lib_normalization_spin=new QSpinBox(this);
-  lib_normalization_spin->setGeometry(160,148,50,19);
+  lib_normalization_spin->setGeometry(180,148,50,19);
   lib_normalization_spin->setMinValue(-99);
   lib_normalization_spin->setMaxValue(0);
   label=new QLabel(lib_normalization_spin,tr("&Normalization Level:"),this);
-  label->setGeometry(25,148,130,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setGeometry(25,148,150,19);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   label=new QLabel(tr("dbFS"),this);
-  label->setGeometry(215,148,120,19);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setGeometry(235,148,120,19);
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Audio Margin
   //
   lib_preroll_spin=new QSpinBox(this);
-  lib_preroll_spin->setGeometry(160,172,60,19);
+  lib_preroll_spin->setGeometry(180,172,60,19);
   lib_preroll_spin->setMinValue(0);
   lib_preroll_spin->setMaxValue(10000);
   lib_preroll_spin->setLineStep(100);
   QLabel *lib_preroll_spin_label=
     new QLabel(lib_preroll_spin,tr("&Audio Margin:"),this);
-  lib_preroll_spin_label->setGeometry(25,172,130,19);
-  lib_preroll_spin_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  lib_preroll_spin_label->setFont(labelFont());
+  lib_preroll_spin_label->setGeometry(25,172,150,19);
+  lib_preroll_spin_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   QLabel *lib_preroll_spin_unit=new QLabel(tr("milliseconds"),this);
-  lib_preroll_spin_unit->setGeometry(225,172,120,19);
-  lib_preroll_spin_unit->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  lib_preroll_spin_unit->setFont(labelFont());
+  lib_preroll_spin_unit->setGeometry(245,172,120,19);
+  lib_preroll_spin_unit->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Format
   //
   lib_format_box=new QComboBox(this);
-  lib_format_box->setGeometry(160,196,150,19);
+  lib_format_box->setGeometry(180,196,150,19);
   connect(lib_format_box,SIGNAL(activated(int)),this,SLOT(formatData(int)));
   QLabel *lib_format_label=new QLabel(lib_format_box,tr("&Format:"),this);
-  lib_format_label->setGeometry(25,196,130,19);
-  lib_format_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  lib_format_label->setFont(labelFont());
+  lib_format_label->setGeometry(25,196,150,19);
+  lib_format_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Bitrate
   //
   lib_bitrate_box=new QComboBox(this);
-  lib_bitrate_box->setGeometry(160,220,130,19);
+  lib_bitrate_box->setGeometry(180,220,130,19);
   QLabel *lib_bitrate_label=new QLabel(lib_bitrate_box,tr("&Bitrate:"),this);
-  lib_bitrate_label->setGeometry(25,220,130,19);
-  lib_bitrate_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  lib_bitrate_label->setFont(labelFont());
+  lib_bitrate_label->setGeometry(25,220,150,19);
+  lib_bitrate_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Enable Second Start Button
   //
   lib_enable_second_start_box=new QComboBox(this);
-  lib_enable_second_start_box->setGeometry(160,244,60,19);
+  lib_enable_second_start_box->setGeometry(180,244,60,19);
   lib_enable_second_start_box->insertItem(tr("No"));
   lib_enable_second_start_box->insertItem(tr("Yes"));
   QLabel *lib_enable_second_start_label=
    new QLabel(lib_enable_second_start_box,tr("Enable &2nd Start Button:"),this);
-  lib_enable_second_start_label->setGeometry(10,244,145,19);
+  lib_enable_second_start_label->setFont(labelFont());
+  lib_enable_second_start_label->setGeometry(10,244,165,19);
   lib_enable_second_start_label->
-    setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Validator
@@ -186,18 +180,32 @@ EditRDLogedit::EditRDLogedit(RDStation *station,RDStation *cae_station,
   QIntValidator *validator=new QIntValidator(this);
   validator->setRange(1,999999);
 
+  //
+  // Waveform Caption
+  //
+  lib_waveform_caption_edit=new QLineEdit(this);
+  lib_waveform_caption_edit->setGeometry(180,268,sizeHint().width()-190,19);
+  lib_waveform_caption_edit->setValidator(validator);
+  QLabel *lib_waveform_caption_label=
+    new QLabel(lib_waveform_caption_edit,tr("WaveForm Caption:"),this);
+  lib_waveform_caption_label->setFont(labelFont());
+  lib_waveform_caption_label->setGeometry(25,268,150,19);
+  lib_waveform_caption_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
+
   //
   // Play Start Cart
   //
   lib_startcart_edit=new QLineEdit(this);
-  lib_startcart_edit->setGeometry(160,268,70,19);
+  lib_startcart_edit->setGeometry(180,290,70,19);
   lib_startcart_edit->setValidator(validator);
   QLabel *lib_startcart_label=
     new QLabel(lib_startcart_edit,tr("Play &Start Cart:"),this);
-  lib_startcart_label->setGeometry(25,268,130,19);
-  lib_startcart_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  lib_startcart_label->setFont(labelFont());
+  lib_startcart_label->setGeometry(25,290,150,19);
+  lib_startcart_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   QPushButton *button=new QPushButton(this);
-  button->setGeometry(240,266,55,23);
+  button->setFont(subButtonFont());
+  button->setGeometry(260,288,55,23);
   button->setText(tr("Select"));
   connect(button,SIGNAL(clicked()),this,SLOT(selectStartData()));
 
@@ -205,14 +213,16 @@ EditRDLogedit::EditRDLogedit(RDStation *station,RDStation *cae_station,
   // Play End Cart
   //
   lib_endcart_edit=new QLineEdit(this);
-  lib_endcart_edit->setGeometry(160,292,70,19);
+  lib_endcart_edit->setGeometry(180,314,70,19);
   lib_endcart_edit->setValidator(validator);
   QLabel *lib_endcart_label=
     new QLabel(lib_endcart_edit,tr("Play &End Cart:"),this);
-  lib_endcart_label->setGeometry(25,292,130,19);
-  lib_endcart_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  lib_endcart_label->setFont(labelFont());
+  lib_endcart_label->setGeometry(25,314,150,19);
+  lib_endcart_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   button=new QPushButton(this);
-  button->setGeometry(240,290,55,23);
+  button->setFont(subButtonFont());
+  button->setGeometry(260,310,55,23);
   button->setText(tr("Select"));
   connect(button,SIGNAL(clicked()),this,SLOT(selectEndData()));
 
@@ -220,14 +230,16 @@ EditRDLogedit::EditRDLogedit(RDStation *station,RDStation *cae_station,
   // Record Start Cart
   //
   lib_recstartcart_edit=new QLineEdit(this);
-  lib_recstartcart_edit->setGeometry(160,316,70,19);
+  lib_recstartcart_edit->setGeometry(180,338,70,19);
   lib_recstartcart_edit->setValidator(validator);
   QLabel *lib_recstartcart_label=
     new QLabel(lib_recstartcart_edit,tr("&Record Start Cart:"),this);
-  lib_recstartcart_label->setGeometry(25,316,130,19);
-  lib_recstartcart_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  lib_recstartcart_label->setFont(labelFont());
+  lib_recstartcart_label->setGeometry(25,338,150,19);
+  lib_recstartcart_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   button=new QPushButton(this);
-  button->setGeometry(240,314,55,23);
+  button->setFont(subButtonFont());
+  button->setGeometry(260,336,55,23);
   button->setText(tr("Select"));
   connect(button,SIGNAL(clicked()),this,SLOT(selectRecordStartData()));
 
@@ -235,14 +247,16 @@ EditRDLogedit::EditRDLogedit(RDStation *station,RDStation *cae_station,
   // Record End Cart
   //
   lib_recendcart_edit=new QLineEdit(this);
-  lib_recendcart_edit->setGeometry(160,340,70,19);
+  lib_recendcart_edit->setGeometry(180,362,70,19);
   lib_recendcart_edit->setValidator(validator);
   QLabel *lib_recendcart_label=
     new QLabel(lib_recendcart_edit,tr("Re&cord End Cart:"),this);
-  lib_recendcart_label->setGeometry(25,340,130,19);
-  lib_recendcart_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  lib_recendcart_label->setFont(labelFont());
+  lib_recendcart_label->setGeometry(25,362,150,19);
+  lib_recendcart_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   button=new QPushButton(this);
-  button->setGeometry(240,338,55,23);
+  button->setFont(subButtonFont());
+  button->setGeometry(260,360,55,23);
   button->setText(tr("Select"));
   connect(button,SIGNAL(clicked()),this,SLOT(selectRecordEndData()));
 
@@ -250,21 +264,23 @@ EditRDLogedit::EditRDLogedit(RDStation *station,RDStation *cae_station,
   // Default Channels
   //
   lib_channels_box=new QComboBox(this);
-  lib_channels_box->setGeometry(160,364,60,19);
+  lib_channels_box->setGeometry(180,386,60,19);
   QLabel *lib_channels_label=new QLabel(lib_channels_box,tr("&Channels:"),this);
-  lib_channels_label->setGeometry(25,364,130,19);
-  lib_channels_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  lib_channels_label->setFont(labelFont());
+  lib_channels_label->setGeometry(25,386,150,19);
+  lib_channels_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Default Transition Type
   //
   lib_default_transtype_box=new QComboBox(this);
-  lib_default_transtype_box->setGeometry(160,388,100,19);
+  lib_default_transtype_box->setGeometry(180,410,100,19);
   QLabel *lib_default_transtype_label=
     new QLabel(lib_default_transtype_box,tr("Default Transition:"),this);
-  lib_default_transtype_label->setGeometry(20,388,130,19);
+  lib_default_transtype_label->setFont(labelFont());
+  lib_default_transtype_label->setGeometry(25,410,150,19);
   lib_default_transtype_label->
-    setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   lib_default_transtype_box->insertItem(tr("Play"));
   lib_default_transtype_box->insertItem(tr("Segue"));
   lib_default_transtype_box->insertItem(tr("Stop"));
@@ -275,7 +291,7 @@ EditRDLogedit::EditRDLogedit(RDStation *station,RDStation *cae_station,
   QPushButton *ok_button=new QPushButton(this);
   ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   ok_button->setDefault(true);
-  ok_button->setFont(small_font);
+  ok_button->setFont(buttonFont());
   ok_button->setText(tr("&OK"));
   connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -285,7 +301,7 @@ EditRDLogedit::EditRDLogedit(RDStation *station,RDStation *cae_station,
   QPushButton *cancel_button=new QPushButton(this);
   cancel_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
 			     80,50);
-  cancel_button->setFont(small_font);
+  cancel_button->setFont(buttonFont());
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
@@ -313,6 +329,7 @@ EditRDLogedit::EditRDLogedit(RDStation *station,RDStation *cae_station,
   lib_maxlength_time->setTime(QTime().addMSecs(lib_lib->maxLength()));
   lib_threshold_spin->setValue(lib_lib->trimThreshold()/100);
   lib_normalization_spin->setValue(lib_lib->ripperLevel()/100);
+  lib_waveform_caption_edit->setText(lib_lib->waveformCaption());
   unsigned cart=lib_lib->startCart();
   if(cart>0) {
     lib_startcart_edit->setText(QString().sprintf("%06u",cart));
@@ -367,7 +384,7 @@ EditRDLogedit::~EditRDLogedit()
 
 QSize EditRDLogedit::sizeHint() const
 {
-  return QSize(375,478);
+  return QSize(395,500);
 } 
 
 
@@ -388,7 +405,7 @@ void EditRDLogedit::selectStartData()
   int cartnum=lib_startcart_edit->text().toInt();
 
   if(admin_cart_dialog->exec(&cartnum,RDCart::Macro,NULL,0,
-			     admin_user->name(),admin_user->password())==0) {
+			     rda->user()->name(),rda->user()->password())==0) {
     lib_startcart_edit->setText(QString().sprintf("%d",cartnum));
   }
 }
@@ -398,7 +415,7 @@ void EditRDLogedit::selectEndData()
 {
   int cartnum=lib_endcart_edit->text().toInt();
   if(admin_cart_dialog->exec(&cartnum,RDCart::Macro,NULL,0,
-			     admin_user->name(),admin_user->password())==0) {
+			     rda->user()->name(),rda->user()->password())==0) {
     lib_endcart_edit->setText(QString().sprintf("%d",cartnum));
   }
 }
@@ -408,7 +425,7 @@ void EditRDLogedit::selectRecordStartData()
 {
   int cartnum=lib_recstartcart_edit->text().toInt();
   if(admin_cart_dialog->exec(&cartnum,RDCart::Macro,NULL,0,
-			     admin_user->name(),admin_user->password())==0) {
+			     rda->user()->name(),rda->user()->password())==0) {
     lib_recstartcart_edit->setText(QString().sprintf("%d",cartnum));
   }
 }
@@ -418,7 +435,7 @@ void EditRDLogedit::selectRecordEndData()
 {
   int cartnum=lib_recendcart_edit->text().toInt();
   if(admin_cart_dialog->exec(&cartnum,RDCart::Macro,NULL,0,
-			     admin_user->name(),admin_user->password())==0) {
+			     rda->user()->name(),rda->user()->password())==0) {
     lib_recendcart_edit->setText(QString().sprintf("%d",cartnum));
   }
 }
@@ -436,6 +453,7 @@ void EditRDLogedit::okData()
   lib_lib->setTrimThreshold(lib_threshold_spin->value()*100);
   lib_lib->setRipperLevel(lib_normalization_spin->value()*100);
   lib_lib->setTailPreroll(lib_preroll_spin->value());
+  lib_lib->setWaveformCaption(lib_waveform_caption_edit->text());
   if(lib_startcart_edit->text().isEmpty()) {
     lib_lib->setStartCart(0);
   }
