@@ -2,7 +2,7 @@
 //
 // Edit Rivendell User/Group Permissions
 //
-//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,26 +18,18 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qstring.h>
 #include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qlabel.h>
-#include <qpainter.h>
-#include <qevent.h>
-#include <qmessagebox.h>
-#include <qcheckbox.h>
-#include <qbuttongroup.h>
 
 #include <rddb.h>
-#include <edit_user_perms.h>
-#include <rduser.h>
-#include <rdpasswd.h>
+#include <rdescape_string.h>
+
+#include "edit_user_perms.h"
 
 EditUserPerms::EditUserPerms(RDUser *user,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   QString sql;
   RDSqlQuery *q;
 
@@ -46,18 +38,10 @@ EditUserPerms::EditUserPerms(RDUser *user,QWidget *parent)
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
-  setCaption(tr("User: ")+user_user->name());
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
+  setWindowTitle("RDAdmin - "+tr("User: ")+user_user->name());
 
   //
   // Groups Selector
@@ -73,7 +57,7 @@ EditUserPerms::EditUserPerms(RDUser *user,QWidget *parent)
   QPushButton *ok_button=new QPushButton(this);
   ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   ok_button->setDefault(true);
-  ok_button->setFont(font);
+  ok_button->setFont(buttonFont());
   ok_button->setText(tr("&OK"));
   connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -83,23 +67,22 @@ EditUserPerms::EditUserPerms(RDUser *user,QWidget *parent)
   QPushButton *cancel_button=new QPushButton(this);
   cancel_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
 			     80,50);
-  cancel_button->setFont(font);
+  cancel_button->setFont(buttonFont());
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
   //
   // Populate Fields
   //
-  sql=QString().sprintf("select GROUP_NAME from USER_PERMS \
-                         where USER_NAME=\"%s\"",
-			(const char *)user_user->name());
+  sql=QString("select GROUP_NAME from USER_PERMS where ")+
+    "USER_NAME=\""+RDEscapeString(user_user->name())+"\"";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     user_host_sel->destInsertItem(q->value(0).toString());
   }
   delete q;
 
-  sql=QString().sprintf("select NAME from GROUPS");
+  sql=QString("select NAME from GROUPS");
   q=new RDSqlQuery(sql);
   while(q->next()) {
     if(user_host_sel->destFindItem(q->value(0).toString())==0) {
@@ -136,18 +119,15 @@ void EditUserPerms::okData()
   // Add New Groups
   //
   for(unsigned i=0;i<user_host_sel->destCount();i++) {
-    sql=QString().sprintf("select GROUP_NAME from USER_PERMS \
-                           where USER_NAME=\"%s\" && GROUP_NAME=\"%s\"",
-			  (const char *)user_user->name(),
-			  (const char *)user_host_sel->destText(i));
+    sql=QString("select GROUP_NAME from USER_PERMS where ")+
+      "USER_NAME=\""+RDEscapeString(user_user->name())+"\" && "
+      "GROUP_NAME=\""+RDEscapeString(user_host_sel->destText(i))+"\"";
     q=new RDSqlQuery(sql);
     if(q->size()==0) {
       delete q;
-      sql=QString().
-	sprintf("insert into USER_PERMS (USER_NAME,GROUP_NAME) \
-                 values (\"%s\",\"%s\")",
-		(const char *)user_user->name(),
-		(const char *)user_host_sel->destText(i));
+      sql=QString("insert into USER_PERMS (USER_NAME,GROUP_NAME) ")+
+	"values (\""+RDEscapeString(user_user->name())+
+	"\",\""+RDEscapeString(user_host_sel->destText(i))+"\")";
       q=new RDSqlQuery(sql);
     }
     delete q;
@@ -156,11 +136,11 @@ void EditUserPerms::okData()
   //
   // Delete Old Groups
   //
-  sql=QString().sprintf("delete from USER_PERMS where USER_NAME=\"%s\"",
-			(const char *)user_user->name());
+  sql=QString("delete from USER_PERMS where ")+
+    "USER_NAME=\""+RDEscapeString(user_user->name())+"\"";
   for(unsigned i=0;i<user_host_sel->destCount();i++) {
-    sql+=QString().sprintf(" && GROUP_NAME<>\"%s\"",
-			   (const char *)user_host_sel->destText(i));
+    sql+=QString(" && GROUP_NAME<>\"")+
+      RDEscapeString(user_host_sel->destText(i))+"\"";
   }
   q=new RDSqlQuery(sql);
   delete q;
