@@ -2,7 +2,7 @@
 //
 // List Rivendell Dropboxes
 //
-//   (C) Copyright 2002,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,25 +18,18 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qlabel.h>
-#include <qpainter.h>
-#include <qevent.h>
-#include <qmessagebox.h>
-#include <qbuttongroup.h>
-
-#include <rddb.h>
-#include <list_dropboxes.h>
-#include <edit_dropbox.h>
+#include <rdapplication.h>
+#include <rdescape_string.h>
+#include <rdnotification.h>
 
+#include "edit_dropbox.h"
+#include "list_dropboxes.h"
 
 ListDropboxes::ListDropboxes(const QString &stationname,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   list_stationname=stationname;
 
   //
@@ -45,24 +38,14 @@ ListDropboxes::ListDropboxes(const QString &stationname,QWidget *parent)
   setMinimumWidth(sizeHint().width());
   setMinimumHeight(sizeHint().height());
 
-  setCaption(QString().sprintf("Rivendell Dropbox Configurations on %s",
-			       (const char *)stationname));
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-  QFont list_font=QFont("Helvetica",12,QFont::Normal);
-  list_font.setPixelSize(12);
-  QFont small_font=QFont("Helvetica",10,QFont::Normal);
-  small_font.setPixelSize(10);
+  setWindowTitle("RDAdmin - "+tr("Rivendell Dropbox Configurations on")+" "+
+		 stationname);
 
   //
   //  Add Button
   //
   list_add_button=new QPushButton(this);
-  list_add_button->setFont(font);
+  list_add_button->setFont(buttonFont());
   list_add_button->setText(tr("&Add"));
   connect(list_add_button,SIGNAL(clicked()),this,SLOT(addData()));
 
@@ -70,15 +53,23 @@ ListDropboxes::ListDropboxes(const QString &stationname,QWidget *parent)
   //  Edit Button
   //
   list_edit_button=new QPushButton(this);
-  list_edit_button->setFont(font);
+  list_edit_button->setFont(buttonFont());
   list_edit_button->setText(tr("&Edit"));
   connect(list_edit_button,SIGNAL(clicked()),this,SLOT(editData()));
 
+  //
+  //  Duplicate Button
+  //
+  list_duplicate_button=new QPushButton(this);
+  list_duplicate_button->setFont(buttonFont());
+  list_duplicate_button->setText(tr("D&uplicate"));
+  connect(list_duplicate_button,SIGNAL(clicked()),this,SLOT(duplicateData()));
+
   //
   //  Delete Button
   //
   list_delete_button=new QPushButton(this);
-  list_delete_button->setFont(font);
+  list_delete_button->setFont(buttonFont());
   list_delete_button->setText(tr("&Delete"));
   connect(list_delete_button,SIGNAL(clicked()),this,SLOT(deleteData()));
 
@@ -87,7 +78,7 @@ ListDropboxes::ListDropboxes(const QString &stationname,QWidget *parent)
   //
   list_close_button=new QPushButton(this);
   list_close_button->setDefault(true);
-  list_close_button->setFont(font);
+  list_close_button->setFont(buttonFont());
   list_close_button->setText(tr("&Close"));
   connect(list_close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
@@ -95,8 +86,9 @@ ListDropboxes::ListDropboxes(const QString &stationname,QWidget *parent)
   // Group List
   //
   list_dropboxes_view=new RDListView(this);
-  list_dropboxes_view->setFont(list_font);
   list_dropboxes_view->setAllColumnsShowFocus(true);
+  list_dropboxes_view->addColumn(tr("ID"));
+  list_dropboxes_view->setColumnAlignment(0,Qt::AlignVCenter|Qt::AlignRight);
   list_dropboxes_view->addColumn(tr("Group"));
   list_dropboxes_view->setColumnAlignment(0,Qt::AlignVCenter|Qt::AlignLeft);
   list_dropboxes_view->addColumn(tr("Path"));
@@ -118,9 +110,9 @@ ListDropboxes::ListDropboxes(const QString &stationname,QWidget *parent)
   list_dropboxes_view->addColumn(tr("User Defined"));
   list_dropboxes_view->setColumnAlignment(9,Qt::AlignVCenter|Qt::AlignLeft);
   connect(list_dropboxes_view,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
 	  this,
-	  SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
+	  SLOT(doubleClickedData(Q3ListViewItem *,const QPoint &,int)));
 
   RefreshList();
 }
@@ -148,8 +140,15 @@ void ListDropboxes::addData()
   RDDropbox *box=new RDDropbox(-1,list_stationname);
   int id=box->id();
   delete box;
-  EditDropbox *edit_dropbox=new EditDropbox(id,this);
-  if(edit_dropbox->exec()<0) {
+  EditDropbox *edit_dropbox=new EditDropbox(id,false,this);
+  if(edit_dropbox->exec()) {
+    RDNotification *notify=new RDNotification(RDNotification::DropboxType,
+					      RDNotification::AddAction,
+					      list_stationname);
+    rda->ripc()->sendNotification(*notify);
+    delete notify;
+  }
+  else {
     QString sql=QString().sprintf("delete from DROPBOXES where ID=%d",id);
     RDSqlQuery *q=new RDSqlQuery(sql);
     delete q;
@@ -171,13 +170,54 @@ void ListDropboxes::editData()
   if(item==NULL) {
     return;
   }
-  EditDropbox *edit_dropbox=new EditDropbox(item->id(),this);
-  edit_dropbox->exec();
+  EditDropbox *edit_dropbox=new EditDropbox(item->id(),false,this);
+  if(edit_dropbox->exec()) {
+    RDNotification *notify=new RDNotification(RDNotification::DropboxType,
+					      RDNotification::ModifyAction,
+					      list_stationname);
+    rda->ripc()->sendNotification(*notify);
+    delete notify;
+  }
   delete edit_dropbox;
   RefreshItem(item);
 }
 
 
+void ListDropboxes::duplicateData()
+{
+  RDListViewItem *item=(RDListViewItem *)list_dropboxes_view->selectedItem();
+  if(item==NULL) {
+    return;
+  }
+
+  RDDropbox *src_box=new RDDropbox(item->id(),list_stationname);
+  int new_box_id=src_box->duplicate();
+  delete src_box;
+
+  EditDropbox *edit_dropbox=new EditDropbox(new_box_id,true,this);
+  if(edit_dropbox->exec()) {
+    RDNotification *notify=new RDNotification(RDNotification::DropboxType,
+					      RDNotification::AddAction,
+					      list_stationname);
+    rda->ripc()->sendNotification(*notify);
+    delete notify;
+  }
+  else {
+    QString sql=QString().sprintf("delete from DROPBOXES where ID=%d",new_box_id);
+    RDSqlQuery *q=new RDSqlQuery(sql);
+    delete q;
+    delete edit_dropbox;
+    return;
+  }
+  item=new RDListViewItem(list_dropboxes_view);
+  item->setId(new_box_id);
+  RefreshItem(item);
+  item->setSelected(true);
+  list_dropboxes_view->setCurrentItem(item);
+  list_dropboxes_view->ensureItemVisible(item);
+}
+
+
 void ListDropboxes::deleteData()
 {
   QString sql;
@@ -194,11 +234,18 @@ void ListDropboxes::deleteData()
   sql=QString().sprintf("delete from DROPBOXES where ID=%d",item->id());
   q=new RDSqlQuery(sql);
   delete q;
+
+  RDNotification *notify=new RDNotification(RDNotification::DropboxType,
+					    RDNotification::DeleteAction,
+					    list_stationname);
+  rda->ripc()->sendNotification(*notify);
+  delete notify;
+
   delete item;
 }
 
 
-void ListDropboxes::doubleClickedData(QListViewItem *item,const QPoint &pt,
+void ListDropboxes::doubleClickedData(Q3ListViewItem *item,const QPoint &pt,
 				   int col)
 {
   editData();
@@ -215,7 +262,8 @@ void ListDropboxes::resizeEvent(QResizeEvent *e)
 {
   list_add_button->setGeometry(size().width()-90,10,80,50);
   list_edit_button->setGeometry(size().width()-90,70,80,50);
-  list_delete_button->setGeometry(size().width()-90,130,80,50);
+  list_duplicate_button->setGeometry(size().width()-90,130,80,50);
+  list_delete_button->setGeometry(size().width()-90,190,80,50);
   list_close_button->setGeometry(size().width()-90,size().height()-60,80,50);
   list_dropboxes_view->
     setGeometry(10,10,size().width()-120,size().height()-40);
@@ -229,17 +277,22 @@ void ListDropboxes::RefreshList()
   RDListViewItem *item;
 
   list_dropboxes_view->clear();
-  sql=QString().sprintf("select DROPBOXES.ID,DROPBOXES.GROUP_NAME,\
-                         DROPBOXES.PATH,DROPBOXES.NORMALIZATION_LEVEL,\
-                         DROPBOXES.AUTOTRIM_LEVEL,\
-                         DROPBOXES.TO_CART,DROPBOXES.USE_CARTCHUNK_ID,\
-                         DROPBOXES.DELETE_CUTS,DROPBOXES.METADATA_PATTERN,\
-                         DROPBOXES.FIX_BROKEN_FORMATS,\
-                         DROPBOXES.SET_USER_DEFINED,GROUPS.COLOR \
-                         from DROPBOXES left join GROUPS on \
-                         DROPBOXES.GROUP_NAME=GROUPS.NAME \
-                         where DROPBOXES.STATION_NAME=\"%s\"",
-			(const char *)list_stationname);
+  sql=QString("select ")+
+    "DROPBOXES.ID,"+                   // 00
+    "DROPBOXES.GROUP_NAME,"+           // 01
+    "DROPBOXES.PATH,"+                 // 02
+    "DROPBOXES.NORMALIZATION_LEVEL,"+  // 03
+    "DROPBOXES.AUTOTRIM_LEVEL,"+       // 04
+    "DROPBOXES.TO_CART,"+              // 05
+    "DROPBOXES.USE_CARTCHUNK_ID,"+     // 06
+    "DROPBOXES.DELETE_CUTS,"+          // 07
+    "DROPBOXES.METADATA_PATTERN,"+     // 08
+    "DROPBOXES.FIX_BROKEN_FORMATS,"+   // 09
+    "DROPBOXES.SET_USER_DEFINED,"+     // 10
+    "GROUPS.COLOR "+                   // 11
+    "from DROPBOXES left join GROUPS "+
+    "on DROPBOXES.GROUP_NAME=GROUPS.NAME where "+
+    "DROPBOXES.STATION_NAME=\""+RDEscapeString(list_stationname)+"\"";
   q=new RDSqlQuery(sql);
   while (q->next()) {
     item=new RDListViewItem(list_dropboxes_view);
@@ -254,16 +307,22 @@ void ListDropboxes::RefreshItem(RDListViewItem *item)
   QString sql;
   RDSqlQuery *q;
 
-  sql=QString().sprintf("select DROPBOXES.ID,DROPBOXES.GROUP_NAME,\
-                         DROPBOXES.PATH,DROPBOXES.NORMALIZATION_LEVEL,\
-                         DROPBOXES.AUTOTRIM_LEVEL,\
-                         DROPBOXES.TO_CART,DROPBOXES.USE_CARTCHUNK_ID,\
-                         DROPBOXES.DELETE_CUTS,DROPBOXES.METADATA_PATTERN,\
-                         DROPBOXES.FIX_BROKEN_FORMATS,\
-                         DROPBOXES.SET_USER_DEFINED,GROUPS.COLOR \
-                         from DROPBOXES left join GROUPS on \
-                         DROPBOXES.GROUP_NAME=GROUPS.NAME \
-                         where DROPBOXES.ID=%d",item->id());
+  sql=QString("select ")+
+    "DROPBOXES.ID,"+                   // 00
+    "DROPBOXES.GROUP_NAME,"+           // 01
+    "DROPBOXES.PATH,"+                 // 02
+    "DROPBOXES.NORMALIZATION_LEVEL,"+  // 03
+    "DROPBOXES.AUTOTRIM_LEVEL,"+       // 04
+    "DROPBOXES.TO_CART,"+              // 05
+    "DROPBOXES.USE_CARTCHUNK_ID,"+     // 06
+    "DROPBOXES.DELETE_CUTS,"+          // 07
+    "DROPBOXES.METADATA_PATTERN,"+     // 08
+    "DROPBOXES.FIX_BROKEN_FORMATS,"+   // 09
+    "DROPBOXES.SET_USER_DEFINED,"+     // 10
+    "GROUPS.COLOR "+                   // 11
+    "from DROPBOXES left join GROUPS on "+
+    "DROPBOXES.GROUP_NAME=GROUPS.NAME where "+
+    QString().sprintf("DROPBOXES.ID=%d",item->id());
   q=new RDSqlQuery(sql);
   if(q->next()) {
     WriteItem(item,q);
@@ -275,35 +334,36 @@ void ListDropboxes::RefreshItem(RDListViewItem *item)
 void ListDropboxes::WriteItem(RDListViewItem *item,RDSqlQuery *q)
 {
   item->setId(q->value(0).toInt());
-  item->setText(0,q->value(1).toString());
-  item->setTextColor(0,q->value(11).toString(),QFont::Bold);
-  item->setText(1,q->value(2).toString());
+  item->setText(0,QString().sprintf("%d",q->value(0).toInt()));
+  item->setText(1,q->value(1).toString());
+  item->setTextColor(1,q->value(11).toString(),QFont::Bold);
+  item->setText(2,q->value(2).toString());
   if(q->value(3).toInt()<0) {
-    item->setText(2,QString().sprintf("%d",q->value(3).toInt()/100));
-  }
-  else {
-    item->setText(2,tr("[off]"));
-  }
-  if(q->value(4).toInt()<0) {
-    item->setText(3,QString().sprintf("%d",q->value(4).toInt()/100));
+    item->setText(3,QString().sprintf("%d",q->value(3).toInt()/100));
   }
   else {
     item->setText(3,tr("[off]"));
   }
+  if(q->value(4).toInt()<0) {
+    item->setText(4,QString().sprintf("%d",q->value(4).toInt()/100));
+  }
+  else {
+    item->setText(4,tr("[off]"));
+  }
   if(q->value(5).toUInt()>0) {
-    item->setText(4,QString().sprintf("%06u",q->value(5).toUInt()));
+    item->setText(5,QString().sprintf("%06u",q->value(5).toUInt()));
   }
   else {
-    item->setText(4,tr("[auto]"));
+    item->setText(5,tr("[auto]"));
   }
-  item->setText(5,q->value(6).toString());
-  item->setText(6,q->value(7).toString());
+  item->setText(6,q->value(6).toString());
+  item->setText(7,q->value(7).toString());
   if(q->value(8).toString().isEmpty()) {
-    item->setText(7,tr("[none]"));
+    item->setText(8,tr("[none]"));
   }
   else {
-    item->setText(7,q->value(8).toString());
+    item->setText(8,q->value(8).toString());
   }
-  item->setText(8,q->value(9).toString());
-  item->setText(9,q->value(10).toString());
+  item->setText(9,q->value(9).toString());
+  item->setText(10,q->value(10).toString());
 }
