@@ -2,7 +2,7 @@
 //
 // List Rivendell Users
 //
-//   (C) Copyright 2002-2008,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,17 +21,14 @@
 #ifndef LIST_USERS_H
 #define LIST_USERS_H
 
-#include <qdialog.h>
 #include <qpixmap.h>
-#include <qradiobutton.h>
-#include <qsqldatabase.h>
 #include <qpushbutton.h>
-#include <qpixmap.h>
 
-#include <rdlistviewitem.h>
 #include <rddb.h>
+#include <rddialog.h>
+#include <rdlistviewitem.h>
 
-class ListUsers : public QDialog
+class ListUsers : public RDDialog
 {
   Q_OBJECT
  public:
@@ -44,7 +41,7 @@ class ListUsers : public QDialog
   void addData();
   void editData();
   void deleteData();
-  void doubleClickedData(QListViewItem *item,const QPoint &pt,int col);
+  void doubleClickedData(Q3ListViewItem *item,const QPoint &pt,int col);
   void closeData();
 
  protected:
