@@ -2,9 +2,7 @@
 //
 // Login widget for RDAdmin.
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: login.cpp,v 1.12 2007/09/14 14:06:27 fredg Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -27,21 +25,22 @@
 #include <qpushbutton.h>
 #include <qradiobutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
 #include <qlabel.h>
 #include <qpainter.h>
 #include <qevent.h>
 #include <qmessagebox.h>
-#include <qbuttongroup.h>
+#include <q3buttongroup.h>
 
 #include <rdtextvalidator.h>
 
 #include <login.h>
 
-
-Login::Login(QString *username,QString *password,QWidget *parent,
-	     const char *name)  : QDialog(parent,name,true)
+Login::Login(QString *username,QString *password,QWidget *parent)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   //
   // Fix the Window Size
   //
@@ -50,27 +49,21 @@ Login::Login(QString *username,QString *password,QWidget *parent,
   setMinimumHeight(sizeHint().height());
   setMaximumHeight(sizeHint().height());
 
-  setCaption(tr("Login"));
+  setWindowTitle("RDAdmin");
   login_name=username;
   login_password=password;
 
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-
   //
   // Text Validator
   //
-  RDTextValidator *validator=new RDTextValidator(this,"validator");
+  RDTextValidator *validator=new RDTextValidator(this);
 
   //
   // OK Button
   //
-  QPushButton *ok_button=new QPushButton(this,"ok_button");
+  QPushButton *ok_button=new QPushButton(this);
   ok_button->setGeometry(10,60,100,55);
-  ok_button->setFont(font);
+  ok_button->setFont(buttonFont());
   ok_button->setText(tr("&OK"));
   ok_button->setDefault(true);
   connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
@@ -78,40 +71,39 @@ Login::Login(QString *username,QString *password,QWidget *parent,
   //
   // CANCEL Button
   //
-  QPushButton *cancel_button=new QPushButton(this,"cancel_button");
+  QPushButton *cancel_button=new QPushButton(this);
   cancel_button->setGeometry(120,60,100,55);
-  cancel_button->setFont(font);
+  cancel_button->setFont(buttonFont());
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
   //
   // Login Name
   //
-  login_name_edit=new QLineEdit(this,"login_name_edit");
+  login_name_edit=new QLineEdit(this);
   login_name_edit->setGeometry(100,10,100,19);
   login_name_edit->setMaxLength(16);
   login_name_edit->setFocus();
   login_name_edit->setValidator(validator);
-  QLabel *login_name_label=new QLabel(login_name_edit,tr("User &Name:"),this,
-				       "login_name_label");
+  QLabel *login_name_label=new QLabel(login_name_edit,tr("User &Name:"),this);
+  login_name_label->setFont(labelFont());
   login_name_label->setGeometry(10,10,85,19);
-  login_name_label->setFont(font);
-  login_name_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  login_name_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Login Password
   //
-  login_password_edit=new QLineEdit(this,"login_password_edit");
+  login_password_edit=new QLineEdit(this);
   login_password_edit->setGeometry(100,31,100,19);
   login_password_edit->setMaxLength(16);
   login_password_edit->setEchoMode(QLineEdit::Password);
   login_password_edit->setValidator(validator);
-  QLabel *login_password_label=new QLabel(login_password_edit,tr("&Password:"),
-					  this,"login_password_label");
+  QLabel *login_password_label=
+    new QLabel(login_password_edit,tr("&Password:"),this);
   login_password_label->setGeometry(10,31,85,19);
-  login_password_label->setFont(font);
-  login_password_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-
+  login_password_label->setFont(labelFont());
+  login_password_label->
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 }
 
 
@@ -138,13 +130,13 @@ void Login::okData()
 {
   *login_name=login_name_edit->text();
   *login_password=login_password_edit->text();
-  done(0);
+  done(true);
 }
 
 
 void Login::cancelData()
 {
-  done(1);
+  done(false);
 }
 
 
