@@ -2,7 +2,7 @@
 //
 // The full log list for RDAirPlay
 //
-//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,21 +18,13 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qtimer.h>
-#include <qpixmap.h>
-#include <qpainter.h>
 #include <qmessagebox.h>
-#include <rddb.h>
-#include <rdconf.h>
-#include <rdlistviewitem.h>
-#include <rddebug.h>
-#include <rdlog.h>
-#include <rdcreate_log.h>
 
-#include <list_log.h>
-#include <button_log.h>
-#include <colors.h>
-#include <globals.h>
+#include <rdapplication.h>
+#include <rdconf.h>
+
+#include "colors.h"
+#include "list_log.h"
 
 #include "../icons/play.xpm"
 #include "../icons/rml5.xpm"
@@ -43,10 +35,9 @@
 #include "../icons/traffic.xpm"
 #include "../icons/music.xpm"
 
-
-ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
+ListLog::ListLog(RDLogPlay *log,RDCae *cae,int id,bool allow_pause,
 		 QWidget *parent)
-  : QWidget(parent)
+  : RDWidget(parent)
 {
   list_id=id;
   list_log=log;
@@ -60,19 +51,6 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   list_audition_head_playing=false;
   list_audition_tail_playing=false;
 
-  //
-  // Create Fonts
-  //
-  QFont list_font=QFont("Helvetica",12,QFont::Normal);
-  list_font.setPixelSize(12);
-  setFont(list_font);
-  QFont label_font=QFont("Helvetica",12,QFont::Bold);
-  label_font.setPixelSize(12);
-  QFont font=QFont("Helvetica",14,QFont::Bold);
-  font.setPixelSize(14);
-  QFont name_font=QFont("Helvetica",18,QFont::Bold);
-  name_font.setPixelSize(18);
-
   //
   // Create Icons
   //
@@ -159,13 +137,12 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   // Log List
   //
   list_log_list=new LibListView(this);
-  list_log_list->setFont(list_font);
   int y=0;
   int h=sizeHint().height()-60;
-  if(rdairplay_conf->showCounters()) {
+  if(rda->airplayConf()->showCounters()) {
     h-=60;
   }
-  if(rdairplay_conf->hourSelectorEnabled()) {
+  if(rda->airplayConf()->hourSelectorEnabled()) {
     y+=80;
     h-=80;
     list_hour_selector->setGeometry(0,0,sizeHint().width(),80);
@@ -173,50 +150,50 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   }
   list_log_list->setGeometry(0,y,sizeHint().width(),h);
   list_log_list->setAllColumnsShowFocus(true);
-  list_log_list->setSelectionMode(QListView::Extended);
+  list_log_list->setSelectionMode(Q3ListView::Extended);
   list_log_list->setItemMargin(5);
   list_log_list->addColumn("");
   list_log_list->setColumnAlignment(0,Qt::AlignHCenter);
-  list_log_list->addColumn(tr("EST TIME"));
+  list_log_list->addColumn(tr("Est. Time"));
   list_log_list->setColumnAlignment(1,Qt::AlignRight);
-  list_log_list->addColumn(tr("LEN"));
+  list_log_list->addColumn(tr("Len"));
   list_log_list->setColumnAlignment(2,Qt::AlignRight);
-  list_log_list->addColumn(tr("TRANS"));
+  list_log_list->addColumn(tr("Trans"));
   list_log_list->setColumnAlignment(3,Qt::AlignHCenter);
-  list_log_list->addColumn(tr("CART"));
+  list_log_list->addColumn(tr("Cart"));
   list_log_list->setColumnAlignment(4,Qt::AlignHCenter);
-  list_log_list->addColumn(tr("TITLE"));
+  list_log_list->addColumn(tr("Title"));
   list_log_list->setColumnAlignment(5,Qt::AlignLeft);
-  list_log_list->addColumn(tr("ARTIST"));
+  list_log_list->addColumn(tr("Artist"));
   list_log_list->setColumnAlignment(6,Qt::AlignLeft);
-  list_log_list->addColumn(tr("GROUP"));
+  list_log_list->addColumn(tr("Group"));
   list_log_list->setColumnAlignment(7,Qt::AlignHCenter);
-  list_log_list->addColumn(tr("TIME"));
+  list_log_list->addColumn(tr("Sch. Time"));
   list_log_list->setColumnAlignment(8,Qt::AlignHCenter);
-  list_log_list->addColumn(tr("ALBUM"));
+  list_log_list->addColumn(tr("Album"));
   list_log_list->setColumnAlignment(9,Qt::AlignLeft);
-  list_log_list->addColumn(tr("LABEL"));
+  list_log_list->addColumn(tr("Label"));
   list_log_list->setColumnAlignment(10,Qt::AlignLeft);
-  list_log_list->addColumn(tr("CLIENT"));
+  list_log_list->addColumn(tr("Client"));
   list_log_list->setColumnAlignment(11,Qt::AlignLeft);
-  list_log_list->addColumn(tr("AGENCY"));
+  list_log_list->addColumn(tr("Agency"));
   list_log_list->setColumnAlignment(12,Qt::AlignLeft);
-  list_log_list->addColumn(tr("MARKER"));
+  list_log_list->addColumn(tr("Marker"));
   list_log_list->setColumnAlignment(13,Qt::AlignHCenter);
-  list_log_list->addColumn(tr("LINE ID"));
+  list_log_list->addColumn(tr("Line ID"));
   list_log_list->setColumnAlignment(14,Qt::AlignHCenter);
-  list_log_list->addColumn(tr("COUNT"));
+  list_log_list->addColumn(tr("Count"));
   list_log_list->setColumnAlignment(15,Qt::AlignHCenter);
-  list_log_list->addColumn(tr("STATUS"));
+  list_log_list->addColumn(tr("Status"));
   list_log_list->setColumnAlignment(16,Qt::AlignHCenter);
   list_log_list->setHardSortColumn(15);
-  list_log_list->setFocusPolicy(QWidget::NoFocus);
+  list_log_list->setFocusPolicy(Qt::NoFocus);
   connect(list_log_list,SIGNAL(selectionChanged()),
 	  this,SLOT(selectionChangedData()));
   connect(list_log_list,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
 	  this,
-	  SLOT(doubleclickedData(QListViewItem *,const QPoint &,int)));
+	  SLOT(doubleclickedData(Q3ListViewItem *,const QPoint &,int)));
   connect(list_log_list,SIGNAL(cartDropped(int,RDLogLine *)),
 	  this,SLOT(cartDroppedData(int,RDLogLine *)));
 
@@ -228,13 +205,11 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   // Time Counter Section
   //
-  QLabel *label=new QLabel(tr("Run Length"),this);
-  label->setGeometry(372,sizeHint().height()-120,75,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignCenter);  
-  label->setBackgroundColor(QColor(system_mid_color));
-  if(!rdairplay_conf->showCounters()) {
-    label->hide();
+  QGroupBox *groupbox=new QGroupBox(tr("Run Length"),this);
+  groupbox->setFont(labelFont());
+  groupbox->setGeometry(336,sizeHint().height()-116,146,58);
+  if(!rda->airplayConf()->showCounters()) {
+    groupbox->hide();
   }
 
   //
@@ -244,10 +219,10 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   list_stoptime_edit->setGeometry(407,sizeHint().height()-100,70,18);
   list_stoptime_label=new QLabel(list_stoptime_edit,tr("Next Stop:"),this);
   list_stoptime_label->setGeometry(337,sizeHint().height()-100,65,18);
-  list_stoptime_label->setFont(label_font);
-  list_stoptime_label->setAlignment(AlignRight|AlignVCenter);  
+  list_stoptime_label->setFont(labelFont());
+  list_stoptime_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);  
   list_stoptime_label->setBackgroundColor(QColor(system_mid_color));
-  if(!rdairplay_conf->showCounters()) {
+  if(!rda->airplayConf()->showCounters()) {
     list_stoptime_edit->hide();
     list_stoptime_label->hide();
   }
@@ -259,10 +234,10 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   list_endtime_edit->setGeometry(407,sizeHint().height()-80,70,18);
   list_endtime_label=new QLabel(list_endtime_edit,tr("Log End:"),this);
   list_endtime_label->setGeometry(337,sizeHint().height()-80,65,18);
-  list_endtime_label->setFont(label_font);
-  list_endtime_label->setAlignment(AlignRight|AlignVCenter);  
+  list_endtime_label->setFont(labelFont());
+  list_endtime_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);  
   list_endtime_label->setBackgroundColor(QColor(system_mid_color));
-  if(!rdairplay_conf->showCounters()) {
+  if(!rda->airplayConf()->showCounters()) {
     list_endtime_edit->hide();
     list_endtime_label->hide();
   }
@@ -272,10 +247,10 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   list_take_button=new QPushButton(this);
   list_take_button->setGeometry(10,sizeHint().height()-55,80,50);
-  list_take_button->setFont(font);
+  list_take_button->setFont(bigButtonFont());
   list_take_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_take_button->setText(tr("Select"));
-  list_take_button->setFocusPolicy(QWidget::NoFocus);
+  list_take_button->setFocusPolicy(Qt::NoFocus);
   connect(list_take_button,SIGNAL(clicked()),this,SLOT(takeButtonData()));
   list_take_button->hide();
 
@@ -284,12 +259,12 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   list_head_button=new QPushButton(this);
   list_head_button->setGeometry(10,sizeHint().height()-113,80,50);
-  list_head_button->setFont(font);
+  list_head_button->setFont(bigButtonFont());
   list_head_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_head_button->setText(tr("Audition\nHead"));
-  list_head_button->setFocusPolicy(QWidget::NoFocus);
+  list_head_button->setFocusPolicy(Qt::NoFocus);
   connect(list_head_button,SIGNAL(clicked()),this,SLOT(headButtonData()));
-  if(!rdairplay_conf->showCounters()) {
+  if(!rda->airplayConf()->showCounters()) {
     list_head_button->hide();
   }
 
@@ -298,12 +273,12 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   list_tail_button=new QPushButton(this);
   list_tail_button->setGeometry(90,sizeHint().height()-113,80,50);
-  list_tail_button->setFont(font);
+  list_tail_button->setFont(bigButtonFont());
   list_tail_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_tail_button->setText(tr("Audition\nTail"));
-  list_tail_button->setFocusPolicy(QWidget::NoFocus);
+  list_tail_button->setFocusPolicy(Qt::NoFocus);
   connect(list_tail_button,SIGNAL(clicked()),this,SLOT(tailButtonData()));
-  if(!rdairplay_conf->showCounters()) {
+  if(!rda->airplayConf()->showCounters()) {
     list_tail_button->hide();
   }
 
@@ -312,11 +287,11 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   list_play_button=new QPushButton(this);
   list_play_button->setGeometry(10,sizeHint().height()-55,80,50);
-  list_play_button->setFont(font);
+  list_play_button->setFont(bigButtonFont());
   list_play_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_play_button->setText(tr("Start"));
   list_play_button->setDisabled(true);
-  list_play_button->setFocusPolicy(QWidget::NoFocus);
+  list_play_button->setFocusPolicy(Qt::NoFocus);
   connect(list_play_button,SIGNAL(clicked()),this,SLOT(playButtonData()));
 
   //
@@ -324,11 +299,11 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   list_next_button=new QPushButton(this);
   list_next_button->setGeometry(90,sizeHint().height()-55,80,50);
-  list_next_button->setFont(font);
+  list_next_button->setFont(bigButtonFont());
   list_next_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_next_button->setText(tr("Make\nNext"));
   list_next_button->setDisabled(true);
-  list_next_button->setFocusPolicy(QWidget::NoFocus);
+  list_next_button->setFocusPolicy(Qt::NoFocus);
   connect(list_next_button,SIGNAL(clicked()),this,SLOT(nextButtonData()));
 
   //
@@ -336,11 +311,11 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   list_modify_button=new QPushButton(this);
   list_modify_button->setGeometry(170,sizeHint().height()-55,80,50);
-  list_modify_button->setFont(font);
+  list_modify_button->setFont(bigButtonFont());
   list_modify_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_modify_button->setText(tr("Modify"));
   list_modify_button->setDisabled(true);
-  list_modify_button->setFocusPolicy(QWidget::NoFocus);
+  list_modify_button->setFocusPolicy(Qt::NoFocus);
   connect(list_modify_button,SIGNAL(clicked()),this,SLOT(modifyButtonData()));
 
   //
@@ -348,10 +323,10 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   list_scroll_button=new QPushButton(this);
   list_scroll_button->setGeometry(250,sizeHint().height()-55,80,50);
-  list_scroll_button->setFont(font);
+  list_scroll_button->setFont(bigButtonFont());
   list_scroll_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_scroll_button->setText(tr("Scroll"));
-  list_scroll_button->setFocusPolicy(QWidget::NoFocus);
+  list_scroll_button->setFocusPolicy(Qt::NoFocus);
   connect(list_scroll_button,SIGNAL(clicked()),this,SLOT(scrollButtonData()));
   list_scroll_button->setPalette(list_scroll_color[0]);
 
@@ -360,11 +335,11 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   //
   list_refresh_button=new QPushButton(this);
   list_refresh_button->setGeometry(330,sizeHint().height()-55,80,50);
-  list_refresh_button->setFont(font);
+  list_refresh_button->setFont(bigButtonFont());
   list_refresh_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_refresh_button->setText(tr("Refresh\nLog"));
   list_refresh_button->setDisabled(true);
-  list_refresh_button->setFocusPolicy(QWidget::NoFocus);
+  list_refresh_button->setFocusPolicy(Qt::NoFocus);
   connect(list_refresh_button,SIGNAL(clicked()),
 	  this,SLOT(refreshButtonData()));
 
@@ -374,10 +349,10 @@ ListLog::ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause,
   list_load_button=new QPushButton(this);
   list_load_button->setGeometry(sizeHint().width()-90,sizeHint().height()-55,
 				80,50);
-  list_load_button->setFont(font);
+  list_load_button->setFont(bigButtonFont());
   list_load_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_load_button->setText(tr("Select\nLog"));
-  list_load_button->setFocusPolicy(QWidget::NoFocus);
+  list_load_button->setFocusPolicy(Qt::NoFocus);
   connect(list_load_button,SIGNAL(clicked()),this,SLOT(loadButtonData()));
 
   //
@@ -474,104 +449,104 @@ void ListLog::setActionMode(RDAirPlayConf::ActionMode mode,int *cartnum)
     return;
   }
   switch(mode) {
-      case RDAirPlayConf::Normal:
-	list_log_list->setSelectionMode(QListView::Extended);
-	list_log_list->setPalette(palette());
-	list_take_button->hide();
-	list_play_button->show();
-	list_next_button->show();
-	list_modify_button->show();
-	list_scroll_button->show();
-	list_refresh_button->show();
-	list_load_button->show();
-	break;
+  case RDAirPlayConf::Normal:
+    list_log_list->setSelectionMode(Q3ListView::Extended);
+    list_log_list->setPalette(palette());
+    list_take_button->hide();
+    list_play_button->show();
+    list_next_button->show();
+    list_modify_button->show();
+    list_scroll_button->show();
+    list_refresh_button->show();
+    list_load_button->show();
+    break;
 
-      case RDAirPlayConf::AddTo:
-	list_log_list->setSelectionMode(QListView::Single);
-	list_log_list->setPalette(list_list_to_color);
-	list_take_button->setText(ADD_TO_MODE_TITLE);
-	list_take_button->setPalette(list_to_color);
-	list_take_button->show();
-	list_play_button->hide();
-	list_next_button->hide();
-	list_modify_button->hide();
-	list_scroll_button->hide();
-	list_refresh_button->hide();
-	list_load_button->hide();
-	break;
+  case RDAirPlayConf::AddTo:
+    list_log_list->setSelectionMode(Q3ListView::Single);
+    list_log_list->setPalette(list_list_to_color);
+    list_take_button->setText(ADD_TO_MODE_TITLE);
+    list_take_button->setPalette(list_to_color);
+    list_take_button->show();
+    list_play_button->hide();
+    list_next_button->hide();
+    list_modify_button->hide();
+    list_scroll_button->hide();
+    list_refresh_button->hide();
+    list_load_button->hide();
+    break;
 
-      case RDAirPlayConf::DeleteFrom:
-	list_log_list->setSelectionMode(QListView::Single);
-	list_log_list->setPalette(list_list_from_color);
-	list_take_button->setText(DELETE_FROM_MODE_TITLE);
-	list_take_button->setPalette(list_from_color);
-	list_take_button->show();
-	list_play_button->hide();
-	list_next_button->hide();
-	list_modify_button->hide();
-	list_scroll_button->hide();
-	list_refresh_button->hide();
-	list_load_button->hide();
-	break;
+  case RDAirPlayConf::DeleteFrom:
+    list_log_list->setSelectionMode(Q3ListView::Single);
+    list_log_list->setPalette(list_list_from_color);
+    list_take_button->setText(DELETE_FROM_MODE_TITLE);
+    list_take_button->setPalette(list_from_color);
+    list_take_button->show();
+    list_play_button->hide();
+    list_next_button->hide();
+    list_modify_button->hide();
+    list_scroll_button->hide();
+    list_refresh_button->hide();
+    list_load_button->hide();
+    break;
 
-      case RDAirPlayConf::MoveFrom:
-	list_log_list->setSelectionMode(QListView::Single);
-	list_log_list->setPalette(list_list_from_color);
-	list_take_button->setText(MOVE_FROM_MODE_TITLE);
-	list_take_button->setPalette(list_from_color);
-	list_take_button->show();
-	list_play_button->hide();
-	list_next_button->hide();
-	list_modify_button->hide();
-	list_scroll_button->hide();
-	list_refresh_button->hide();
-	list_load_button->hide();
-	break;
+  case RDAirPlayConf::MoveFrom:
+    list_log_list->setSelectionMode(Q3ListView::Single);
+    list_log_list->setPalette(list_list_from_color);
+    list_take_button->setText(MOVE_FROM_MODE_TITLE);
+    list_take_button->setPalette(list_from_color);
+    list_take_button->show();
+    list_play_button->hide();
+    list_next_button->hide();
+    list_modify_button->hide();
+    list_scroll_button->hide();
+    list_refresh_button->hide();
+    list_load_button->hide();
+    break;
 
-      case RDAirPlayConf::MoveTo:
-	list_log_list->setSelectionMode(QListView::Single);
-	list_log_list->setPalette(list_list_to_color);
-	list_take_button->setText(MOVE_TO_MODE_TITLE);
-	list_take_button->setPalette(list_to_color);
-	list_take_button->show();
-	list_play_button->hide();
-	list_next_button->hide();
-	list_modify_button->hide();
-	list_scroll_button->hide();
-	list_refresh_button->hide();
-	list_load_button->hide();
-	break;
+  case RDAirPlayConf::MoveTo:
+    list_log_list->setSelectionMode(Q3ListView::Single);
+    list_log_list->setPalette(list_list_to_color);
+    list_take_button->setText(MOVE_TO_MODE_TITLE);
+    list_take_button->setPalette(list_to_color);
+    list_take_button->show();
+    list_play_button->hide();
+    list_next_button->hide();
+    list_modify_button->hide();
+    list_scroll_button->hide();
+    list_refresh_button->hide();
+    list_load_button->hide();
+    break;
 
-      case RDAirPlayConf::CopyFrom:
-	list_log_list->setSelectionMode(QListView::Single);
-	list_log_list->setPalette(list_list_from_color);
-	list_take_button->setText(COPY_FROM_MODE_TITLE);
-	list_take_button->setPalette(list_from_color);
-	list_take_button->show();
-	list_play_button->hide();
-	list_next_button->hide();
-	list_modify_button->hide();
-	list_scroll_button->hide();
-	list_refresh_button->hide();
-	list_load_button->hide();
-	break;
+  case RDAirPlayConf::CopyFrom:
+    list_log_list->setSelectionMode(Q3ListView::Single);
+    list_log_list->setPalette(list_list_from_color);
+    list_take_button->setText(COPY_FROM_MODE_TITLE);
+    list_take_button->setPalette(list_from_color);
+    list_take_button->show();
+    list_play_button->hide();
+    list_next_button->hide();
+    list_modify_button->hide();
+    list_scroll_button->hide();
+    list_refresh_button->hide();
+    list_load_button->hide();
+    break;
 
-      case RDAirPlayConf::CopyTo:
-	list_log_list->setSelectionMode(QListView::Single);
-	list_log_list->setPalette(list_list_to_color);
-	list_take_button->setText(COPY_TO_MODE_TITLE);
-	list_take_button->setPalette(list_to_color);
-	list_take_button->show();
-	list_play_button->hide();
-	list_next_button->hide();
-	list_modify_button->hide();
-	list_scroll_button->hide();
-	list_refresh_button->hide();
-	list_load_button->hide();
-	break;
+  case RDAirPlayConf::CopyTo:
+    list_log_list->setSelectionMode(Q3ListView::Single);
+    list_log_list->setPalette(list_list_to_color);
+    list_take_button->setText(COPY_TO_MODE_TITLE);
+    list_take_button->setPalette(list_to_color);
+    list_take_button->show();
+    list_play_button->hide();
+    list_next_button->hide();
+    list_modify_button->hide();
+    list_scroll_button->hide();
+    list_refresh_button->hide();
+    list_load_button->hide();
+    break;
 
-      default:
-	break;
+  default:
+    break;
   }
   if(mode==RDAirPlayConf::Normal) {
     list_scroll=list_suspended_scroll;
@@ -626,75 +601,75 @@ void ListLog::takeButtonData()
 
   RDLogLine::Status status=CurrentStatus();
   switch(list_action_mode) {
-      case RDAirPlayConf::AddTo:
-      case RDAirPlayConf::MoveTo:
-      case RDAirPlayConf::CopyTo:
-	switch(status) {
-	    case RDLogLine::Finished:
-	    case RDLogLine::Playing:
-	    case RDLogLine::Paused:
-	    case RDLogLine::Finishing:
-	      return;
+  case RDAirPlayConf::AddTo:
+  case RDAirPlayConf::MoveTo:
+  case RDAirPlayConf::CopyTo:
+    switch(status) {
+    case RDLogLine::Finished:
+    case RDLogLine::Playing:
+    case RDLogLine::Paused:
+    case RDLogLine::Finishing:
+      return;
 	      
-	    default:
-	      line=list_log_list->currentItem()->text(15).toInt();
-	      break;
-	}
-	break;
+    default:
+      line=list_log_list->currentItem()->text(15).toInt();
+      break;
+    }
+    break;
 	  
-      case RDAirPlayConf::CopyFrom:
-	line=list_log_list->currentItem()->text(15).toInt();
-	if(list_log->logLine(line)!=NULL) {
-	  switch(list_log->logLine(line)->type()) {
-	      case RDLogLine::Marker:
-	      case RDLogLine::OpenBracket:
-	      case RDLogLine::CloseBracket:
-	      case RDLogLine::Chain:
-	      case RDLogLine::Track:
-	      case RDLogLine::MusicLink:
-	      case RDLogLine::TrafficLink:
-	      case RDLogLine::UnknownType:
-		return;
+  case RDAirPlayConf::CopyFrom:
+    line=list_log_list->currentItem()->text(15).toInt();
+    if(list_log->logLine(line)!=NULL) {
+      switch(list_log->logLine(line)->type()) {
+      case RDLogLine::Marker:
+      case RDLogLine::OpenBracket:
+      case RDLogLine::CloseBracket:
+      case RDLogLine::Chain:
+      case RDLogLine::Track:
+      case RDLogLine::MusicLink:
+      case RDLogLine::TrafficLink:
+      case RDLogLine::UnknownType:
+	return;
 		
-	      default:
-		break;
-	  }
-	}
-	break;
-
-      case RDAirPlayConf::MoveFrom:
-	switch(status) {
-	    case RDLogLine::Finished:
-	    case RDLogLine::Playing:
-	    case RDLogLine::Paused:
-	    case RDLogLine::Finishing:
-	      return;
-	      
-	    default:
-	      line=list_log_list->currentItem()->text(15).toInt();
-	      break;
-	}
-	break;
-
-      case RDAirPlayConf::DeleteFrom:
-	switch(status) {
-	    case RDLogLine::Finished:
-	    case RDLogLine::Playing:
-	    case RDLogLine::Finishing:
-	      return;
-	      
-	    default:
-	      line=list_log_list->currentItem()->text(15).toInt();
-              // Don't try delete "end of log" or other invalid log entries.
-              if (line<0) {
-                return;
-              }
-	      break;
-	}
-	break;
-
       default:
 	break;
+      }
+    }
+    break;
+
+  case RDAirPlayConf::MoveFrom:
+    switch(status) {
+    case RDLogLine::Finished:
+    case RDLogLine::Playing:
+    case RDLogLine::Paused:
+    case RDLogLine::Finishing:
+      return;
+	      
+    default:
+      line=list_log_list->currentItem()->text(15).toInt();
+      break;
+    }
+    break;
+
+  case RDAirPlayConf::DeleteFrom:
+    switch(status) {
+    case RDLogLine::Finished:
+    case RDLogLine::Playing:
+    case RDLogLine::Finishing:
+      return;
+	      
+    default:
+      line=list_log_list->currentItem()->text(15).toInt();
+      // Don't try delete "end of log" or other invalid log entries.
+      if (line<0) {
+	return;
+      }
+      break;
+    }
+    break;
+
+  default:
+    break;
   }
   emit selectClicked(list_id,line,status);
 }
@@ -757,34 +732,34 @@ void ListLog::playButtonData()
   }
 
   switch(list_playbutton_mode) {
-      case ListLog::ButtonPlay:
-	switch(CurrentStatus()) {
-	    case RDLogLine::Scheduled:
-	    case RDLogLine::Paused:
-	      if(line<0) {
-		return;
-	      }
-	      list_log->play(line,RDLogLine::StartManual);
-	      ClearSelection();
-	      break;
+  case ListLog::ButtonPlay:
+    switch(CurrentStatus()) {
+    case RDLogLine::Scheduled:
+    case RDLogLine::Paused:
+      if(line<0) {
+	return;
+      }
+      list_log->play(line,RDLogLine::StartManual);
+      ClearSelection();
+      break;
 	      
-	    default:
-	      break;
-	}
-	break;
+    default:
+      break;
+    }
+    break;
 
-      case ListLog::ButtonStop:
-	if(list_pause_allowed) {
-	  list_log->pause(line);
-	}
-	else {
-	  list_log->stop(line);
-	}
-	ClearSelection();
-	break;
+  case ListLog::ButtonStop:
+    if(list_pause_allowed) {
+      list_log->pause(line);
+    }
+    else {
+      list_log->stop(line);
+    }
+    ClearSelection();
+    break;
 
-      case ListLog::ButtonDisabled:
-	break;
+  case ListLog::ButtonDisabled:
+    break;
   }
 }
 
@@ -811,7 +786,7 @@ void ListLog::modifyButtonData()
 }
 
 
-void ListLog::doubleclickedData(QListViewItem *,const QPoint &,int)
+void ListLog::doubleclickedData(Q3ListViewItem *,const QPoint &,int)
 {
   modifyButtonData();
 }
@@ -852,61 +827,46 @@ void ListLog::nextButtonData()
 
 void ListLog::loadButtonData()
 {
-  QString name=list_log->logName().left(list_log->logName().length()-4);
+  QString name=list_log->logName();
   QString svcname=list_log->serviceName();
-
+  QString err_msg;
   RDLog *edit_log;
-  QString sql;
-  RDSqlQuery *q;
+  RDLogLock *log_lock=NULL;
 
-  switch(list_logs_dialog->exec(&name,&svcname)) {
-      case 0:
-	list_log->setLogName(RDLog::tableName(name));
-	list_log->load();
-	break;
+  switch((ListLogs::Operation)list_logs_dialog->exec(&name,&svcname,&log_lock)) {
+  case ListLogs::Load:
+    list_log->setLogName(name);
+    list_log->load();
+    break;
 
-      case 2:
-	list_log->save();
-	edit_log=new RDLog(list_log->logName().
-			   left(list_log->logName().length()-4));
-	delete edit_log;
-	break;
+  case ListLogs::Save:
+    list_log->save();
+    edit_log=
+      new RDLog(list_log->logName().left(list_log->logName().length()-4));
+    delete edit_log;
+    break;
+    
+  case ListLogs::SaveAs:
+    if(!RDLog::create(name,svcname,QDate(),rda->ripc()->user(),&err_msg,
+		      rda->config())) {
+      QMessageBox::warning(this,"RDAirPlay - "+tr("Error"),err_msg);
+      return;
+    }
+    list_log->setServiceName(svcname);
+    list_log->setLogName(name);
+    list_log->save();
+    break;
 
-      case 3:
-        sql=QString().sprintf("insert into LOGS set \
-                                       NAME=\"%s\",TYPE=0,\
-                                       DESCRIPTION=\"%s log\",\
-                                       ORIGIN_USER=\"%s\",\
-                                       ORIGIN_DATETIME=NOW(),\
-                                       LINK_DATETIME=NOW(),\
-                                       MODIFIED_DATETIME=NOW(),\
-                                       SERVICE=\"%s\"",
-			      (const char *)name,
-			      (const char *)name,
-			      (const char *)rdripc->user(),
-			      (const char *)svcname);
-	q=new RDSqlQuery(sql);
-	if(!q->isActive()) {
-	  QMessageBox::warning(this,tr("Log Exists"),
-			       tr("Log Already Exists!"));
-	  delete q;
-	  return;
-	}
-	delete q;
-	edit_log=new RDLog(name,true);
-	RDCreateLogTable(RDLog::tableName(name));
-	list_log->setServiceName(svcname);
-	list_log->setLogName(RDLog::tableName(name));
-	list_log->save();
-	edit_log->setModifiedDatetime(QDateTime(QDate::currentDate(),
-						QTime::currentTime()));
-	delete edit_log;
-	break;
+  case ListLogs::Unload:
+    list_log->clear();
+    break;
 
-      case -1:
-	list_log->clear();
-	break;
-  } 
+  case ListLogs::Cancel:
+    break;
+  }
+  if(log_lock!=NULL) {
+    delete log_lock;
+  }
 }
 
 
@@ -965,6 +925,7 @@ void ListLog::logInsertedData(int line)
       list_log_list->ensureItemVisible(item);
     }
   }
+  list_log_list->sort();
 }
 
 
@@ -984,6 +945,7 @@ void ListLog::logRemovedData(int line,int num,bool moving)
   if(!moving) {
     UpdateTimes(line,num);
   }
+  list_log_list->sort();
 }
 
 
@@ -1021,27 +983,27 @@ void ListLog::selectionChangedData()
     return;
   }  
   switch(CurrentStatus()) {
-      case RDLogLine::Scheduled:
-      case RDLogLine::Paused:
-	SetPlaybuttonMode(ListLog::ButtonPlay);
-	list_modify_button->setEnabled(true);
-	list_next_button->setEnabled(true);
-	break;
+  case RDLogLine::Scheduled:
+  case RDLogLine::Paused:
+    SetPlaybuttonMode(ListLog::ButtonPlay);
+    list_modify_button->setEnabled(true);
+    list_next_button->setEnabled(true);
+    break;
 
-      case RDLogLine::Playing:
-	SetPlaybuttonMode(ListLog::ButtonStop);
-	list_modify_button->setEnabled(true);
-	list_next_button->setDisabled(true);
-	break;
+  case RDLogLine::Playing:
+    SetPlaybuttonMode(ListLog::ButtonStop);
+    list_modify_button->setEnabled(true);
+    list_next_button->setDisabled(true);
+    break;
 
-      case RDLogLine::Finished:
-	SetPlaybuttonMode(ListLog::ButtonDisabled);
-	list_modify_button->setDisabled(true);
-	list_next_button->setDisabled(true);
-	break;
+  case RDLogLine::Finished:
+    SetPlaybuttonMode(ListLog::ButtonDisabled);
+    list_modify_button->setDisabled(true);
+    list_next_button->setDisabled(true);
+    break;
 
-      default:
-	break;
+  default:
+    break;
   }
   if(item->text(15).toInt()>=0) {
     list_endtime_edit->setText(RDGetTimeLength(list_log->
@@ -1099,29 +1061,6 @@ void ListLog::cartDroppedData(int line,RDLogLine *ll)
 }
 
 
-void ListLog::paintEvent(QPaintEvent *e)
-{
-  if(!rdairplay_conf->showCounters()) {
-    return;
-  }
-  int x=336;
-  int y=sizeHint().height()-111;
-
-  QPainter *p=new QPainter(this);
-  p->setPen(black);
-  p->setBrush(black);
-  p->moveTo(x,y);
-  p->lineTo(x+146,y);
-  p->lineTo(x+146,y+53);
-  p->lineTo(x,y+53);
-  p->lineTo(x,y);
-
-  p->end();
-  delete p;
-  
-}
-
-
 void ListLog::RefreshList()
 {
   RDListViewItem *l;
@@ -1164,66 +1103,69 @@ void ListLog::RefreshItem(RDListViewItem *l,int line)
     return;
   }
   switch(log_line->timeType()) {
-      case RDLogLine::Hard:
-	l->setText(1,QString("T")+
-		   TimeString(log_line->startTime(RDLogLine::Logged)));
-	l->setText(8,QString("T")+
-		   TimeString(log_line->startTime(RDLogLine::Logged)));
-	for(int i=0;i<list_log_list->columns();i++) {
-	  l->setTextColor(i,LOG_HARDTIME_TEXT_COLOR,QFont::Bold);
-	}
-	l->setText(14,"N");
-	break;
-      default:
-	if(!log_line->startTime(RDLogLine::Logged).isNull()) {
-	  l->setText(8,TimeString(log_line->startTime(RDLogLine::Logged)));
-	}
-	else {
-	  l->setText(8,"");
-	}
-	for(int i=0;i<list_log_list->columns();i++) {
-	  l->setTextColor(i,LOG_RELATIVE_TEXT_COLOR,QFont::Normal);
-	}
-	l->setText(14,"");
-	break;
+  case RDLogLine::Hard:
+    l->setText(1,QString("T")+
+	       TimeString(log_line->startTime(RDLogLine::Logged)));
+    l->setText(8,QString("T")+
+	       TimeString(log_line->startTime(RDLogLine::Logged)));
+    for(int i=0;i<list_log_list->columns();i++) {
+      l->setTextColor(i,LOG_HARDTIME_TEXT_COLOR,QFont::Bold);
+    }
+    l->setText(14,"N");
+    break;
+
+  default:
+    if(!log_line->startTime(RDLogLine::Logged).isNull()) {
+      l->setText(8,TimeString(log_line->startTime(RDLogLine::Logged)));
+    }
+    else {
+      l->setText(8,"");
+    }
+    for(int i=0;i<list_log_list->columns();i++) {
+      l->setTextColor(i,LOG_RELATIVE_TEXT_COLOR,QFont::Normal);
+    }
+    l->setText(14,"");
+    break;
   }
   switch(log_line->transType()) {
-      case RDLogLine::Play:
-	l->setText(3,tr("PLAY"));
-	l->setTextColor(3,l->textColor(2),QFont::Normal);
-	break;
-      case RDLogLine::Stop:
-	l->setText(3,tr("STOP"));
-	l->setTextColor(3,l->textColor(2),QFont::Normal);
-	break;
-      case RDLogLine::Segue:
-	l->setText(3,tr("SEGUE"));
-	if(log_line->hasCustomTransition()) {
-	  l->setTextColor(3,RD_CUSTOM_TRANSITION_COLOR,QFont::Bold);
-	}
-	else {
-	  if(log_line->timeType()==RDLogLine::Hard) {
-	    l->setTextColor(3,l->textColor(2),QFont::Bold);
-	  }
-	  else {
-	    l->setTextColor(3,l->textColor(2),QFont::Normal);
-	  }
-	}
-	break;
+  case RDLogLine::Play:
+    l->setText(3,tr("PLAY"));
+    l->setTextColor(3,l->textColor(2),QFont::Normal);
+    break;
 
-      default:
-	break;
+  case RDLogLine::Stop:
+    l->setText(3,tr("STOP"));
+    l->setTextColor(3,l->textColor(2),QFont::Normal);
+    break;
+
+  case RDLogLine::Segue:
+    l->setText(3,tr("SEGUE"));
+    if(log_line->hasCustomTransition()) {
+      l->setTextColor(3,RD_CUSTOM_TRANSITION_COLOR,QFont::Bold);
+    }
+    else {
+      if(log_line->timeType()==RDLogLine::Hard) {
+	l->setTextColor(3,l->textColor(2),QFont::Bold);
+      }
+      else {
+	l->setTextColor(3,l->textColor(2),QFont::Normal);
+      }
+    }
+    break;
+
+  default:
+    break;
   }
   switch(log_line->type()) {
-      case RDLogLine::Cart:
-	switch(log_line->source()) {
-	    case RDLogLine::Tracker:
-	      l->setPixmap(0,*list_track_cart_map);
-	      break;
+  case RDLogLine::Cart:
+    switch(log_line->source()) {
+    case RDLogLine::Tracker:
+      l->setPixmap(0,*list_track_cart_map);
+      break;
 
-	    default:
-	      l->setPixmap(0,*list_playout_map);
-	      break;
+    default:
+      l->setPixmap(0,*list_playout_map);
+      break;
 	}
 	l->setText(2,RDGetTimeLength(log_line->effectiveLength(),false,false));
 	l->setText(4,QString().
@@ -1234,12 +1176,8 @@ void ListLog::RefreshItem(RDListViewItem *l,int line)
 	  l->setText(5,log_line->title());
 	}
 	else {
-	  l->setText(5,QString().
-		     sprintf("%s -- %s %s",
-			     (const char *)log_line->title(),
-			     (const char *)log_line->originUser(),
-			     (const char *)log_line->originDateTime().
-			     toString("M/d hh:mm")));
+	  l->setText(5,log_line->title()+" -- "+log_line->originUser()+" "+
+		     log_line->originDateTime().toString("M/d hh:mm"));
 	}
 	l->setText(6,log_line->artist());
 	l->setText(7,log_line->groupName());
@@ -1311,27 +1249,33 @@ void ListLog::RefreshItem(RDListViewItem *l,int line)
   SetPlaybuttonMode(ListLog::ButtonDisabled);
   list_modify_button->setDisabled(true);
   switch(log_line->state()) {
-      case RDLogLine::NoCart:
-	if(log_line->type()==RDLogLine::Cart) {
-	  l->setPixmap(0,NULL);
-	  l->setText(8,"");
-	  l->setText(3,"");
-	  l->setText(5,tr("[CART NOT FOUND]"));
-	}
-	break;
+  case RDLogLine::NoCart:
+    if(log_line->type()==RDLogLine::Cart) {
+      l->setPixmap(0,NULL);
+      if(log_line->startTime(RDLogLine::Logged).isNull()) {
+	l->setText(8,"");
+      }
+      else {
+	l->setText(8,
+		   log_line->startTime(RDLogLine::Logged).toString("hh:mm:ss"));
+      }
+      l->setText(3,"");
+      l->setText(5,tr("[CART NOT FOUND]"));
+    }
+    break;
 
-      case RDLogLine::NoCut:
-	if(log_line->type()==RDLogLine::Cart) {
-	  l->setText(6,tr("[NO VALID CUT AVAILABLE]"));
-	}
-	break;
+  case RDLogLine::NoCut:
+    if(log_line->type()==RDLogLine::Cart) {
+      l->setText(6,tr("[NO VALID CUT AVAILABLE]"));
+    }
+    break;
 
-      default:
-	if((log_line->type()==RDLogLine::Cart)&&
-	   (log_line->effectiveLength()==0)) {
-	  l->setText(6,tr("[NO AUDIO AVAILABLE]"));
-	}
-	break;
+  default:
+    if((log_line->type()==RDLogLine::Cart)&&
+       (log_line->effectiveLength()==0)) {
+      l->setText(6,tr("[NO AUDIO AVAILABLE]"));
+    }
+    break;
   }
   list_log->transportEvents(lines);
   for(int i=0;i<TRANSPORT_QUANTITY;i++) {
@@ -1406,29 +1350,29 @@ void ListLog::UpdateTimes(int removed_line,int num_lines)
     }
     if((logline=list_log->logLine(line))!=NULL) {
       switch((RDLogLine::Status)next->text(16).toInt()) {
-	  case RDLogLine::Scheduled:
-	  case RDLogLine::Paused:
-	    switch(logline->timeType()) {
-		case RDLogLine::Hard:
-		  next->setText(1,QString(tr("T"))+
-			  TimeString(logline->startTime(RDLogLine::Logged)));
-		  break;
+      case RDLogLine::Scheduled:
+      case RDLogLine::Paused:
+	switch(logline->timeType()) {
+	case RDLogLine::Hard:
+	  next->setText(1,QString(tr("T"))+
+			TimeString(logline->startTime(RDLogLine::Logged)));
+	  break;
 		  
-		default:
-		  if(!logline->startTime(RDLogLine::Predicted).isNull()) {
-		    next->setText(1,
-		        TimeString(logline->startTime(RDLogLine::Predicted)));
-		  }
-		  else {
-		    next->setText(1,"");
-		  }
-		  break;
-	    }
-	    break;
+	default:
+	  if(!logline->startTime(RDLogLine::Predicted).isNull()) {
+	    next->setText(1,
+			  TimeString(logline->startTime(RDLogLine::Predicted)));
+	  }
+	  else {
+	    next->setText(1,"");
+	  }
+	  break;
+	}
+	break;
 
-	  default:
-	    next->setText(1,TimeString(logline->startTime(RDLogLine::Actual)));
-	    break;
+      default:
+	next->setText(1,TimeString(logline->startTime(RDLogLine::Actual)));
+	break;
       }
       next=(RDListViewItem *)next->nextSibling();
     }
@@ -1527,25 +1471,25 @@ void ListLog::SetPlaybuttonMode(ListLog::PlayButtonMode mode)
     return;
   }
   switch(mode) {
-      case ListLog::ButtonPlay:
-	list_play_button->setEnabled(true);
-	list_play_button->setText(tr("Start"));
-	break;
+  case ListLog::ButtonPlay:
+    list_play_button->setEnabled(true);
+    list_play_button->setText(tr("Start"));
+    break;
 
-      case ListLog::ButtonStop:
-	list_play_button->setEnabled(true);
-	if(list_pause_allowed) {
-	  list_play_button->setText(tr("Pause"));
-	}
-	else {
-	  list_play_button->setText(tr("Stop"));
-	}
-	break;
+  case ListLog::ButtonStop:
+    list_play_button->setEnabled(true);
+    if(list_pause_allowed) {
+      list_play_button->setText(tr("Pause"));
+    }
+    else {
+      list_play_button->setText(tr("Stop"));
+    }
+    break;
 
-      case ListLog::ButtonDisabled:
-	list_play_button->setDisabled(true);
-	list_play_button->setText(tr("Start"));
-	break;
+  case ListLog::ButtonDisabled:
+    list_play_button->setDisabled(true);
+    list_play_button->setText(tr("Start"));
+    break;
   }
   list_playbutton_mode=mode;
 }
@@ -1592,7 +1536,7 @@ int ListLog::PredictedStartHour(RDListViewItem *item)
   if(item==NULL) {
     return -1;
   }
-  QStringList item_fields=QStringList().split(":",item->text(1));
+  QStringList item_fields=item->text(1).split(":");
   if(item_fields.size()==3) {
     int item_hour=item_fields[0].replace("T","").toInt(&ok);
     if(ok) {
