@@ -2,7 +2,7 @@
 //
 // A PodCast Management Utility for Rivendell.
 //
-//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,35 +18,16 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#ifndef WIN32
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <unistd.h>
-#endif
 #include <qapplication.h>
-#include <qwindowsstyle.h>
-#include <qwidget.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qtextcodec.h>
 #include <qtranslator.h>
-#include <qsettings.h>
-#include <qpainter.h>
 #include <qmessagebox.h>
 
-#include <rd.h>
-#include <rdconf.h>
-#include <rduser.h>
-#include <rdripc.h>
-#include <rdcastmanager.h>
-#include <rdcmd_switch.h>
-#include <rddb.h>
+#include <rdescape_string.h>
 #include <rdpodcast.h>
-#include <dbversion.h>
 
-#include <list_casts.h>
-#include <globals.h>
+#include "globals.h"
+#include "list_casts.h"
+#include "rdcastmanager.h"
 
 //
 // Icons
@@ -61,107 +42,59 @@
 QString cast_filter;
 QString cast_group;
 QString cast_schedcode;
-RDUser *cast_user;
-RDRipc *cast_ripc;
-RDStation *rdstation_conf;
-RDConfig *config;
-RDSystem *cast_system=NULL;
 
-MainWidget::MainWidget(QWidget *parent)
-  :QMainWindow(parent)
+MainWidget::MainWidget(RDConfig *c,QWidget *parent)
+  : RDWidget(c,parent)
 {
   QString str1;
   QString str2;
-  bool skip_db_check=false;
-  unsigned schema=0;
+  QString err_msg;
 
-  //
-  // Read Command Options
-  //
-  RDCmdSwitch *cmd=
-    new RDCmdSwitch(qApp->argc(),qApp->argv(),"rdcastmanager","\n");
-  for(unsigned i=0;i<cmd->keys();i++) {
-    if(cmd->key(i)=="--skip-db-check") {
-      skip_db_check=true;
-    }
-  }
-  delete cmd;
+  cast_resize=false;
 
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
+  setMinimumSize(sizeHint());
 
   //
-  // Load Local Configs
+  // Open the Database/
   //
-  config=new RDConfig(RD_CONF_FILE);
-  config->load();
-  config->setModuleName("RDCastManager");
+  rda=new RDApplication("RDCastManager","rdcastmanager",RDCASTMANAGER_USAGE,
+			this);
+  if(!rda->open(&err_msg)) {
+    QMessageBox::critical(this,"RDCastManager - "+tr("Error"),err_msg);
+    exit(1);
+  }
+
+  //
+  // Read Command Options
+  //
+  for(unsigned i=0;i<rda->cmdSwitch()->keys();i++) {
+    if(!rda->cmdSwitch()->processed(i)) {
+      QMessageBox::critical(this,"RDCastManager - "+tr("Error"),
+			    tr("Unknown command option")+": "+
+			    rda->cmdSwitch()->key(i));
+      exit(2);
+    }
+  }
 
   str1=QString("RDCastManager")+" v"+VERSION+" - "+tr("Host");
   str2=QString(tr("User: [Unknown]"));
-  setCaption(QString().sprintf("%s: %s, %s",(const char *)str1,
-			       (const char *)config->stationName(),
-			       (const char *)str2));
-
-  //
-  // Open Database
-  //
-  QString err;
-  QSqlDatabase *db=RDInitDb(&schema,&err);
-  if(!db) {
-    QMessageBox::warning(this,tr("Can't Connect"),err);
-    exit(0);
-  }
-  if((schema!=RD_VERSION_DATABASE)&&(!skip_db_check)) {
-    fprintf(stderr,
-	    "rdcastmanager: database version mismatch, should be %u, is %u\n",
-	    RD_VERSION_DATABASE,schema);
-    exit(256);
-  }
-
-  //
-  // Station Configuration
-  //
-  rdstation_conf=new RDStation(config->stationName(),this);
-  cast_system=new RDSystem();
+  setWindowTitle(str1+": "+rda->config()->stationName()+" "+str2);
 
   //
   // RIPC Connection
   //
-#ifndef WIN32
-  cast_ripc=new RDRipc(rdstation_conf,config,this);
-  connect(cast_ripc,SIGNAL(userChanged()),this,SLOT(userChangedData()));
-  cast_ripc->connectHost("localhost",RIPCD_TCP_PORT,config->password());
-#else
-  cast_ripc=NULL;
-#endif  // WIN32
-
-  //
-  // User
-  //
-#ifndef WIN32
-  cast_user=NULL;
-#else 
-  cast_user=new RDUser(RD_USER_LOGIN_NAME);
-#endif  // WIN32
-
-  // 
-  // Create Fonts
-  //
-  QFont default_font("Helvetica",12,QFont::Normal);
-  default_font.setPixelSize(12);
-  qApp->setFont(default_font);
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
+  connect(rda,SIGNAL(userChanged()),this,SLOT(userChangedData()));
+  rda->ripc()->
+    connectHost("localhost",RIPCD_TCP_PORT,rda->config()->password());
 
   //
   // Create Icons
   //
   cast_rivendell_map=new QPixmap(rdcastmanager_22x22_xpm);
-  setIcon(*cast_rivendell_map);
+  setWindowIcon(*cast_rivendell_map);
   cast_greencheckmark_map=new QPixmap(greencheckmark_xpm);
   cast_redx_map=new QPixmap(redx_xpm);
 
@@ -169,13 +102,12 @@ MainWidget::MainWidget(QWidget *parent)
   // Feed List
   //
   cast_feed_list=new RDListView(this);
-  cast_feed_list->setFont(default_font);
   cast_feed_list->setAllColumnsShowFocus(true);
   cast_feed_list->setItemMargin(5);
   connect(cast_feed_list,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
 	  this,
-	  SLOT(feedDoubleclickedData(QListViewItem *,const QPoint &,int)));
+	  SLOT(feedDoubleclickedData(Q3ListViewItem *,const QPoint &,int)));
   cast_feed_list->addColumn("");
   cast_feed_list->setColumnAlignment(0,Qt::AlignCenter);
   cast_feed_list->addColumn(tr("Key Name"));
@@ -191,7 +123,7 @@ MainWidget::MainWidget(QWidget *parent)
   // Open Button
   //
   cast_open_button=new QPushButton(this);
-  cast_open_button->setFont(button_font);
+  cast_open_button->setFont(buttonFont());
   cast_open_button->setText(tr("&View\nFeed"));
   connect(cast_open_button,SIGNAL(clicked()),this,SLOT(openData()));
 
@@ -199,9 +131,11 @@ MainWidget::MainWidget(QWidget *parent)
   // Close Button
   //
   cast_close_button=new QPushButton(this);
-  cast_close_button->setFont(button_font);
+  cast_close_button->setFont(buttonFont());
   cast_close_button->setText(tr("&Close"));
   connect(cast_close_button,SIGNAL(clicked()),this,SLOT(quitMainWidget()));
+
+  cast_resize=true;
 }
 
 
@@ -222,16 +156,9 @@ void MainWidget::userChangedData()
   QString str1;
   QString str2;
 
-  if(cast_user!=NULL) {
-    delete cast_user;
-  }
   str1=QString("RDCastManager")+" v"+VERSION+" - "+tr("Host");
   str2=QString(tr("User"));
-  setCaption(QString().sprintf("%s: %s, %s: %s",(const char *)str1,
-			       (const char *)config->stationName(),
-			       (const char *)str2,
-			       (const char *)cast_ripc->user()));
-  cast_user=new RDUser(cast_ripc->user());
+  setCaption(str1+": "+rda->config()->stationName()+" "+str2+" "+rda->ripc()->user());
   RefreshList();
 }
 
@@ -249,7 +176,7 @@ void MainWidget::openData()
 }
 
 
-void MainWidget::feedDoubleclickedData(QListViewItem *,const QPoint &,int)
+void MainWidget::feedDoubleclickedData(Q3ListViewItem *,const QPoint &,int)
 {
   openData();
 }
@@ -263,9 +190,11 @@ void MainWidget::quitMainWidget()
 
 void MainWidget::resizeEvent(QResizeEvent *e)
 {
-  cast_feed_list->setGeometry(10,10,size().width()-20,size().height()-70);
-  cast_open_button->setGeometry(10,size().height()-55,80,50);
-  cast_close_button->setGeometry(size().width()-90,size().height()-55,80,50);
+  if(cast_resize) {
+    cast_feed_list->setGeometry(10,10,size().width()-20,size().height()-70);
+    cast_open_button->setGeometry(10,size().height()-55,80,50);
+    cast_close_button->setGeometry(size().width()-90,size().height()-55,80,50);
+  }
 }
 
 
@@ -277,9 +206,12 @@ void MainWidget::RefreshItem(RDListViewItem *item)
   int active=0;
   int total=0;
 
-  sql=QString().sprintf("select CHANNEL_TITLE,CHANNEL_DESCRIPTION,ID \
-                         from FEEDS where KEY_NAME=\"%s\"",
-			(const char *)item->text(1));
+  sql=QString("select ")+
+    "CHANNEL_TITLE,"+        // 00
+    "CHANNEL_DESCRIPTION,"+  // 01
+    "ID "+                   // 02
+    "from FEEDS where "+
+    "KEY_NAME=\""+RDEscapeString(item->text(1))+"\"";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     sql=QString().sprintf("select STATUS from PODCASTS where FEED_ID=%u",
@@ -323,9 +255,8 @@ void MainWidget::RefreshList()
     id=item->id();
   }
   cast_feed_list->clear();
-  sql=QString().sprintf("select KEY_NAME from FEED_PERMS \
-                         where USER_NAME=\"%s\"",
-			(const char *)cast_user->name());
+  sql=QString("select KEY_NAME from FEED_PERMS where ")+
+    "USER_NAME=\""+RDEscapeString(rda->user()->name())+"\"";
   q=new RDSqlQuery(sql);
   if(q->size()<=0) {  // No valid feeds!
     delete q;
@@ -333,8 +264,7 @@ void MainWidget::RefreshList()
   }
   sql="select ID,KEY_NAME from FEEDS where ";
   while(q->next()) {
-    sql+=QString().sprintf("(KEY_NAME=\"%s\")||",
-			   (const char *)q->value(0).toString());
+    sql+=QString("(KEY_NAME=\"")+RDEscapeString(q->value(0).toString())+"\")||";
   }
   delete q;
   sql=sql.left(sql.length()-2);
@@ -358,6 +288,7 @@ void MainWidget::RefreshList()
 
 int main(int argc,char *argv[])
 {
+  QApplication::setStyle(RD_GUI_STYLE);
   QApplication a(argc,argv);
   
   //
@@ -365,17 +296,9 @@ int main(int argc,char *argv[])
   //
   QString tr_path;
   QString qt_path;
-#ifdef WIN32
-  QSettings settings;
-  settings.insertSearchPath(QSettings::Windows,"/SalemRadioLabs");
-  tr_path=QString().sprintf("%s\\",
-			    (const char *)settings.
-			    readEntry("/Rivendell/InstallDir"));
-  qt_path=tr_path;
-#else
   tr_path=QString(PREFIX)+QString("/share/rivendell/");
-  qt_path=QString(QTDIR)+QString("/translation/");
-#endif  // WIN32
+  qt_path=QString("/usr/share/qt4/translation/");
+
   QTranslator qt(0);
   qt.load(qt_path+QString("qt_")+QTextCodec::locale(),".");
   a.installTranslator(&qt);
@@ -395,7 +318,9 @@ int main(int argc,char *argv[])
   //
   // Start Event Loop
   //
-  MainWidget *w=new MainWidget();
+  RDConfig *config=new RDConfig();
+  config->load();
+  MainWidget *w=new MainWidget(config);
   a.setMainWidget(w);
   w->setGeometry(w->geometry().x(),w->geometry().y(),w->sizeHint().width(),w->sizeHint().height());
   w->show();
