@@ -2,7 +2,7 @@
 //
 // A RSS Feed Management Utility for Rivendell.
 //
-//   (C) Copyright 2002-2007,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,34 +21,26 @@
 #ifndef RDCASTMANAGER_H
 #define RDCASTMANAGER_H
 
-#include <vector>
-
-#include <qmainwindow.h>
-#include <qsize.h>
-#include <qsizepolicy.h>
-#include <qsqldatabase.h>
 #include <qpushbutton.h>
-#include <qpixmap.h>
 
-#include <rdlistview.h>
-#include <rduser.h>
-#include <rdripc.h>
-#include <rdlibrary_conf.h>
-#include <rdlog_line.h>
 #include <rdconfig.h>
+#include <rdlog_line.h>
+#include <rdwidget.h>
 
-class MainWidget : public QMainWindow
+#define RDCASTMANAGER_USAGE "\n"
+
+class MainWidget : public RDWidget
 {
  Q_OBJECT
  public:
-  MainWidget(QWidget *parent=0);
+  MainWidget(RDConfig *c,QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
   
  private slots:
   void openData();
   void userChangedData();
-  void feedDoubleclickedData(QListViewItem *item,const QPoint &pt,int col);
+  void feedDoubleclickedData(Q3ListViewItem *item,const QPoint &pt,int col);
   void quitMainWidget();
 
  protected:
@@ -63,6 +55,7 @@ class MainWidget : public QMainWindow
   QPixmap *cast_redx_map;
   QPushButton *cast_open_button;
   QPushButton *cast_close_button;
+  bool cast_resize;
 };
 
 
