@@ -2,9 +2,7 @@
 //
 // Edit a Rivendell Macro
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_macro.h,v 1.8.8.2 2013/12/23 22:04:03 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,19 +21,16 @@
 #ifndef EDIT_MACRO_H
 #define EDIT_MACRO_H
 
-#include <qdialog.h>
 #include <qlineedit.h>
-#include <qpushbutton.h>
 
-#include <rdcart.h>
+#include <rddialog.h>
 #include <rdmacro.h>
 
-
-class EditMacro : public QDialog
+class EditMacro : public RDDialog
 {
   Q_OBJECT
  public:
-  EditMacro(RDMacro *cmd,bool highlight,QWidget *parent=0,const char *name=0);
+  EditMacro(RDMacro *cmd,bool highlight,QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
