@@ -47,7 +47,8 @@ EditLogLine::EditLogLine(RDLogLine *line,QString *filter,QString *group,
   //
   // Cart Picker
   //
-  edit_cart_dialog=new RDCartDialog(edit_filter,edit_group,edit_schedcode,this);
+  edit_cart_dialog=new RDCartDialog(edit_filter,edit_group,edit_schedcode,
+				    "RDLogEdit",this);
 
   //
   // Overlap Box
