@@ -2,7 +2,7 @@
 //
 // List and Generate Log Reports
 //
-//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,24 +18,22 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qsqldatabase.h>
 #include <qmessagebox.h>
+#include <qpushbutton.h>
 
 #include <rdconf.h>
-#include <rdtextfile.h>
 #include <rddatedialog.h>
+#include <rdreport.h>
+#include <rdtextfile.h>
 
-#include <globals.h>
-#include <list_reports.h>
+#include "globals.h"
+#include "list_reports.h"
 
 ListReports::ListReports(const QString &logname,const QString &description,
 			 const QString service_name,const QDate &start_date,
 			 const QDate &end_date,bool auto_refresh,
 			 RDLogEvent *events,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
   list_log_name=logname;
   list_description=description;
@@ -45,23 +43,13 @@ ListReports::ListReports(const QString &logname,const QString &description,
   list_auto_refresh=auto_refresh;
   list_events=events;
 
+  setWindowTitle("RDLogEdit - "+tr("Reports"));
+
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
-
-  setCaption(tr("RDLibrary Reports"));
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-  QFont select_font=QFont("Helvetica",12,QFont::Normal);
-  select_font.setPixelSize(12);
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
   //
   // Reports List
@@ -73,21 +61,21 @@ ListReports::ListReports(const QString &logname,const QString &description,
   QLabel *list_reports_label=
     new QLabel(list_reports_box,tr("Type:"),this);
   list_reports_label->setGeometry(10,10,35,19);
-  list_reports_label->setFont(font);
-  list_reports_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  list_reports_label->setFont(labelFont());
+  list_reports_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Effective Date
   //
-  list_date_edit=new QDateEdit(this);
+  list_date_edit=new Q3DateEdit(this);
   list_date_edit->setGeometry(110,34,100,19);
   QLabel *list_date_label=new QLabel(list_date_edit,tr("Effective Date:"),this);
   list_date_label->setGeometry(10,34,95,19);
-  list_date_label->setFont(font);
-  list_date_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  list_date_label->setFont(labelFont());
+  list_date_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   QPushButton *button=new QPushButton(this);
   button->setGeometry(215,32,60,24);
-  button->setFont(select_font);
+  button->setFont(subButtonFont());
   button->setText(tr("&Select"));
   connect(button,SIGNAL(clicked()),this,SLOT(selectDateData()));
   list_date_edit->setDate(QDate::currentDate());
@@ -98,7 +86,7 @@ ListReports::ListReports(const QString &logname,const QString &description,
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   button->setDefault(true);
-  button->setFont(font);
+  button->setFont(buttonFont());
   button->setText(tr("&Generate"));
   connect(button,SIGNAL(clicked()),this,SLOT(generateData()));
 
@@ -107,7 +95,7 @@ ListReports::ListReports(const QString &logname,const QString &description,
   //
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
-  button->setFont(font);
+  button->setFont(buttonFont());
   button->setText(tr("&Close"));
   connect(button,SIGNAL(clicked()),this,SLOT(closeData()));
 }
@@ -147,16 +135,16 @@ void ListReports::generateData()
   QString report;
 
   switch(list_reports_box->currentItem()) {
-      case 0:  // Event Report
-	GenerateLogReport(&report);
-	break;
+  case 0:  // Event Report
+    GenerateLogReport(&report);
+    break;
 
-      case 1:  // XLoad Report
-	GenerateExceptionReport(&report,list_date_edit->date());
-	break;
+  case 1:  // XLoad Report
+    GenerateExceptionReport(&report,list_date_edit->date());
+    break;
 
-      default:
-	return;
+  default:
+    return;
   }
   if(!report.isEmpty()) {
     RDTextFile(report);
@@ -187,18 +175,16 @@ void ListReports::GenerateLogReport(QString *report)
   if(!list_end_date.isNull()) {
     end_date=list_end_date.toString("MM/dd/yyyy");
   }
-  *report="                                                     Rivendell Log Listing\n";
-  *report+=QString().
-    sprintf("Generated: %s                        Log: %-30s  Description: %s\n",
-	    (const char *)QDateTime(QDate::currentDate(),QTime::currentTime()).
-	    toString("MM/dd/yyyy - hh:mm:ss"),
-	    (const char *)list_log_name.left(30),
-	    (const char *)list_description.left(27));
-  *report+=QString().
-    sprintf("Service: %-10s          AutoRefresh Enabled: %-3s   Start Date: %-10s               End Date: %s\n",
-	    (const char *)list_service_name,
-	    (const char *)refresh,
-	    (const char *)start_date,(const char *)end_date);
+  *report=RDReport::center("Rivendell Log Listing",132)+"\n";
+  //  *report="                                                     Rivendell Log Listing\n";
+  *report+=QString("Generated: ")+
+    QDateTime::currentDateTime().toString("MM/dd/yyyy")+"                        Log: "+
+    RDReport::leftJustify(list_log_name,30)+
+    "  Description: "+RDReport::leftJustify(list_description,27)+"\n";
+  *report+=QString("Service: ")+RDReport::leftJustify(list_service_name,10)+
+    "          AutoRefresh Enabled: "+RDReport::leftJustify(refresh,3)+"   "+
+    RDReport::leftJustify(start_date,10)+"               "+end_date+"\n";
+
   *report+="\n";
   *report+="-Type-- -Time---- Trans -Cart- -Group---- -Length- -Title--------------------------- -Artist----------------------- -Source----- Line\n";
 
@@ -212,8 +198,7 @@ void ListReports::GenerateLogReport(QString *report)
     //
     // Type
     //
-    *report+=QString().sprintf("%-7s ",
-	       (const char *)RDLogLine::typeText(logline->type()));
+    *report+=RDReport::leftJustify(RDLogLine::typeText(logline->type()),7)+" ";
 
     //
     // Time
@@ -225,10 +210,7 @@ void ListReports::GenerateLogReport(QString *report)
       *report+=" ";
     }
     if(!logline->startTime(RDLogLine::Imported).isNull()) {
-      *report+=QString().sprintf("%-8s ",
-				 (const char *)logline->
-				 startTime(RDLogLine::Logged).
-				 toString("hh:mm:ss"));
+      *report+=RDReport::leftJustify(logline->startTime(RDLogLine::Logged).toString("hh:mm:ss"),8)+" ";
     }
     else {
       *report+="         ";
@@ -237,76 +219,61 @@ void ListReports::GenerateLogReport(QString *report)
     //
     // Transition Type
     //
-    *report+=QString().sprintf("%-5s ",
-	  (const char *)RDLogLine::transText(logline->transType()).left(5));
+    *report+=RDReport::leftJustify(RDLogLine::transText(logline->transType()).left(5),5)+" ";
 
     switch(logline->type()) {
-	case RDLogLine::Cart:
-	case RDLogLine::Macro:
-	  *report+=QString().sprintf("%06u ",logline->cartNumber());
-	  *report+=QString().sprintf("%-10s ",
-				     (const char *)logline->groupName());
-	  *report+=QString().sprintf("%8s ",(const char *)
-				     RDGetTimeLength(logline->forcedLength(),
-						    false,false));
-	  *report+=
-	    QString().sprintf("%-33s ",
-			      (const char *)logline->title().left(33));
-	  *report+=
-	    QString().sprintf("%-30s ",
-			      (const char *)logline->artist().left(30));
-	  break;
+    case RDLogLine::Cart:
+    case RDLogLine::Macro:
+      *report+=QString().sprintf("%06u ",logline->cartNumber());
+      *report+=RDReport::leftJustify(logline->groupName(),10)+" ";
+      *report+=RDReport::rightJustify(RDGetTimeLength(logline->forcedLength(),false,false),8)+" ";
+      *report+=RDReport::leftJustify(logline->title(),33)+" ";
+      *report+=RDReport::leftJustify(logline->artist(),30)+" ";
+      break;
 
-	case RDLogLine::Marker:
-	case RDLogLine::Track:
-	  *report+="       ";
-	  *report+="           ";
-	  *report+="     :00 ";
-	  *report+=
-	    QString().sprintf("%-30s ",
-			      (const char *)logline->markerComment().left(30));
-	  *report+="                               ";
-	  break;
+    case RDLogLine::Marker:
+    case RDLogLine::Track:
+      *report+="       ";
+      *report+="           ";
+      *report+="     :00 ";
+      *report+=RDReport::leftJustify(logline->markerComment(),30)+" ";
+      *report+="                               ";
+      break;
 
-	case RDLogLine::TrafficLink:
-	  *report+="       ";
-	  *report+="           ";
-	  *report+="     :00 ";
-	  *report+="Traffic Import                 ";
-	  *report+="                               ";
-	  break;
+    case RDLogLine::TrafficLink:
+      *report+="       ";
+      *report+="           ";
+      *report+="     :00 ";
+      *report+="Traffic Import                 ";
+      *report+="                               ";
+      break;
 
-	case RDLogLine::MusicLink:
-	  *report+="       ";
-	  *report+="           ";
-	  *report+="     :00 ";
-	  *report+="Music Import                 ";
-	  *report+="                               ";
-	  break;
+    case RDLogLine::MusicLink:
+      *report+="       ";
+      *report+="           ";
+      *report+="     :00 ";
+      *report+="Music Import                 ";
+      *report+="                               ";
+      break;
 
 
-	case RDLogLine::Chain:
-	  *report+="       ";
-	  *report+="           ";
-	  *report+="         ";
-	  *report+=
-	    QString().sprintf("%-30s ",
-			      (const char *)logline->markerLabel().left(30));
-	  *report+="                               ";
-	  break;
-	  break;
+    case RDLogLine::Chain:
+      *report+="       ";
+      *report+="           ";
+      *report+="         ";
+      *report+=RDReport::leftJustify(logline->markerLabel(),30)+" ";
+      break;
 
-	case RDLogLine::OpenBracket:
-	case RDLogLine::CloseBracket:
-	case RDLogLine::UnknownType:
-	  break;
+    case RDLogLine::OpenBracket:
+    case RDLogLine::CloseBracket:
+    case RDLogLine::UnknownType:
+      break;
     }
 
     //
     // Source
     //
-    *report+=QString().sprintf("%-12s ",
-		(const char *)RDLogLine::sourceText(logline->source()));
+    *report+=RDReport::leftJustify(RDLogLine::sourceText(logline->source()),12)+" ";
 
     //
     // Line
