@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AddMeta</name>
     <message>
@@ -30,39 +32,39 @@
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Začít na:</translation>
+        <translation type="obsolete">Začít na:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Činnost, když předchozí událost ještě běží</translation>
+        <translation type="obsolete">Činnost, když předchozí událost ještě běží</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Spustit ihned</translation>
+        <translation type="obsolete">Spustit ihned</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Jako další</translation>
+        <translation type="obsolete">Jako další</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Počkat až do</translation>
+        <translation type="obsolete">Počkat až do</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Přehrát</translation>
+        <translation type="obsolete">Přehrát</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Přechod</translation>
+        <translation type="obsolete">Přechod</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Zastavit</translation>
+        <translation type="obsolete">Zastavit</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Typ přechodu:</translation>
+        <translation type="obsolete">Typ přechodu:</translation>
     </message>
     <message>
         <source>Log Name</source>
@@ -78,15 +80,15 @@
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>Z&amp;rušit</translation>
+        <translation type="obsolete">Z&amp;rušit</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Přechod, když předchozí vozík skončí dříve</translation>
+        <translation type="obsolete">Přechod, když předchozí vozík skončí dříve</translation>
     </message>
 </context>
 <context>
@@ -145,55 +147,55 @@
     </message>
     <message>
         <source>TIME</source>
-        <translation>ČAS</translation>
+        <translation type="obsolete">ČAS</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation>PŘECHOD</translation>
+        <translation type="obsolete">PŘECHOD</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>VOZÍK</translation>
+        <translation type="obsolete">VOZÍK</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>SKUPINA</translation>
+        <translation type="obsolete">SKUPINA</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DÉLKA</translation>
+        <translation type="obsolete">DÉLKA</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>NÁZEV</translation>
+        <translation type="obsolete">NÁZEV</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>UMĚLEC</translation>
+        <translation type="obsolete">UMĚLEC</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>ZÁKAZNÍK</translation>
+        <translation type="obsolete">ZÁKAZNÍK</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENTURA</translation>
+        <translation type="obsolete">AGENTURA</translation>
     </message>
     <message>
         <source>LABEL</source>
-        <translation>ŠTÍTEK</translation>
+        <translation type="obsolete">ŠTÍTEK</translation>
     </message>
     <message>
         <source>SOURCE</source>
-        <translation>ZDROJ</translation>
+        <translation type="obsolete">ZDROJ</translation>
     </message>
     <message>
         <source>LINE ID</source>
-        <translation>ID ŘÁDKU</translation>
+        <translation type="obsolete">ID ŘÁDKU</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>POČÍTADLO</translation>
+        <translation type="obsolete">POČÍTADLO</translation>
     </message>
     <message>
         <source>Insert
@@ -379,7 +381,7 @@ jež jsou pro vybranou službu zakázány!</translation>
     </message>
     <message>
         <source>Run Length</source>
-        <translation>Délka běhu</translation>
+        <translation type="unfinished">Délka běhu</translation>
     </message>
     <message>
         <source>Selected:</source>
@@ -397,10 +399,6 @@ jež jsou pro vybranou službu zakázány!</translation>
         <source>Unable to save log, audio deletion error!</source>
         <translation>Soubor se zápisem nelze uložit, chyba při mazání zvuku!</translation>
     </message>
-    <message>
-        <source>EXT DATA</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Link Start</source>
         <translation type="unfinished"></translation>
@@ -425,6 +423,94 @@ jež jsou pro vybranou službu zakázány!</translation>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>User</source>
+        <translation type="obsolete">Uživatel</translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished">Vozík</translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">Název</translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished">Umělec</translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished">Štítek</translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ext Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Line ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scheduled</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Start Times As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sch. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Estimated</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Est. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditLogLine</name>
@@ -434,39 +520,39 @@ jež jsou pro vybranou službu zakázány!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Začít na:</translation>
+        <translation type="obsolete">Začít na:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Činnost, když předchozí událost ještě běží</translation>
+        <translation type="obsolete">Činnost, když předchozí událost ještě běží</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Spustit ihned</translation>
+        <translation type="obsolete">Spustit ihned</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Jako další</translation>
+        <translation type="obsolete">Jako další</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Počkat až do</translation>
+        <translation type="obsolete">Počkat až do</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Přehrát</translation>
+        <translation type="obsolete">Přehrát</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Přechod</translation>
+        <translation type="obsolete">Přechod</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Zastavit</translation>
+        <translation type="obsolete">Zastavit</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Typ přechodu:</translation>
+        <translation type="obsolete">Typ přechodu:</translation>
     </message>
     <message>
         <source>Cart</source>
@@ -488,15 +574,15 @@ vozík</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>Z&amp;rušit</translation>
+        <translation type="obsolete">Z&amp;rušit</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Přechod, když předchozí vozík skončí dříve</translation>
+        <translation type="obsolete">Přechod, když předchozí vozík skončí dříve</translation>
     </message>
     <message>
         <source>Missing Cart</source>
@@ -522,11 +608,11 @@ vybrané služby!</translation>
     </message>
     <message>
         <source>Duplicate Start Time</source>
-        <translation>Zdvojený čas začátku</translation>
+        <translation type="obsolete">Zdvojený čas začátku</translation>
     </message>
     <message>
         <source>An event is already scheduled with this start time!</source>
-        <translation>Již existuje událost s tímto začátečním časem!</translation>
+        <translation type="obsolete">Již existuje událost s tímto začátečním časem!</translation>
     </message>
 </context>
 <context>
@@ -537,35 +623,35 @@ vybrané služby!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Začít na:</translation>
+        <translation type="obsolete">Začít na:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Činnost, když předchozí událost ještě běží</translation>
+        <translation type="obsolete">Činnost, když předchozí událost ještě běží</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Spustit ihned</translation>
+        <translation type="obsolete">Spustit ihned</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Jako další</translation>
+        <translation type="obsolete">Jako další</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Počkat až do</translation>
+        <translation type="obsolete">Počkat až do</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Přehrát</translation>
+        <translation type="obsolete">Přehrát</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Přechod</translation>
+        <translation type="obsolete">Přechod</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Zastavit</translation>
+        <translation type="obsolete">Zastavit</translation>
     </message>
     <message>
         <source>Comment</source>
@@ -577,19 +663,19 @@ vybrané služby!</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>Z&amp;rušit</translation>
+        <translation type="obsolete">Z&amp;rušit</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Přechod, když předchozí vozík skončí dříve</translation>
+        <translation type="obsolete">Přechod, když předchozí vozík skončí dříve</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Typ přechodu:</translation>
+        <translation type="obsolete">Typ přechodu:</translation>
     </message>
 </context>
 <context>
@@ -600,35 +686,35 @@ vybrané služby!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Začít na:</translation>
+        <translation type="obsolete">Začít na:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Činnost, když předchozí událost ještě běží</translation>
+        <translation type="obsolete">Činnost, když předchozí událost ještě běží</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Spustit ihned</translation>
+        <translation type="obsolete">Spustit ihned</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Jako další</translation>
+        <translation type="obsolete">Jako další</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Počkat až do</translation>
+        <translation type="obsolete">Počkat až do</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Přehrát</translation>
+        <translation type="obsolete">Přehrát</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Přechod</translation>
+        <translation type="obsolete">Přechod</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Zastavit</translation>
+        <translation type="obsolete">Zastavit</translation>
     </message>
     <message>
         <source>Comment</source>
@@ -636,19 +722,19 @@ vybrané služby!</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>Z&amp;rušit</translation>
+        <translation type="obsolete">Z&amp;rušit</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Přechod, když předchozí vozík skončí dříve</translation>
+        <translation type="obsolete">Přechod, když předchozí vozík skončí dříve</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Typ přechodu:</translation>
+        <translation type="obsolete">Typ přechodu:</translation>
     </message>
 </context>
 <context>
@@ -682,7 +768,7 @@ vybrané služby!</translation>
     <name>ListReports</name>
     <message>
         <source>RDLibrary Reports</source>
-        <translation>Zprávy RDLibrary</translation>
+        <translation type="obsolete">Zprávy RDLibrary</translation>
     </message>
     <message>
         <source>Log Listing</source>
@@ -724,6 +810,10 @@ vybrané služby!</translation>
         <source>&amp;Select</source>
         <translation>&amp;Vybrat</translation>
     </message>
+    <message>
+        <source>Reports</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWidget</name>
@@ -737,55 +827,55 @@ vybrané služby!</translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>Nelze spojit</translation>
+        <translation type="obsolete">Nelze spojit</translation>
     </message>
     <message>
         <source>LOG NAME</source>
-        <translation>NÁZEV ZÁPISU</translation>
+        <translation type="obsolete">NÁZEV ZÁPISU</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>POPIS</translation>
+        <translation type="obsolete">POPIS</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SLUŽBA</translation>
+        <translation type="obsolete">SLUŽBA</translation>
     </message>
     <message>
         <source>MUSIC</source>
-        <translation>HUDBA</translation>
+        <translation type="obsolete">HUDBA</translation>
     </message>
     <message>
         <source>TRAFFIC</source>
-        <translation>PŘENOS</translation>
+        <translation type="obsolete">PŘENOS</translation>
     </message>
     <message>
         <source>TRACKS</source>
-        <translation>STOPY</translation>
+        <translation type="obsolete">STOPY</translation>
     </message>
     <message>
         <source>VALID FROM</source>
-        <translation>PLATNÉ OD</translation>
+        <translation type="obsolete">PLATNÉ OD</translation>
     </message>
     <message>
         <source>VALID TO</source>
-        <translation>PLATNÉ DO</translation>
+        <translation type="obsolete">PLATNÉ DO</translation>
     </message>
     <message>
         <source>AUTO REFRESH</source>
-        <translation>AUTOOBNOVA</translation>
+        <translation type="obsolete">AUTOOBNOVA</translation>
     </message>
     <message>
         <source>ORIGIN</source>
-        <translation>PŮVOD</translation>
+        <translation type="obsolete">PŮVOD</translation>
     </message>
     <message>
         <source>LAST LINKED</source>
-        <translation>NAPOSLEDY SPOJENO</translation>
+        <translation type="obsolete">NAPOSLEDY SPOJENO</translation>
     </message>
     <message>
         <source>LAST MODIFIED</source>
-        <translation>NAPOSLEDY ZMĚNĚNO</translation>
+        <translation type="obsolete">NAPOSLEDY ZMĚNĚNO</translation>
     </message>
     <message>
         <source>&amp;Add</source>
@@ -867,12 +957,12 @@ Pokračovat?</translation>
     </message>
     <message>
         <source>RDLogEdit -- Database Skew</source>
-        <translation>RDLogEdit - Nesouměrnost v databázi</translation>
+        <translation type="obsolete">RDLogEdit - Nesouměrnost v databázi</translation>
     </message>
     <message>
         <source>This version of RDLogEdit is incompatible with the version installed on the server.
 See your system administrator for an update!</source>
-        <translation>Tato verze RDLogEdit je neslučitelná s verzí nainstalovanou na serveru.
+        <translation type="obsolete">Tato verze RDLogEdit je neslučitelná s verzí nainstalovanou na serveru.
 Vyhledejte svého správce systému kvůli aktualizaci!</translation>
     </message>
     <message>
@@ -924,7 +1014,63 @@ Vyhledejte svého správce systému kvůli aktualizaci!</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Windows</source>
+        <source>Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log Name</source>
+        <translation type="unfinished">Název zápisu</translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music</source>
+        <translation type="unfinished">Hudba</translation>
+    </message>
+    <message>
+        <source>Traffic</source>
+        <translation type="unfinished">Přenos</translation>
+    </message>
+    <message>
+        <source>Tracks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Valid From</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Valid To</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto Refresh</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Origin</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Linked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Modified</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1089,31 +1235,31 @@ Track</source>
     </message>
     <message>
         <source>TIME</source>
-        <translation type="unfinished">ČAS</translation>
+        <translation type="obsolete">ČAS</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation type="unfinished">PŘECHOD</translation>
+        <translation type="obsolete">PŘECHOD</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation type="unfinished">VOZÍK</translation>
+        <translation type="obsolete">VOZÍK</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation type="unfinished">SKUPINA</translation>
+        <translation type="obsolete">SKUPINA</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation type="unfinished">DÉLKA</translation>
+        <translation type="obsolete">DÉLKA</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation type="unfinished">NÁZEV</translation>
+        <translation type="obsolete">NÁZEV</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation type="unfinished">UMĚLEC</translation>
+        <translation type="obsolete">UMĚLEC</translation>
     </message>
     <message>
         <source>Do Over</source>
@@ -1243,12 +1389,52 @@ therefore only existing transitions will be editable.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALBUM</source>
+        <source>LABEL</source>
+        <translation type="obsolete">ŠTÍTEK</translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>LABEL</source>
-        <translation type="unfinished">ŠTÍTEK</translation>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Talk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished">Vozík</translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">Název</translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished">Umělec</translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished">Štítek</translation>
     </message>
 </context>
 </TS>
