@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AddMeta</name>
     <message>
@@ -30,39 +32,39 @@
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Inicia en:</translation>
+        <translation type="obsolete">Inicia en:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Acción si el evento previo no ha terminado</translation>
+        <translation type="obsolete">Acción si el evento previo no ha terminado</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Iniciar de inmediato</translation>
+        <translation type="obsolete">Iniciar de inmediato</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Convertir en el siguente</translation>
+        <translation type="obsolete">Convertir en el siguente</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Espe. hasta</translation>
+        <translation type="obsolete">Espe. hasta</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Reproducir</translation>
+        <translation type="obsolete">Reproducir</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Segue</translation>
+        <translation type="obsolete">Segue</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Parar</translation>
+        <translation type="obsolete">Parar</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Tipo de transición:</translation>
+        <translation type="obsolete">Tipo de transición:</translation>
     </message>
     <message>
         <source>Log Name</source>
@@ -78,15 +80,15 @@
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;Aceptar</translation>
+        <translation type="obsolete">&amp;Aceptar</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Transic. si cart. previo termina antes de</translation>
+        <translation type="obsolete">Transic. si cart. previo termina antes de</translation>
     </message>
 </context>
 <context>
@@ -129,51 +131,51 @@
     </message>
     <message>
         <source>TIME</source>
-        <translation>TIEMPO</translation>
+        <translation type="obsolete">TIEMPO</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation>TRANS</translation>
+        <translation type="obsolete">TRANS</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>CARTUCHO</translation>
+        <translation type="obsolete">CARTUCHO</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPO</translation>
+        <translation type="obsolete">GRUPO</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DURACIÓN</translation>
+        <translation type="obsolete">DURACIÓN</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TÍTULO</translation>
+        <translation type="obsolete">TÍTULO</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTISTA</translation>
+        <translation type="obsolete">ARTISTA</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>CLIENTE</translation>
+        <translation type="obsolete">CLIENTE</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENCIA</translation>
+        <translation type="obsolete">AGENCIA</translation>
     </message>
     <message>
         <source>LABEL</source>
-        <translation>ETIQUETA</translation>
+        <translation type="obsolete">ETIQUETA</translation>
     </message>
     <message>
         <source>LINE ID</source>
-        <translation>ID LÍNEA</translation>
+        <translation type="obsolete">ID LÍNEA</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>CUENTA</translation>
+        <translation type="obsolete">CUENTA</translation>
     </message>
     <message>
         <source>Insert
@@ -247,11 +249,11 @@ desactivados para el dispositivo seleccionado!</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>La Lista ya existe</translation>
+        <translation type="obsolete">La Lista ya existe</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>¡El playlist o Lista ya existe!</translation>
+        <translation type="obsolete">¡El playlist o Lista ya existe!</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
@@ -293,7 +295,7 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>SOURCE</source>
-        <translation>FUENTE</translation>
+        <translation type="obsolete">FUENTE</translation>
     </message>
     <message>
         <source>Manual</source>
@@ -379,7 +381,7 @@ desactivados para el servicio actual!
     </message>
     <message>
         <source>Run Length</source>
-        <translation>Durac. total</translation>
+        <translation type="unfinished">Durac. total</translation>
     </message>
     <message>
         <source>Selected:</source>
@@ -397,10 +399,6 @@ desactivados para el servicio actual!
         <source>Unable to save log, audio deletion error!</source>
         <translation>No es posible guardar la Lista, ¡error por eliminación de audio!</translation>
     </message>
-    <message>
-        <source>EXT DATA</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Link Start</source>
         <translation type="unfinished"></translation>
@@ -421,6 +419,98 @@ desactivados para el servicio actual!
         <source>Render</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User</source>
+        <translation type="obsolete">Usuario</translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Time</source>
+        <translation type="unfinished">Tiempo</translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished">Cartucho</translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">Título</translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished">Artista</translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished">Etiqueta</translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ext Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Line ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scheduled</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Start Times As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sch. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Estimated</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Est. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditLogLine</name>
@@ -430,39 +520,39 @@ desactivados para el servicio actual!
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Inicia en:</translation>
+        <translation type="obsolete">Inicia en:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Acción si el evento previo no ha terminado</translation>
+        <translation type="obsolete">Acción si el evento previo no ha terminado</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Iniciar de inmediato</translation>
+        <translation type="obsolete">Iniciar de inmediato</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Convertir en el siguente</translation>
+        <translation type="obsolete">Convertir en el siguente</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Esp. hasta</translation>
+        <translation type="obsolete">Esp. hasta</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Reproducir</translation>
+        <translation type="obsolete">Reproducir</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Segue</translation>
+        <translation type="obsolete">Segue</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Parar</translation>
+        <translation type="obsolete">Parar</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Tipo de transición:</translation>
+        <translation type="obsolete">Tipo de transición:</translation>
     </message>
     <message>
         <source>Cart</source>
@@ -484,15 +574,15 @@ cartucho</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;Aceptar</translation>
+        <translation type="obsolete">&amp;Aceptar</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Transic. si cart. previo termina antes de</translation>
+        <translation type="obsolete">Transic. si cart. previo termina antes de</translation>
     </message>
     <message>
         <source>Missing Cart</source>
@@ -518,11 +608,11 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Duplicate Start Time</source>
-        <translation>Tiempo de inicio duplicado</translation>
+        <translation type="obsolete">Tiempo de inicio duplicado</translation>
     </message>
     <message>
         <source>An event is already scheduled with this start time!</source>
-        <translation>¡Se programó un evento para esta misma hora de inicio!</translation>
+        <translation type="obsolete">¡Se programó un evento para esta misma hora de inicio!</translation>
     </message>
 </context>
 <context>
@@ -533,35 +623,35 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Inicia en:</translation>
+        <translation type="obsolete">Inicia en:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Acción si el evento previo no ha terminado</translation>
+        <translation type="obsolete">Acción si el evento previo no ha terminado</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Iniciar de inmediato</translation>
+        <translation type="obsolete">Iniciar de inmediato</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Convertir en el siguente</translation>
+        <translation type="obsolete">Convertir en el siguente</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Esp. hasta</translation>
+        <translation type="obsolete">Esp. hasta</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Reproducir</translation>
+        <translation type="obsolete">Reproducir</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Segue</translation>
+        <translation type="obsolete">Segue</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Parar</translation>
+        <translation type="obsolete">Parar</translation>
     </message>
     <message>
         <source>Comment</source>
@@ -573,19 +663,19 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;Aceptar</translation>
+        <translation type="obsolete">&amp;Aceptar</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Transic. si cart. previo termina antes de</translation>
+        <translation type="obsolete">Transic. si cart. previo termina antes de</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Tipo de transición:</translation>
+        <translation type="obsolete">Tipo de transición:</translation>
     </message>
 </context>
 <context>
@@ -596,35 +686,35 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Inicia en:</translation>
+        <translation type="obsolete">Inicia en:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Acción si el evento previo no ha terminado</translation>
+        <translation type="obsolete">Acción si el evento previo no ha terminado</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Iniciar de inmediato</translation>
+        <translation type="obsolete">Iniciar de inmediato</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Convertir en el siguente</translation>
+        <translation type="obsolete">Convertir en el siguente</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Esp. hasta</translation>
+        <translation type="obsolete">Esp. hasta</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Reproducir</translation>
+        <translation type="obsolete">Reproducir</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Segue</translation>
+        <translation type="obsolete">Segue</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Parar</translation>
+        <translation type="obsolete">Parar</translation>
     </message>
     <message>
         <source>Comment</source>
@@ -632,53 +722,53 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;Aceptar</translation>
+        <translation type="obsolete">&amp;Aceptar</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Transic. si cart. previo termina antes de</translation>
+        <translation type="obsolete">Transic. si cart. previo termina antes de</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Tipo de transición:</translation>
+        <translation type="obsolete">Tipo de transición:</translation>
     </message>
 </context>
 <context>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation>Seleccione una Lista</translation>
+        <translation type="obsolete">Seleccione una Lista</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NOMBRE</translation>
+        <translation type="obsolete">NOMBRE</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>DESCRIPCIÓN</translation>
+        <translation type="obsolete">DESCRIPCIÓN</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SERVICIO</translation>
+        <translation type="obsolete">SERVICIO</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;Aceptar</translation>
+        <translation type="obsolete">&amp;Aceptar</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
 </context>
 <context>
     <name>ListReports</name>
     <message>
         <source>RDLibrary Reports</source>
-        <translation>Reportes de RDLibrary</translation>
+        <translation type="obsolete">Reportes de RDLibrary</translation>
     </message>
     <message>
         <source>Log Listing</source>
@@ -720,6 +810,10 @@ desactivado para el servicio especificado!</translation>
         <source>&amp;Select</source>
         <translation>&amp;Seleccionar</translation>
     </message>
+    <message>
+        <source>Reports</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWidget</name>
@@ -733,31 +827,31 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>No puedo conectarme</translation>
+        <translation type="obsolete">No puedo conectarme</translation>
     </message>
     <message>
         <source>LOG NAME</source>
-        <translation>NOMBRE DE LA LISTA</translation>
+        <translation type="obsolete">NOMBRE DE LA LISTA</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>DESCRIPCIÓN</translation>
+        <translation type="obsolete">DESCRIPCIÓN</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SERVICIO</translation>
+        <translation type="obsolete">SERVICIO</translation>
     </message>
     <message>
         <source>VALID FROM</source>
-        <translation>VÁLIDO DESDE</translation>
+        <translation type="obsolete">VÁLIDO DESDE</translation>
     </message>
     <message>
         <source>VALID TO</source>
-        <translation>VÁLIDO HASTA</translation>
+        <translation type="obsolete">VÁLIDO HASTA</translation>
     </message>
     <message>
         <source>ORIGIN</source>
-        <translation>ORIGEN</translation>
+        <translation type="obsolete">ORIGEN</translation>
     </message>
     <message>
         <source>&amp;Add</source>
@@ -785,11 +879,11 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>La Lista ya existe</translation>
+        <translation type="obsolete">La Lista ya existe</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>¡La lista de reproducción ya existe!</translation>
+        <translation type="obsolete">¡La lista de reproducción ya existe!</translation>
     </message>
     <message>
         <source>Always</source>
@@ -806,7 +900,7 @@ desactivado para el servicio especificado!</translation>
     <message>
         <source>voice tracks associated with this log.
 Continue?</source>
-        <translation> voicetracks asociados a esta lista.
+        <translation type="obsolete"> voicetracks asociados a esta lista.
 ¿Desea continuar?</translation>
     </message>
     <message>
@@ -815,7 +909,7 @@ Continue?</source>
     </message>
     <message>
         <source>TRACKS</source>
-        <translation>PISTAS</translation>
+        <translation type="obsolete">PISTAS</translation>
     </message>
     <message>
         <source>Voice
@@ -829,23 +923,23 @@ de &amp;Voz</translation>
     </message>
     <message>
         <source>MUSIC</source>
-        <translation>MÚSICA</translation>
+        <translation type="obsolete">MÚSICA</translation>
     </message>
     <message>
         <source>TRAFFIC</source>
-        <translation>TRÁFICO</translation>
+        <translation type="obsolete">TRÁFICO</translation>
     </message>
     <message>
         <source>LAST LINKED</source>
-        <translation>ÚLTIMO ENLACE</translation>
+        <translation type="obsolete">ÚLTIMO ENLACE</translation>
     </message>
     <message>
         <source>LAST MODIFIED</source>
-        <translation>ÚLTIMO CAMBIO</translation>
+        <translation type="obsolete">ÚLTIMO CAMBIO</translation>
     </message>
     <message>
         <source>AUTO REFRESH</source>
-        <translation>AUTO ACTUALIZAR</translation>
+        <translation type="obsolete">AUTO ACTUALIZAR</translation>
     </message>
     <message>
         <source>Log
@@ -853,22 +947,18 @@ Report</source>
         <translation>Reporte
 de Listas</translation>
     </message>
-    <message>
-        <source>RDLogEdit</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Unable to delete log, audio deletion error!</source>
-        <translation>¡No es posible eliminar la lista, error de eliminación de audios!</translation>
+        <translation type="obsolete">¡No es posible eliminar la lista, error de eliminación de audios!</translation>
     </message>
     <message>
         <source>RDLogEdit -- Database Skew</source>
-        <translation>RDLogEdit -- Asimetría en la Base de Datos</translation>
+        <translation type="obsolete">RDLogEdit -- Asimetría en la Base de Datos</translation>
     </message>
     <message>
         <source>This version of RDLogEdit is incompatible with the version installed on the server.
 See your system administrator for an update!</source>
-        <translation>Esta versión de RDLogEdit es incompatible con la versión instalada en el servidor.
+        <translation type="obsolete">Esta versión de RDLogEdit es incompatible con la versión instalada en el servidor.
 ¡Solicite una actualización al administrador!</translation>
     </message>
     <message>
@@ -880,7 +970,63 @@ See your system administrator for an update!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALL</source>
+        <source>Are you sure you want to delete the</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>log?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with this log.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete these</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>logs?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with these logs.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>audio deletion error!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log Name</source>
+        <translation type="unfinished">Nombre de la Lista</translation>
+    </message>
+    <message>
+        <source>Description</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -888,15 +1034,134 @@ See your system administrator for an update!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Filter</source>
+        <source>Music</source>
+        <translation type="unfinished">Música</translation>
+    </message>
+    <message>
+        <source>Traffic</source>
+        <translation type="unfinished">Tráfico</translation>
+    </message>
+    <message>
+        <source>Tracks</source>
+        <translation type="unfinished">Pistas</translation>
+    </message>
+    <message>
+        <source>Valid From</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Clear</source>
+        <source>Valid To</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Show Only Recent Logs</source>
+        <source>Auto Refresh</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Origin</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Linked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Modified</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RenderDialog</name>
+    <message>
+        <source>Render Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering Log...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render Progress</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart/Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render To</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation type="unfinished">Seleccionar</translation>
+    </message>
+    <message>
+        <source>Audio Parameters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[now]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>As Specified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Virtual Start Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Only Selected Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Include</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Stop Rendering</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Treat as PLAY</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>At STOP transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Render</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">&amp;Cancelar</translation>
+    </message>
+    <message>
+        <source>Filename</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -968,31 +1233,31 @@ Track</source>
     </message>
     <message>
         <source>TIME</source>
-        <translation>TIEMPO</translation>
+        <translation type="obsolete">TIEMPO</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation>TRANS</translation>
+        <translation type="obsolete">TRANS</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>CARTUCHO</translation>
+        <translation type="obsolete">CARTUCHO</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPO</translation>
+        <translation type="obsolete">GRUPO</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DURACIÓN</translation>
+        <translation type="obsolete">DURACIÓN</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TÍTULO</translation>
+        <translation type="obsolete">TÍTULO</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTISTA</translation>
+        <translation type="obsolete">ARTISTA</translation>
     </message>
     <message>
         <source>Do Over</source>
@@ -1126,12 +1391,52 @@ sólo podrás editar transiciones ya existentes.</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALBUM</source>
+        <source>LABEL</source>
+        <translation type="obsolete">ETIQUETA</translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>LABEL</source>
-        <translation type="unfinished">ETIQUETA</translation>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Talk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished">Cartucho</translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">Título</translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished">Artista</translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished">Etiqueta</translation>
     </message>
 </context>
 </TS>
