@@ -2,7 +2,7 @@
 //
 // The User Login/Logout Utility for Rivendell.
 //
-//   (C) Copyright 2002-2008,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,146 +21,84 @@
 #include <stdlib.h>
 
 #include <qapplication.h>
-#include <qwindowsstyle.h>
-#include <qpainter.h>
-#include <qsqldatabase.h>
 #include <qmessagebox.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qtextcodec.h>
 #include <qtranslator.h>
 
-#include <rd.h>
-#include <rduser.h>
-#include <rdripc.h>
-#include <rdcheck_daemons.h>
-#include <rdcmd_switch.h>
-#include <rddbheartbeat.h>
+#include <rdapplication.h>
 #include <rddb.h>
-#include <dbversion.h>
 
-#include <rdlogin.h>
+#include "rdlogin.h"
 
 //
 // Icons
 //
 #include "../icons/rivendell-22x22.xpm"
 
-MainWidget::MainWidget(QWidget *parent)
-  :QWidget(parent)
+MainWidget::MainWidget(RDConfig *c,QWidget *parent)
+  : RDWidget(c,parent)
 {
+  login_resize=false;
   login_user_width=160;
 
   QString str;
   QString sql;
   RDSqlQuery *q;
-  bool skip_db_check=false;
-  unsigned schema=0;
-
-  //
-  // Read Command Options
-  //
-  RDCmdSwitch *cmd=new RDCmdSwitch(qApp->argc(),qApp->argv(),"rdlogin","\n");
-  for(unsigned i=0;i<cmd->keys();i++) {
-    if(cmd->key(i)=="--skip-db-check") {
-      skip_db_check=true;
-    }
-  }
-  delete cmd;
+  QString err_msg;
 
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
+  setMinimumSize(sizeHint());
   setMaximumHeight(sizeHint().height());
 
-  //
-  // Generate Fonts
-  //
-  QFont default_font("Helvetica",12,QFont::Normal);
-  default_font.setPixelSize(12);
-  qApp->setFont(default_font);
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-  QFont label_font=QFont("Helvetica",16,QFont::Bold);
-  label_font.setPixelSize(12);
-  QFont small_label_font=QFont("Helvetica",12,QFont::Bold);
-  small_label_font.setPixelSize(12);
-  QFont line_edit_font=QFont("Helvetica",12,QFont::Normal);
-  line_edit_font.setPixelSize(12);
-
   //
   // Create And Set Icon
   //
   login_rivendell_map=new QPixmap(rivendell_22x22_xpm);
-  setIcon(*login_rivendell_map);
+  setWindowIcon(*login_rivendell_map);
 
-  //
-  // Ensure that the system daemons are running
-  //
-  RDInitializeDaemons();
-
-  //
-  // Load Configs
-  //
-  login_config=new RDConfig();
-  login_config->load();
-  login_config->setModuleName("RDLogin");
-
-  str=QString(tr("RDLogin - Station:"));
-  setCaption(QString().sprintf("%s %s",(const char *)str,
-			       (const char *)login_config->stationName()));
-
-  //
-  // Open Database
-  //
-  QString err(tr("rdlogin : "));
-  login_db = RDInitDb(&schema,&err);
-  if(!login_db) {
-    QMessageBox::warning(this,tr("Can't Connect"),err);
-    exit(0);
+  rda=new RDApplication("RDLogin","rdlogin",RDLOGIN_USAGE,this);
+  if(!rda->open(&err_msg)) {
+    QMessageBox::critical(this,"RDLogin - "+tr("Error"),err_msg);
+    exit(1);
   }
-  if((schema!=RD_VERSION_DATABASE)&&(!skip_db_check)) {
-    fprintf(stderr,"rdlogin: database version mismatch, should be %u, is %u\n",
-	    RD_VERSION_DATABASE,schema);
-    exit(256);
+
+  //
+  // Read Command Options
+  //
+  for(unsigned i=0;i<rda->cmdSwitch()->keys();i++) {
+    if(!rda->cmdSwitch()->processed(i)) {
+      QMessageBox::critical(this,"RDLogin - "+tr("Error"),
+			    tr("Unknown command option")+": "+
+			    rda->cmdSwitch()->key(i));
+      exit(2);
+    }
   }
 
+  setWindowTitle("RDLogin");
+
   //
   // RIPC Connection
   //
-  login_ripc=new RDRipc(login_config->stationName());
-  connect(login_ripc,SIGNAL(connected(bool)),this,SLOT(connectedData(bool)));
-  connect(login_ripc,SIGNAL(userChanged()),this,SLOT(userData()));
-  login_ripc->connectHost("localhost",RIPCD_TCP_PORT,
-			  login_config->password());
-
-  //
-  // Station
-  //
-  login_station=new RDStation(login_config->stationName());
-
-  //
-  // System
-  //
-  login_system=new RDSystem();
+  connect(rda->ripc(),SIGNAL(connected(bool)),this,SLOT(connectedData(bool)));
+  connect(rda->ripc(),SIGNAL(userChanged()),this,SLOT(userData()));
+  rda->ripc()->connectHost("localhost",RIPCD_TCP_PORT,
+			  rda->config()->password());
 
   //
   // User Label
   //
   login_label=new QLabel(this);
-  login_label->setFont(label_font);
-  login_label->setAlignment(AlignCenter);
+  login_label->setFont(sectionLabelFont());
+  login_label->setAlignment(Qt::AlignCenter);
   login_label->setText(tr("Current User: unknown"));
 
   //
   // User Name
   //
   login_username_box=new QComboBox(this);
-  login_username_box->setFont(line_edit_font);
   login_username_box->setFocus();
-  QFontMetrics fm(line_edit_font);
+  QFontMetrics fm(font());
   sql="select LOGIN_NAME from USERS where ADMIN_CONFIG_PRIV=\"N\"\
        order by LOGIN_NAME";
   q=new RDSqlQuery(sql);
@@ -176,9 +114,9 @@ MainWidget::MainWidget(QWidget *parent)
     login_user_width=900;
   }
   login_username_label=new QLabel(login_username_box,tr("&Username:"),this);
-  login_username_label->setFont(small_label_font);
-  login_username_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-  if(login_system->showUserList()) {
+  login_username_label->setFont(labelFont());
+  login_username_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
+  if(rda->system()->showUserList()) {
     login_username_edit->hide();
   }
   else {
@@ -189,18 +127,17 @@ MainWidget::MainWidget(QWidget *parent)
   // Password
   //
   login_password_edit=new QLineEdit(this);
-  login_password_edit->setFont(line_edit_font);
   login_password_edit->setEchoMode(QLineEdit::Password);
   login_password_label=new QLabel(login_password_edit,tr("&Password:"),this);
-  login_password_label->setFont(small_label_font);
-  login_password_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  login_password_label->setFont(labelFont());
+  login_password_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
   connect(login_password_edit,SIGNAL(returnPressed()),this,SLOT(loginData()));
 
   //
   // Login Button
   //
   login_button=new QPushButton(this);
-  login_button->setFont(button_font);
+  login_button->setFont(buttonFont());
   login_button->setText(tr("&Set User"));
   connect(login_button,SIGNAL(clicked()),this,SLOT(loginData()));
 
@@ -208,7 +145,7 @@ MainWidget::MainWidget(QWidget *parent)
   // Logout Button
   //
   logout_button=new QPushButton(this);
-  logout_button->setFont(button_font);
+  logout_button->setFont(buttonFont());
   logout_button->setText(tr("&Default\nUser"));
   connect(logout_button,SIGNAL(clicked()),this,SLOT(logoutData()));
 
@@ -216,19 +153,18 @@ MainWidget::MainWidget(QWidget *parent)
   // Cancel Button
   //
   cancel_button=new QPushButton(this);
-  cancel_button->setFont(button_font);
+  cancel_button->setFont(buttonFont());
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
+  login_resize=true;
+
   resizeEvent(NULL);
 }
 
 
 MainWidget::~MainWidget()
 {
-  delete login_db;
-  delete login_ripc;
-  delete login_station;
   delete login_label;
   delete login_username_box;
   delete login_password_edit;
@@ -254,11 +190,7 @@ void MainWidget::connectedData(bool state)
 
 void MainWidget::userData()
 {
-  QString str;
-
-  str=QString(tr("Current User:"));
-  login_label->setText(QString().sprintf("%s %s",(const char *)str,
-					 (const char *)login_ripc->user()));
+  login_label->setText(tr("Current User")+": "+rda->ripc()->user());
   resizeEvent(NULL);
 }
 
@@ -267,18 +199,18 @@ void MainWidget::loginData()
 {
   RDUser *user;
 
-  if(login_system->showUserList()) {
+  if(rda->system()->showUserList()) {
     user=new RDUser(login_username_box->currentText());
   }
   else {
     user=new RDUser(login_username_edit->text());
   }
   if(user->exists()&&user->checkPassword(login_password_edit->text(),false)) {
-    if(login_system->showUserList()) {
-      login_ripc->setUser(login_username_box->currentText());
+    if(rda->system()->showUserList()) {
+      rda->ripc()->setUser(login_username_box->currentText());
     }
     else {
-      login_ripc->setUser(login_username_edit->text());
+      rda->ripc()->setUser(login_username_edit->text());
     }
     login_password_edit->clear();
     delete user;
@@ -294,8 +226,8 @@ void MainWidget::loginData()
 
 void MainWidget::logoutData()
 {
-  QString default_name=login_station->defaultName();
-  login_ripc->setUser(default_name);
+  QString default_name=rda->station()->defaultName();
+  rda->ripc()->setUser(default_name);
   login_password_edit->clear();
   for(int i=0;i<login_username_box->count();i++) {
     if(login_username_box->text(i)==default_name) {
@@ -316,34 +248,36 @@ void MainWidget::cancelData()
 
 void MainWidget::quitMainWidget()
 {
-  login_db->removeDatabase(login_config->mysqlDbname());
   qApp->quit();
 }
 
 
 void MainWidget::resizeEvent(QResizeEvent *e)
 {
-  login_label->setGeometry(0,10,size().width(),21);
-  login_username_box->setGeometry(110,40,size().width()-120,19);
-  login_username_edit->setGeometry(110,40,size().width()-120,19);
-  login_username_label->setGeometry(10,40,85,19);
-  login_password_edit->setGeometry(110,61,size().width()-120,19);
-  login_password_label->setGeometry(10,61,85,19);
-  login_button->setGeometry(size().width()-270,size().height()-60,80,50);
-  logout_button->setGeometry(size().width()-180,size().height()-60,80,50);
-  cancel_button->setGeometry(size().width()-90,size().height()-60,80,50);
+  if(login_resize) {
+    login_label->setGeometry(0,10,size().width(),21);
+    login_username_box->setGeometry(110,40,size().width()-120,19);
+    login_username_edit->setGeometry(110,40,size().width()-120,19);
+    login_username_label->setGeometry(10,40,85,19);
+    login_password_edit->setGeometry(110,61,size().width()-120,19);
+    login_password_label->setGeometry(10,61,85,19);
+    login_button->setGeometry(size().width()-270,size().height()-60,80,50);
+    logout_button->setGeometry(size().width()-180,size().height()-60,80,50);
+    cancel_button->setGeometry(size().width()-90,size().height()-60,80,50);
+  }
 }
 
 
 int main(int argc,char *argv[])
 {
+  QApplication::setStyle(RD_GUI_STYLE);
   QApplication a(argc,argv);
   
   //
   // Load Translations
   //
   QTranslator qt(0);
-  qt.load(QString(QTDIR)+QString("/translations/qt_")+QTextCodec::locale(),
+  qt.load(QString("/usr/share/qt4/translations/qt_")+QTextCodec::locale(),
 	  ".");
   a.installTranslator(&qt);
 
@@ -365,7 +299,9 @@ int main(int argc,char *argv[])
   //
   // Start Event Loop
   //
-  MainWidget *w=new MainWidget();
+  RDConfig *config=new RDConfig();
+  config->load();
+  MainWidget *w=new MainWidget(config);
   a.setMainWidget(w);
   w->setGeometry(QRect(QPoint(0,0),w->sizeHint()));
   w->show();
