@@ -2,7 +2,7 @@
 //
 // List a Rivendell Log Event
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,47 +18,29 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <vector>
-
-#include <qdialog.h>
-#include <qstring.h>
-#include <qtextedit.h>
-#include <qpainter.h>
 #include <qmessagebox.h>
+#include <qpainter.h>
 
-#include <rddb.h>
-#include <rd.h>
-#include <rdevent.h>
-#include <rdcreate_log.h>
+#include <rdescape_string.h>
 
-#include <list_events.h>
-#include <add_event.h>
-#include <edit_event.h>
-#include <globals.h>
-#include <rename_item.h>
+#include "add_event.h"
+#include "edit_event.h"
+#include "globals.h"
+#include "list_events.h"
+#include "rename_item.h"
 
 ListEvents::ListEvents(QString *eventname,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
   QStringList services_list;
-  QString str1=tr("Log Events - User: ");
-  setCaption(QString().sprintf("%s%s",(const char *)str1,
-			       (const char *)rdripc->user()));
   edit_eventname=eventname;
 
+  setWindowTitle("RDLogManager - "+tr("Log Events"));
+
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-
-  //
-  // Create Fonts
-  //
-  QFont bold_font=QFont("Helvetica",12,QFont::Bold);
-  bold_font.setPixelSize(12);
-  QFont font=QFont("Helvetica",12,QFont::Normal);
-  font.setPixelSize(12);
+  setMinimumSize(sizeHint());
 
   //
   // Event Filter
@@ -66,30 +48,30 @@ ListEvents::ListEvents(QString *eventname,QWidget *parent)
   edit_filter_box=new QComboBox(this);
   edit_filter_label=new QLabel(edit_filter_box,tr("Filter:"),this);
   edit_filter_label->setGeometry(10,10,50,20);
-  edit_filter_label->setFont(bold_font);
-  edit_filter_label->setAlignment(AlignRight|AlignVCenter);
+  edit_filter_label->setFont(labelFont());
+  edit_filter_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(edit_filter_box,SIGNAL(activated(int)),
 	  this,SLOT(filterActivatedData(int)));
 
   //
   // Events List
   //
-  edit_events_list=new QListView(this);
+  edit_events_list=new Q3ListView(this);
   edit_events_list->setAllColumnsShowFocus(true);
   edit_events_list->setItemMargin(5);
   edit_events_list->addColumn(tr("Name"));
   edit_events_list->addColumn(tr("Properties"));
   edit_events_list->addColumn(tr("Color"));
-  edit_events_list->setColumnAlignment(2,AlignCenter);
+  edit_events_list->setColumnAlignment(2,Qt::AlignCenter);
   connect(edit_events_list,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
-	  this,SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
+	  this,SLOT(doubleClickedData(Q3ListViewItem *,const QPoint &,int)));
 
   //
   //  Add Button
   //
   edit_add_button=new QPushButton(this);
-  edit_add_button->setFont(bold_font);
+  edit_add_button->setFont(buttonFont());
   edit_add_button->setText(tr("&Add"));
   connect(edit_add_button,SIGNAL(clicked()),this,SLOT(addData()));
     
@@ -97,7 +79,7 @@ ListEvents::ListEvents(QString *eventname,QWidget *parent)
   //  Edit Button
   //
   edit_edit_button=new QPushButton(this);
-  edit_edit_button->setFont(bold_font);
+  edit_edit_button->setFont(buttonFont());
   edit_edit_button->setText(tr("&Edit"));
   connect(edit_edit_button,SIGNAL(clicked()),this,SLOT(editData()));
     
@@ -105,7 +87,7 @@ ListEvents::ListEvents(QString *eventname,QWidget *parent)
   //  Delete Button
   //
   edit_delete_button=new QPushButton(this);
-  edit_delete_button->setFont(bold_font);
+  edit_delete_button->setFont(buttonFont());
   edit_delete_button->setText(tr("&Delete"));
   connect(edit_delete_button,SIGNAL(clicked()),this,SLOT(deleteData()));
     
@@ -113,7 +95,7 @@ ListEvents::ListEvents(QString *eventname,QWidget *parent)
   //  Rename Button
   //
   edit_rename_button=new QPushButton(this);
-  edit_rename_button->setFont(bold_font);
+  edit_rename_button->setFont(buttonFont());
   edit_rename_button->setText(tr("&Rename"));
   connect(edit_rename_button,SIGNAL(clicked()),this,SLOT(renameData()));
     
@@ -121,7 +103,7 @@ ListEvents::ListEvents(QString *eventname,QWidget *parent)
   //  Close Button
   //
   edit_close_button=new QPushButton(this);
-  edit_close_button->setFont(bold_font);
+  edit_close_button->setFont(buttonFont());
   edit_close_button->setText(tr("&OK"));
   connect(edit_close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
@@ -129,7 +111,7 @@ ListEvents::ListEvents(QString *eventname,QWidget *parent)
   //  Ok Button
   //
   edit_ok_button=new QPushButton(this);
-  edit_ok_button->setFont(bold_font);
+  edit_ok_button->setFont(buttonFont());
   edit_ok_button->setText(tr("&Ok"));
   connect(edit_ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -137,7 +119,7 @@ ListEvents::ListEvents(QString *eventname,QWidget *parent)
   //  Cancel Button
   //
   edit_cancel_button=new QPushButton(this);
-  edit_cancel_button->setFont(bold_font);
+  edit_cancel_button->setFont(buttonFont());
   edit_cancel_button->setText(tr("&Cancel"));
   connect(edit_cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
@@ -161,16 +143,12 @@ ListEvents::ListEvents(QString *eventname,QWidget *parent)
   edit_filter_box->insertItem(tr("ALL"));
   edit_filter_box->insertItem(tr("NONE"));
 
-  if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
-    services_list = rduser->services();
-  } else { // RDStation::HostSec
-    QString sql="select NAME from SERVICES";
-    RDSqlQuery *q=new RDSqlQuery(sql);
-    while(q->next()) {
-      services_list.append( q->value(0).toString() );
-    }
-    delete q;
-  } 
+  QString sql="select NAME from SERVICES";
+  RDSqlQuery *q=new RDSqlQuery(sql);
+  while(q->next()) {
+    services_list.append( q->value(0).toString() );
+  }
+  delete q;
   services_list.sort();
   for ( QStringList::Iterator it = services_list.begin(); 
         it != services_list.end();
@@ -256,7 +234,7 @@ void ListEvents::addData()
     }
   }
   delete event_dialog;
-  QListViewItem *item=new QListViewItem(edit_events_list);
+  Q3ListViewItem *item=new Q3ListViewItem(edit_events_list);
   item->setText(0,logname);
   RefreshItem(item,&new_events);
   edit_events_list->setSelected(item,true);
@@ -268,7 +246,7 @@ void ListEvents::editData()
 {
   std::vector<QString> new_events;
 
-  QListViewItem *item=edit_events_list->selectedItem();
+  Q3ListViewItem *item=edit_events_list->selectedItem();
   if(item==NULL) {
     return;
   }
@@ -286,30 +264,24 @@ void ListEvents::deleteData()
 {
   int n;
   QString clock_list;
-  QString str1;
-  QString str2;
 
-  QListViewItem *item=edit_events_list->selectedItem();
+  Q3ListViewItem *item=edit_events_list->selectedItem();
   if(item==NULL) {
     return;
   }
-  str1=QString(tr("Are you sure you want to\ndelete"));
-  if(QMessageBox::question(this,tr("Delete Event"),
-			   QString().sprintf("%s \'%s\'?",(const char *)str1,
-					     (const char *)item->text(0)),
+  if(QMessageBox::question(this,"RDLogManager - "+tr("Delete Event"),
+			   tr("Are you sure you want to delete")+" \""+
+			   item->text(0)+"\"?",
 			  QMessageBox::Yes,QMessageBox::No)
      !=QMessageBox::Yes) {
     return;
   }
   if((n=ActiveEvents(item->text(0),&clock_list))>0) {
-    str1=QString(tr("is in use in the following clocks:"));
-    str2=QString(tr("Do you still want to delete it?"));
-    if(QMessageBox::warning(this,tr("Event In Use"),
-			 QString().sprintf("\'%s\' %s\n\n%s\n%s",
-					   (const char *)item->text(0),
-					   (const char *)str1,
-					   (const char *)clock_list,
-					   (const char *)str2),
+    if(QMessageBox::warning(this,"RDLogManager - "+tr("Event In Use"),
+			    "\""+item->text(0)+"\" "+
+			    tr("is in use in the following clocks")+":\n\n"+
+			    clock_list+"\n"+
+			    tr("Do you still want to delete it?"),
 			    QMessageBox::Yes,QMessageBox::No)!=
        QMessageBox::Yes) {
       return;
@@ -325,9 +297,7 @@ void ListEvents::renameData()
 {
   QString sql;
   RDSqlQuery *q;
-  RDSqlQuery *q1;
-  QString clock_name_esc;
-  QListViewItem *item=edit_events_list->selectedItem();
+  Q3ListViewItem *item=edit_events_list->selectedItem();
   if(item==NULL) {
     return;
   }
@@ -342,36 +312,18 @@ void ListEvents::renameData()
   //
   // Rename Clock References
   //
-  sql="select NAME from CLOCKS";
+  sql=QString("update CLOCK_LINES set ")+
+    "EVENT_NAME=\""+RDEscapeString(new_name)+"\" where "+
+    "EVENT_NAME=\""+RDEscapeString(item->text(0))+"\"";
   q=new RDSqlQuery(sql);
-  while(q->next()) {
-    clock_name_esc=q->value(0).toString();
-    clock_name_esc.replace(" ","_");
-    sql=QString().sprintf("update %s_CLK set EVENT_NAME=\"%s\"\
-                           where EVENT_NAME=\"%s\"",
-			  (const char *)clock_name_esc,
-			  (const char *)new_name,
-			  (const char *)item->text(0));
-    q1=new RDSqlQuery(sql);
-    delete q1;
-  }
   delete q;
 
   //
-  // Rename Meta Tables
+  // Rename Event Line References
   //
-  QString old_name_esc=item->text(0);
-  old_name_esc.replace(" ","_");
-  QString new_name_esc=new_name;
-  new_name_esc.replace(" ","_");
-  sql=QString().sprintf("alter table %s_PRE rename to %s_PRE",
-			(const char *)old_name_esc,
-			(const char *)new_name_esc);
-  q=new RDSqlQuery(sql);
-  delete q;
-  sql=QString().sprintf("alter table %s_POST rename to %s_POST",
-			(const char *)old_name_esc,
-			(const char *)new_name_esc);
+  sql=QString("update EVENT_LINES set ")+
+    "EVENT_NAME=\""+RDEscapeString(new_name)+"\" where "+
+    "EVENT_NAME=\""+RDEscapeString(item->text(0))+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 
@@ -405,7 +357,7 @@ void ListEvents::filterActivatedData(int id)
 }
 
 
-void ListEvents::doubleClickedData(QListViewItem *item,const QPoint &,int)
+void ListEvents::doubleClickedData(Q3ListViewItem *item,const QPoint &,int)
 {
   if(edit_eventname==NULL) {
     editData();
@@ -424,7 +376,7 @@ void ListEvents::closeData()
 
 void ListEvents::okData()
 {
-  QListViewItem *item=edit_events_list->selectedItem();
+  Q3ListViewItem *item=edit_events_list->selectedItem();
   *event_filter=edit_filter_box->currentText();
   if(item==NULL) {
     done(-1);
@@ -478,25 +430,25 @@ void ListEvents::RefreshList()
   QString sql=QString().sprintf("select NAME,PROPERTIES,COLOR from EVENTS %s",
 				(const char *)filter);
   RDSqlQuery *q=new RDSqlQuery(sql);
-  QListViewItem *item=NULL;
+  Q3ListViewItem *item=NULL;
   while(q->next()) {
-    item=new QListViewItem(edit_events_list);
+    item=new Q3ListViewItem(edit_events_list);
     WriteItem(item,q);
   }
   delete q;
 }
 
 
-void ListEvents::RefreshItem(QListViewItem *item,
+void ListEvents::RefreshItem(Q3ListViewItem *item,
 			     std::vector<QString> *new_events)
 {
-  QListViewItem *new_item;
+  Q3ListViewItem *new_item;
   UpdateItem(item,item->text(0));
 
   if(new_events!=NULL) {
     for(unsigned i=0;i<new_events->size();i++) {
       if((new_item=edit_events_list->findItem(new_events->at(i),0))==NULL) {
-	new_item=new QListViewItem(edit_events_list);
+	new_item=new Q3ListViewItem(edit_events_list);
       }
       UpdateItem(new_item,new_events->at(i));
     }
@@ -504,7 +456,7 @@ void ListEvents::RefreshItem(QListViewItem *item,
 }
 
 
-void ListEvents::UpdateItem(QListViewItem *item,QString name)
+void ListEvents::UpdateItem(Q3ListViewItem *item,QString name)
 {
   QString sql=QString().sprintf("select NAME,PROPERTIES,COLOR from EVENTS\
                                  where NAME=\"%s\"",(const char *)name);
@@ -517,7 +469,7 @@ void ListEvents::UpdateItem(QListViewItem *item,QString name)
 }
 
 
-void ListEvents::WriteItem(QListViewItem *item,RDSqlQuery *q)
+void ListEvents::WriteItem(Q3ListViewItem *item,RDSqlQuery *q)
 {
   QPixmap *pix;
   QPainter *p=new QPainter();
@@ -539,16 +491,13 @@ int ListEvents::ActiveEvents(QString event_name,QString *clock_list)
   int n=0;
   QString sql;
   RDSqlQuery *q,*q1;
-  QString clockname;
 
   sql="select NAME from CLOCKS";
   q=new RDSqlQuery(sql);
   while(q->next()) {
-    clockname=q->value(0).toString();
-    clockname.replace(" ","_");
-    sql=QString().sprintf("select EVENT_NAME from %s_CLK\
-                           where EVENT_NAME=\"%s\"",(const char *)clockname,
-			  (const char *)event_name);
+    sql=QString("select EVENT_NAME from CLOCK_LINES where ")+
+      "CLOCK_NAME=\""+RDEscapeString(q->value(0).toString())+"\" && "+
+      "EVENT_NAME=\""+RDEscapeString(event_name)+"\"";
     q1=new RDSqlQuery(sql);
     if(q1->first()) {
       *clock_list+=
@@ -566,7 +515,6 @@ void ListEvents::DeleteEvent(QString event_name)
 {
   QString sql;
   RDSqlQuery *q,*q1;
-  QString clockname;
   QString base_name=event_name;
   base_name.replace(" ","_");
 
@@ -576,11 +524,9 @@ void ListEvents::DeleteEvent(QString event_name)
   sql="select NAME from CLOCKS";
   q=new RDSqlQuery(sql);
   while(q->next()) {
-    clockname=q->value(0).toString();
-    clockname.replace(" ","_");
-    sql=QString().sprintf("delete from %s_CLK\
-                           where EVENT_NAME=\"%s\"",(const char *)clockname,
-			  (const char *)event_name);
+    sql=QString("delete from CLOCK_LINES where ")+
+      "CLOCK_NAME=\""+RDEscapeString(q->value(0).toString())+"\" && "+
+      "EVENT_NAME=\""+RDEscapeString(event_name)+"\"";
     q1=new RDSqlQuery(sql);
     delete q1;
   }
@@ -599,13 +545,10 @@ void ListEvents::DeleteEvent(QString event_name)
   //
   sql=QString().sprintf("delete from EVENTS where NAME=\"%s\"",
 			(const char *)event_name);
-  q=new RDSqlQuery(sql);
-  delete q;
-  sql=QString().sprintf("drop table %s_PRE",(const char *)base_name);
-  q=new RDSqlQuery(sql);
-  delete q;
-  sql=QString().sprintf("drop table %s_POST",(const char *)base_name);
-  q=new RDSqlQuery(sql);
+  RDSqlQuery::apply(sql);
+  sql=QString("delete from EVENT_LINES where ")+
+    "EVENT_NAME=\""+RDEscapeString(event_name)+"\"";
+  RDSqlQuery::apply(sql);
 }
 
 
