@@ -2,7 +2,7 @@
 //
 // Select a Set of Dates for a Rivendell Report
 //
-//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,42 +19,37 @@
 //
 
 #include <qpushbutton.h>
-#include <qlabel.h>
 #include <qmessagebox.h>
 #include <qfile.h>
 
 #include <rddatedialog.h>
-#include <rdreport.h>
 #include <rddatedecode.h>
-#include <rddb.h>
-#include <globals.h>
-#include <pick_report_dates.h>
+#include <rdescape_string.h>
+#include <rdreport.h>
+
+#include "globals.h"
+#include "pick_report_dates.h"
 
 PickReportDates::PickReportDates(const QString &svcname,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
   QString sql;
   RDSqlQuery *q;
   QDate yesterday_date=QDate::currentDate().addDays(-1);
-
   edit_svcname=svcname;
-  setCaption(tr("Select Report Dates"));
+
+  setWindowTitle("RDLogManager - "+tr("Select Report Dates"));
 	     
   //
   // Fix the Window Size
   //
-  setMaximumWidth(sizeHint().width());
-  setMaximumHeight(sizeHint().height());
-  setMinimumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
+  setMaximumSize(sizeHint());
+  setMinimumSize(sizeHint());
 
   //
-  // Create Fonts
+  // Dialogs
   //
-  QFont bold_font=QFont("Helvetica",12,QFont::Bold);
-  bold_font.setPixelSize(12);
-  QFont font=QFont("Helvetica",12,QFont::Normal);
-  font.setPixelSize(12);
+  edit_viewreport_dialog=new ViewReportDialog(this);
 
   //
   // Report List
@@ -63,11 +58,11 @@ PickReportDates::PickReportDates(const QString &svcname,QWidget *parent)
   edit_report_box->setGeometry(75,11,sizeHint().width()-85,19);
   QLabel *label=new QLabel(edit_report_box,tr("&Report:"),this);
   label->setGeometry(10,11,60,19);
-  label->setFont(bold_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-  sql=QString().sprintf("select REPORT_NAME from REPORT_SERVICES\
-                         where SERVICE_NAME=\"%s\" order by REPORT_NAME",
-			(const char *)svcname);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
+  sql=QString("select REPORT_NAME from REPORT_SERVICES where ")+
+    "SERVICE_NAME=\""+RDEscapeString(svcname)+"\" "+
+    "order by REPORT_NAME";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     edit_report_box->insertItem(q->value(0).toString());
@@ -79,14 +74,15 @@ PickReportDates::PickReportDates(const QString &svcname,QWidget *parent)
   //
   edit_startdate_edit=new QDateEdit(this);
   edit_startdate_edit->setGeometry(150,35,100,22);
+  edit_startdate_edit->setDisplayFormat("MM/dd/yyyy");
   edit_startdate_edit->setDate(yesterday_date);
   label=new QLabel(edit_startdate_edit,tr("&Start Date:"),this);
   label->setGeometry(75,36,70,19);
-  label->setFont(bold_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   QPushButton *button=new QPushButton(this);
   button->setGeometry(260,33,50,27);
-  button->setFont(font);
+  button->setFont(subButtonFont());
   button->setText(tr("&Select"));
   connect(button,SIGNAL(clicked()),this,SLOT(selectStartDateData()));
 
@@ -95,14 +91,15 @@ PickReportDates::PickReportDates(const QString &svcname,QWidget *parent)
   //
   edit_enddate_edit=new QDateEdit(this);
   edit_enddate_edit->setGeometry(150,65,100,22);
+  edit_enddate_edit->setDisplayFormat("MM/dd/yyyy");
   edit_enddate_edit->setDate(yesterday_date);
   label=new QLabel(edit_enddate_edit,tr("&End Date:"),this);
   label->setGeometry(75,66,70,19);
-  label->setFont(bold_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   button=new QPushButton(this);
   button->setGeometry(260,63,50,27);
-  button->setFont(font);
+  button->setFont(subButtonFont());
   button->setText(tr("&Select"));
   connect(button,SIGNAL(clicked()),this,SLOT(selectEndDateData()));
 
@@ -111,7 +108,7 @@ PickReportDates::PickReportDates(const QString &svcname,QWidget *parent)
   //
   button=new QPushButton(this);
   button->setGeometry(10,sizeHint().height()-60,80,50);
-  button->setFont(bold_font);
+  button->setFont(buttonFont());
   button->setText(tr("&Generate\nReport"));
   connect(button,SIGNAL(clicked()),this,SLOT(generateData()));
 
@@ -121,7 +118,7 @@ PickReportDates::PickReportDates(const QString &svcname,QWidget *parent)
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
   button->setDefault(true);
-  button->setFont(bold_font);
+  button->setFont(buttonFont());
   button->setText(tr("C&lose"));
   connect(button,SIGNAL(clicked()),this,SLOT(closeData()));
 }
@@ -129,6 +126,7 @@ PickReportDates::PickReportDates(const QString &svcname,QWidget *parent)
 
 PickReportDates::~PickReportDates()
 {
+  delete edit_viewreport_dialog;
 }
 
 
@@ -174,41 +172,34 @@ void PickReportDates::selectEndDateData()
 void PickReportDates::generateData()
 {
   if(edit_startdate_edit->date()>edit_enddate_edit->date()) {
-    QMessageBox::warning(this,tr("Invalid Date Range"),
+    QMessageBox::warning(this,"RDLogManager - "+tr("Invalid Date Range"),
 		 tr("The end date cannot be earlier than the start date!"));
     return;
   }
   RDReport *report=
-    new RDReport(edit_report_box->currentText(),rdstation_conf,log_config,this);
+    new RDReport(edit_report_box->currentText(),rda->station(),rda->config(),this);
   if((edit_startdate_edit->date()!=edit_enddate_edit->date())&&
      (!RDReport::multipleDaysAllowed(report->filter()))) {
-    QMessageBox::warning(this,tr("Invalid Date Range"),
+    QMessageBox::warning(this,"RDLogManager - "+tr("Invalid Date Range"),
 			 tr("This report type cannot span multiple dates!"));
     delete report;
     return;
   }
   if((edit_startdate_edit->date().month()!=edit_enddate_edit->date().month())&&
      (!RDReport::multipleMonthsAllowed(report->filter()))) {
-    QMessageBox::warning(this,tr("Invalid Date Range"),
+    QMessageBox::warning(this,"RDLogManager - "+tr("Invalid Date Range"),
 			 tr("This report type cannot span multiple months!"));
     delete report;
     return;
   }
-#ifdef WIN32
-  QString filename=
-    RDDateDecode(report->exportPath(RDReport::Windows),
-		 edit_startdate_edit->date(),rdstation_conf,log_config,
-		 edit_svcname);
-#else
   QString filename=
     RDDateDecode(report->exportPath(RDReport::Linux),
-		 edit_startdate_edit->date(),rdstation_conf,log_config,
+		 edit_startdate_edit->date(),rda->station(),rda->config(),
 		 edit_svcname);
-#endif
   QFile file(filename);
   if(file.exists()) {
-    if(QMessageBox::question(this,"File Exists",
-			     "The report file already exists.  Overwrite?",
+    if(QMessageBox::question(this,"RDLogManager - "+tr("File Exists"),
+			     tr("The report file already exists.  Overwrite?"),
 			     QMessageBox::Yes,QMessageBox::No)!=
        QMessageBox::Yes) {
       delete report;
@@ -217,21 +208,20 @@ void PickReportDates::generateData()
   }
   QString out_path;
   report->generateReport(edit_startdate_edit->date(),
-			 edit_enddate_edit->date(),rdstation_conf,&out_path);
+			 edit_enddate_edit->date(),rda->station(),&out_path);
   switch(report->errorCode()) {
-      case RDReport::ErrorOk:
-	QMessageBox::information(this,tr("Report Complete"),
-				 tr("Report generated in")+" \""+out_path+
-				 "\".");
-	break;
+  case RDReport::ErrorOk:
+    edit_viewreport_dialog->exec(out_path);
+    break;
 
-      case RDReport::ErrorCantOpen:
-	QMessageBox::warning(this,"File Error","Unable to open report file at"+
-			     QString("\"")+out_path+"\"!");
-	break;
+  case RDReport::ErrorCantOpen:
+    QMessageBox::warning(this,"RDLogManager - "+tr("File Error"),
+			 tr("Unable to open report file at")+
+			 QString("\"")+out_path+"\"!");
+    break;
 
-      case RDReport::ErrorCanceled:
-	break;
+  case RDReport::ErrorCanceled:
+    break;
   }
   delete report;
 }
