@@ -1,9 +1,11 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AddClock</name>
     <message>
         <source>Add Log Clock</source>
-        <translation>Añadir Torta </translation>
+        <translation type="obsolete">Añadir Torta </translation>
     </message>
     <message>
         <source>&amp;New Clock Name:</source>
@@ -17,6 +19,10 @@
         <source>&amp;Cancel</source>
         <translation>&amp;Cancelar</translation>
     </message>
+    <message>
+        <source>Add Clock</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AddEvent</name>
@@ -48,7 +54,7 @@
     <name>EditClock</name>
     <message>
         <source>Edit Clock:</source>
-        <translation>Editar Torta:</translation>
+        <translation type="obsolete">Editar Torta:</translation>
     </message>
     <message>
         <source>Code:</source>
@@ -143,7 +149,7 @@ Do you want to save?</source>
     </message>
     <message>
         <source>--- End of clock ---</source>
-        <translation>--- Fin de la torta ---</translation>
+        <translation type="obsolete">--- Fin de la torta ---</translation>
     </message>
     <message>
         <source>Invalid Code</source>
@@ -196,6 +202,22 @@ horario</translation>
 </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Clock</source>
+        <translation type="unfinished">Editar Torta</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>That event does not exist.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -225,35 +247,35 @@ horario</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>CARTUCHO</translation>
+        <translation type="obsolete">CARTUCHO</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPO</translation>
+        <translation type="obsolete">GRUPO</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DURACIÓN</translation>
+        <translation type="obsolete">DURACIÓN</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TÍTULO</translation>
+        <translation type="obsolete">TÍTULO</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTISTA</translation>
+        <translation type="obsolete">ARTISTA</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>INICIO</translation>
+        <translation type="obsolete">INICIO</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>FIN</translation>
+        <translation type="obsolete">FIN</translation>
     </message>
     <message>
         <source>TYPE</source>
-        <translation>TIPO</translation>
+        <translation type="obsolete">TIPO</translation>
     </message>
     <message>
         <source>ALL</source>
@@ -329,11 +351,11 @@ horario</translation>
     </message>
     <message>
         <source>TRANSITION</source>
-        <translation>TRANSICIÓN</translation>
+        <translation type="obsolete">TRANSICIÓN</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>CUENTA</translation>
+        <translation type="obsolete">CUENTA</translation>
     </message>
     <message>
         <source>None</source>
@@ -443,7 +465,7 @@ List</source>
     </message>
     <message>
         <source>Timed(Wait</source>
-        <translation>Tiempo(Esperar</translation>
+        <translation type="obsolete">Tiempo(Esperar</translation>
     </message>
     <message>
         <source>, Post</source>
@@ -531,6 +553,58 @@ Do you want to overwrite it?</source>
         <source>and code</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Timed(Wait)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished">Duración</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished">Inicio</translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Fin</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished">Cuenta</translation>
+    </message>
+    <message>
+        <source>Artist Separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEventLine</name>
@@ -589,7 +663,7 @@ un evento ya existente.</translation>
     <name>EditGrid</name>
     <message>
         <source>Edit Grid:</source>
-        <translation>Editar Parrilla:</translation>
+        <translation type="obsolete">Editar Parrilla:</translation>
     </message>
     <message>
         <source>&amp;Close</source>
@@ -620,6 +694,10 @@ un evento ya existente.</translation>
         <source>This operation cannot be undone!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Grid</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditNote</name>
@@ -659,6 +737,41 @@ un evento ya existente.</translation>
         <translation>&amp;Cancelar</translation>
     </message>
 </context>
+<context>
+    <name>EditSchedCodeRules</name>
+    <message>
+        <source>Edit Rules for Code</source>
+        <translation type="unfinished">Editar reglas para el código</translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished">&amp;Aceptar</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">&amp;Cancelar</translation>
+    </message>
+    <message>
+        <source>Code:</source>
+        <translation type="unfinished">Código:</translation>
+    </message>
+    <message>
+        <source>Max. in a row:</source>
+        <translation type="unfinished">Máx. por fila:</translation>
+    </message>
+    <message>
+        <source>Min. wait:</source>
+        <translation type="unfinished">Espera Mín.:</translation>
+    </message>
+    <message>
+        <source>Do not schedule after:</source>
+        <translation type="unfinished">No programar después de:</translation>
+    </message>
+    <message>
+        <source>Or after:</source>
+        <translation type="unfinished">O después de:</translation>
+    </message>
+</context>
 <context>
     <name>EditSchedRules</name>
     <message>
@@ -727,6 +840,14 @@ Do you want to save?</source>
         <source>Import Rules from Clock</source>
         <translation>Importar reglas desde Torta</translation>
     </message>
+    <message>
+        <source>None</source>
+        <translation type="obsolete">Ninguno</translation>
+    </message>
+    <message>
+        <source>(This setting is deprecated and has been moved to events)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditTrack</name>
@@ -779,11 +900,11 @@ Do you want to save?</source>
     </message>
     <message>
         <source>No Errors</source>
-        <translation>No hubo errores</translation>
+        <translation type="unfinished">No hubo errores</translation>
     </message>
     <message>
         <source>No exceptions found.</source>
-        <translation>No se encontraron errores.</translation>
+        <translation type="obsolete">No se encontraron errores.</translation>
     </message>
     <message>
         <source>This will also delete the</source>
@@ -792,7 +913,7 @@ Do you want to save?</source>
     <message>
         <source>voice tracks associated with this log.
 Continue?</source>
-        <translation>pistas de voz asociadas a esta lista.
+        <translation type="obsolete">pistas de voz asociadas a esta lista.
 ¿Continuar?</translation>
     </message>
     <message>
@@ -816,7 +937,7 @@ Continue?</source>
 will remove any merged Music or Traffic events.
 
 Recreate?</source>
-        <translation>ya existe.  Al recrearlo
+        <translation type="obsolete">ya existe.  Al recrearlo
 se eliminará cualquier evento de Música o Tráfico fusionados.
 
 ¿Recrear?</translation>
@@ -832,13 +953,13 @@ se eliminará cualquier evento de Música o Tráfico fusionados.
     <message>
         <source>already contains merged music and/or traffic data.
 Remerging it will remove this data.  Remerge?</source>
-        <translation>ya contiene datos de música o tráfico fusionados.
+        <translation type="obsolete">ya contiene datos de música o tráfico fusionados.
 Remezclarlos removerá estos datos.  ¿Remezclar?</translation>
     </message>
     <message>
         <source>already contains merged traffic data.  Remerging it
 will remove this data.  Remerge?</source>
-        <translation>ya contiene datos de tráfico fusionados.  Remezclarlos
+        <translation type="obsolete">ya contiene datos de tráfico fusionados.  Remezclarlos
 removerá estos datos.  ¿Remezclar?</translation>
     </message>
     <message>
@@ -855,7 +976,7 @@ removerá estos datos.  ¿Remezclar?</translation>
     </message>
     <message>
         <source>Generate Log - User: </source>
-        <translation>Generar lista - Usuario: </translation>
+        <translation type="obsolete">Generar lista - Usuario: </translation>
     </message>
     <message>
         <source>Error</source>
@@ -881,6 +1002,50 @@ removerá estos datos.  ¿Remezclar?</translation>
         <source>Unable to link traffic log</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Generate Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already exists.  Recreating it</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>will remove any merged Music or Traffic events.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recreate?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with this log.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already contains merged music and/or traffic data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remerging it will remove this data.  Remerge?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already contains merged traffic data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cannot be relinked.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No broken rules or validation exceptions found.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImportListView</name>
@@ -894,15 +1059,15 @@ removerá estos datos.  ¿Remezclar?</translation>
     </message>
     <message>
         <source>Set PLAY Transition</source>
-        <translation>Asignar transición REPROD</translation>
+        <translation type="obsolete">Asignar transición REPROD</translation>
     </message>
     <message>
         <source>Set SEGUE Transition</source>
-        <translation>Asignar transición SEGUE</translation>
+        <translation type="obsolete">Asignar transición SEGUE</translation>
     </message>
     <message>
         <source>Set STOP Transition</source>
-        <translation>Asignar transición PARAR</translation>
+        <translation type="obsolete">Asignar transición PARAR</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -944,6 +1109,18 @@ removerá estos datos.  ¿Remezclar?</translation>
         <source>Edit Voice Track</source>
         <translation>Editar pista de voz</translation>
     </message>
+    <message>
+        <source>PLAY Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SEGUE Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>STOP Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListClocks</name>
@@ -1006,7 +1183,7 @@ removerá estos datos.  ¿Remezclar?</translation>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>Realmente desea 
+        <translation type="obsolete">Realmente desea 
 eliminar</translation>
     </message>
     <message>
@@ -1015,7 +1192,7 @@ eliminar</translation>
     </message>
     <message>
         <source>is in use in the following grid(s):</source>
-        <translation>está en uso en las siguiente(s) parrilla(s):</translation>
+        <translation type="obsolete">está en uso en las siguiente(s) parrilla(s):</translation>
     </message>
     <message>
         <source>Do you still want to delete it?</source>
@@ -1035,7 +1212,19 @@ eliminar</translation>
     </message>
     <message>
         <source>Log Clocks - User: </source>
-        <translation>Tortas - Usuario: </translation>
+        <translation type="obsolete">Tortas - Usuario: </translation>
+    </message>
+    <message>
+        <source>Log Clocks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use in the following grid(s)</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1095,7 +1284,7 @@ eliminar</translation>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>Realmente desea
+        <translation type="obsolete">Realmente desea
 eliminar</translation>
     </message>
     <message>
@@ -1104,7 +1293,7 @@ eliminar</translation>
     </message>
     <message>
         <source>is in use in the following clocks:</source>
-        <translation>está en uso en las siguientes tortas:</translation>
+        <translation type="obsolete">está en uso en las siguientes tortas:</translation>
     </message>
     <message>
         <source>Do you still want to delete it?</source>
@@ -1124,7 +1313,19 @@ eliminar</translation>
     </message>
     <message>
         <source>Log Events - User: </source>
-        <translation>Eventos - Usuario: </translation>
+        <translation type="obsolete">Eventos - Usuario: </translation>
+    </message>
+    <message>
+        <source>Log Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use in the following clocks</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1158,11 +1359,11 @@ eliminar</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SERVICIO</translation>
+        <translation type="obsolete">SERVICIO</translation>
     </message>
     <message>
         <source>OLDEST REPORT</source>
-        <translation>REPORTE MAS ANTIGUO</translation>
+        <translation type="obsolete">REPORTE MAS ANTIGUO</translation>
     </message>
     <message>
         <source>C&amp;lose</source>
@@ -1183,12 +1384,20 @@ Reports</source>
         <translation>&amp;Generar 
 Reportes</translation>
     </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Oldest Report</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWidget</name>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>No puedo conectarme</translation>
+        <translation type="obsolete">No puedo conectarme</translation>
     </message>
     <message>
         <source>RDLogManager</source>
@@ -1224,18 +1433,22 @@ Reportes</translation>
     </message>
     <message>
         <source>RDLogManager - User: </source>
-        <translation>RDLogManager - Usuario: </translation>
+        <translation type="obsolete">RDLogManager - Usuario: </translation>
     </message>
     <message>
         <source>RDLogEdit -- Database Skew</source>
-        <translation>RDLOgEdit -- Asimetría en la base de datos</translation>
+        <translation type="obsolete">RDLOgEdit -- Asimetría en la base de datos</translation>
     </message>
     <message>
         <source>This version of RDLogManager is incompatible with the version installed on the server.
 See your system administrator for an update!</source>
-        <translation>Esta versión de RDLogManager no es compatible con la versión instalada en el servidor.
+        <translation type="obsolete">Esta versión de RDLogManager no es compatible con la versión instalada en el servidor.
 ¡Solicite al administrador del sistema una actualización!</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PickReportDates</name>
@@ -1287,14 +1500,26 @@ Reporte</translation>
     </message>
     <message>
         <source>Report Complete</source>
-        <translation>Reporte completado</translation>
+        <translation type="obsolete">Reporte completado</translation>
     </message>
     <message>
         <source>Report complete!</source>
         <translation type="obsolete">¡Reporte completado!</translation>
     </message>
     <message>
-        <source>Report generated in</source>
+        <source>File Exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open report file at</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The report file already exists.  Overwrite?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1381,35 +1606,35 @@ Datos</translation>
     <name>editSchedCodeRules</name>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;Aceptar</translation>
+        <translation type="obsolete">&amp;Aceptar</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
     <message>
         <source>Code:</source>
-        <translation>Código:</translation>
+        <translation type="obsolete">Código:</translation>
     </message>
     <message>
         <source>Max. in a row:</source>
-        <translation>Máx. por fila:</translation>
+        <translation type="obsolete">Máx. por fila:</translation>
     </message>
     <message>
         <source>Min. wait:</source>
-        <translation>Espera Mín.:</translation>
+        <translation type="obsolete">Espera Mín.:</translation>
     </message>
     <message>
         <source>Do not schedule after:</source>
-        <translation>No programar después de:</translation>
+        <translation type="obsolete">No programar después de:</translation>
     </message>
     <message>
         <source>Or after:</source>
-        <translation>O después de:</translation>
+        <translation type="obsolete">O después de:</translation>
     </message>
     <message>
         <source>Edit Rules for Code</source>
-        <translation>Editar reglas para el código</translation>
+        <translation type="obsolete">Editar reglas para el código</translation>
     </message>
 </context>
 </TS>
