@@ -1,10 +1,8 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AddClock</name>
-    <message>
-        <source>Add Log Clock</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;New Clock Name:</source>
         <translation type="unfinished"></translation>
@@ -17,6 +15,10 @@
         <source>&amp;Cancel</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Add Clock</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AddEvent</name>
@@ -46,10 +48,6 @@
 </context>
 <context>
     <name>EditClock</name>
-    <message>
-        <source>Edit Clock:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Code:</source>
         <translation type="unfinished"></translation>
@@ -153,10 +151,6 @@ Do you want to save?</source>
         <source>Clock already exists!  Overwrite?</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>--- End of clock ---</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Invalid Code</source>
         <translation type="unfinished"></translation>
@@ -186,6 +180,22 @@ Do you want to save?</source>
 </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Clock</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>That event does not exist.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -213,38 +223,6 @@ Do you want to save?</source>
         <source>Macros Only</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>CART</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>GROUP</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>LENGTH</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>TITLE</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>ARTIST</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>START</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>END</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>TYPE</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>ALL</source>
         <translation type="unfinished"></translation>
@@ -325,14 +303,6 @@ Do you want to save?</source>
         <source>Use Timescaling</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>TRANSITION</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>COUNT</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>None</source>
         <translation type="unfinished"></translation>
@@ -467,10 +437,6 @@ Do you want to overwrite it?</source>
         <source>, Timed(MakeNext)</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Timed(Wait</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>, Post</source>
         <translation type="unfinished"></translation>
@@ -519,6 +485,58 @@ Do you want to overwrite it?</source>
         <source>and code</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Timed(Wait)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist Separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEventLine</name>
@@ -574,10 +592,6 @@ already existing event.</source>
 </context>
 <context>
     <name>EditGrid</name>
-    <message>
-        <source>Edit Grid:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Edit Clock</source>
         <translation type="unfinished"></translation>
@@ -607,6 +621,10 @@ already existing event.</source>
         <source>This operation cannot be undone!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Grid</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditNote</name>
@@ -646,6 +664,41 @@ already existing event.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>EditSchedCodeRules</name>
+    <message>
+        <source>Edit Rules for Code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Code:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Max. in a row:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Min. wait:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not schedule after:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Or after:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>EditSchedRules</name>
     <message>
@@ -713,6 +766,10 @@ Do you want to save?</source>
         <source>Import Rules from Clock</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>(This setting is deprecated and has been moved to events)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditTrack</name>
@@ -783,13 +840,6 @@ Do you want to save?</source>
         <source>The log for</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>already exists.  Recreating it
-will remove any merged Music or Traffic events.
-
-Recreate?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Log Exists</source>
         <translation type="unfinished"></translation>
@@ -798,45 +848,18 @@ Recreate?</source>
         <source>This will also delete the</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>voice tracks associated with this log.
-Continue?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Tracks Exist</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>No Errors</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>No exceptions found.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>already contains merged music and/or traffic data.
-Remerging it will remove this data.  Remerge?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Music Exists</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>already contains merged traffic data.  Remerging it
-will remove this data.  Remerge?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Traffic Exists</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Generate Log - User: </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Error</source>
         <translation type="unfinished"></translation>
@@ -861,6 +884,54 @@ will remove this data.  Remerge?</source>
         <source>Unable to link traffic log</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Generate Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already exists.  Recreating it</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>will remove any merged Music or Traffic events.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recreate?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with this log.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already contains merged music and/or traffic data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remerging it will remove this data.  Remerge?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already contains merged traffic data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No Errors</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cannot be relinked.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No broken rules or validation exceptions found.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImportListView</name>
@@ -880,18 +951,6 @@ will remove this data.  Remerge?</source>
         <source>Edit Voice Track</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Set PLAY Transition</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Set SEGUE Transition</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Set STOP Transition</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Delete</source>
         <translation type="unfinished"></translation>
@@ -924,6 +983,18 @@ will remove this data.  Remerge?</source>
         <source>STOP</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>PLAY Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SEGUE Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>STOP Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListClocks</name>
@@ -991,19 +1062,10 @@ will remove this data.  Remerge?</source>
         <source>An clock with that name already exists!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Are you sure you want to
-delete</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Delete Clock</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>is in use in the following grid(s):</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Do you still want to delete it?</source>
         <translation type="unfinished"></translation>
@@ -1013,7 +1075,15 @@ delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Log Clocks - User: </source>
+        <source>Log Clocks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use in the following grid(s)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1079,19 +1149,10 @@ delete</source>
         <source>An event with that name already exists!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Are you sure you want to
-delete</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Delete Event</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>is in use in the following clocks:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Do you still want to delete it?</source>
         <translation type="unfinished"></translation>
@@ -1101,7 +1162,15 @@ delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Log Events - User: </source>
+        <source>Log Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use in the following clocks</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1134,14 +1203,6 @@ delete</source>
         <source>Rivendell Services</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>SERVICE</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>OLDEST REPORT</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Generate
 Reports</source>
@@ -1160,13 +1221,17 @@ Data</source>
         <source>[none]</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Oldest Report</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWidget</name>
-    <message>
-        <source>Can&apos;t Connect</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>RDLogManager</source>
         <translation type="unfinished"></translation>
@@ -1200,16 +1265,7 @@ Data</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>RDLogManager - User: </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>RDLogEdit -- Database Skew</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>This version of RDLogManager is incompatible with the version installed on the server.
-See your system administrator for an update!</source>
+        <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1261,11 +1317,19 @@ Report</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Report Complete</source>
+        <source>File Exists</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Report generated in</source>
+        <source>File Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open report file at</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The report file already exists.  Overwrite?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1347,39 +1411,4 @@ Data</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>editSchedCodeRules</name>
-    <message>
-        <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Code:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Max. in a row:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Min. wait:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Do not schedule after:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Or after:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Edit Rules for Code</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 </TS>
