@@ -1,9 +1,11 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AddClock</name>
     <message>
         <source>Add Log Clock</source>
-        <translation>Legg til loggklokke</translation>
+        <translation type="obsolete">Legg til loggklokke</translation>
     </message>
     <message>
         <source>&amp;New Clock Name:</source>
@@ -17,6 +19,10 @@
         <source>&amp;Cancel</source>
         <translation>&amp;Avbryt</translation>
     </message>
+    <message>
+        <source>Add Clock</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AddEvent</name>
@@ -48,7 +54,7 @@
     <name>EditClock</name>
     <message>
         <source>Edit Clock:</source>
-        <translation>Rediger klokke:</translation>
+        <translation type="obsolete">Rediger klokke:</translation>
     </message>
     <message>
         <source>Code:</source>
@@ -121,7 +127,7 @@ tene&amp;ster</translation>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>Er du sikker på at du vil
+        <translation type="obsolete">Er du sikker på at du vil
 sletta</translation>
     </message>
     <message>
@@ -164,7 +170,7 @@ Vil du lagra?</translation>
     </message>
     <message>
         <source>--- End of clock ---</source>
-        <translation>--- Slutt på klokka ---</translation>
+        <translation type="obsolete">--- Slutt på klokka ---</translation>
     </message>
     <message>
         <source>Invalid Code</source>
@@ -190,6 +196,27 @@ Vil du lagra?</translation>
         <source>&amp;Clone</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Are you sure you want to delete
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit Clock</source>
+        <translation type="unfinished">Rediger klokke</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>That event does not exist.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -219,35 +246,35 @@ Vil du lagra?</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>KORG</translation>
+        <translation type="obsolete">KORG</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>LENGD</translation>
+        <translation type="obsolete">LENGD</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITTEL</translation>
+        <translation type="obsolete">TITTEL</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTIST</translation>
+        <translation type="obsolete">ARTIST</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>START</translation>
+        <translation type="obsolete">START</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>SLUTT</translation>
+        <translation type="obsolete">SLUTT</translation>
     </message>
     <message>
         <source>TYPE</source>
-        <translation>TYPE</translation>
+        <translation type="obsolete">TYPE</translation>
     </message>
     <message>
         <source>ALL</source>
@@ -335,11 +362,11 @@ Vil du lagra?</translation>
     </message>
     <message>
         <source>TRANSITION</source>
-        <translation>OVERGANG</translation>
+        <translation type="obsolete">OVERGANG</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>TELLING</translation>
+        <translation type="obsolete">TELLING</translation>
     </message>
     <message>
         <source>None</source>
@@ -483,7 +510,7 @@ Vil du byta henne ut?</translation>
     </message>
     <message>
         <source>Timed(Wait</source>
-        <translation>Tidlagt (Vent</translation>
+        <translation type="obsolete">Tidlagt (Vent</translation>
     </message>
     <message>
         <source>, Post</source>
@@ -533,6 +560,58 @@ Vil du byta henne ut?</translation>
         <source>and code</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Timed(Wait)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished">Lengd</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished">Start</translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Slutt</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished">Tellign</translation>
+    </message>
+    <message>
+        <source>Artist Separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEventLine</name>
@@ -591,7 +670,7 @@ ei anna hending som finst frå før.</translation>
     <name>EditGrid</name>
     <message>
         <source>Edit Grid:</source>
-        <translation>Rediger gitter:</translation>
+        <translation type="obsolete">Rediger gitter:</translation>
     </message>
     <message>
         <source>Edit Clock</source>
@@ -622,6 +701,10 @@ ei anna hending som finst frå før.</translation>
         <source>This operation cannot be undone!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Grid</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditNote</name>
@@ -661,6 +744,41 @@ ei anna hending som finst frå før.</translation>
         <translation>&amp;Avbryt</translation>
     </message>
 </context>
+<context>
+    <name>EditSchedCodeRules</name>
+    <message>
+        <source>Edit Rules for Code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished">&amp;OK</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">&amp;Avbryt</translation>
+    </message>
+    <message>
+        <source>Code:</source>
+        <translation type="unfinished">Kode:</translation>
+    </message>
+    <message>
+        <source>Max. in a row:</source>
+        <translation type="unfinished">Maks på ei rad:</translation>
+    </message>
+    <message>
+        <source>Min. wait:</source>
+        <translation type="unfinished">Min. venting:</translation>
+    </message>
+    <message>
+        <source>Do not schedule after:</source>
+        <translation type="unfinished">Ikkje planlegg etter:</translation>
+    </message>
+    <message>
+        <source>Or after:</source>
+        <translation type="unfinished">Eller etter:</translation>
+    </message>
+</context>
 <context>
     <name>EditSchedRules</name>
     <message>
@@ -729,6 +847,14 @@ Vil du lagra?</translation>
         <source>Import Rules from Clock</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>None</source>
+        <translation type="obsolete">Ingen</translation>
+    </message>
+    <message>
+        <source>(This setting is deprecated and has been moved to events)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditTrack</name>
@@ -749,7 +875,7 @@ Vil du lagra?</translation>
     <name>GenerateLog</name>
     <message>
         <source>Generate Log</source>
-        <translation type="obsolete">Lag logg</translation>
+        <translation type="unfinished">Lag logg</translation>
     </message>
     <message>
         <source>Generating Log...</source>
@@ -808,7 +934,7 @@ Vil du lagra?</translation>
 will remove any merged Music or Traffic events.
 
 Recreate?</source>
-        <translation>finst alt. Om du lagar han på nytt,
+        <translation type="obsolete">finst alt. Om du lagar han på nytt,
 vil det fjerna alle innfletta Musikk- eller Trafikk-hendingar.
 
 Lag på nytt?</translation>
@@ -824,7 +950,7 @@ Lag på nytt?</translation>
     <message>
         <source>voice tracks associated with this log.
 Continue?</source>
-        <translation>røystspor som er kopla til denne loggen.
+        <translation type="obsolete">røystspor som er kopla til denne loggen.
 Hald fram?</translation>
     </message>
     <message>
@@ -833,16 +959,16 @@ Hald fram?</translation>
     </message>
     <message>
         <source>No Errors</source>
-        <translation>Ingen feil</translation>
+        <translation type="unfinished">Ingen feil</translation>
     </message>
     <message>
         <source>No exceptions found.</source>
-        <translation>Fann ingen unntak.</translation>
+        <translation type="obsolete">Fann ingen unntak.</translation>
     </message>
     <message>
         <source>already contains merged music and/or traffic data.
 Remerging it will remove this data.  Remerge?</source>
-        <translation>inneheld alt fletta musikk- og/eller trafikkdata.
+        <translation type="obsolete">inneheld alt fletta musikk- og/eller trafikkdata.
 Flettar du på nytt, vil du fjerna desse dataa. Flett på nytt?</translation>
     </message>
     <message>
@@ -852,7 +978,7 @@ Flettar du på nytt, vil du fjerna desse dataa. Flett på nytt?</translation>
     <message>
         <source>already contains merged traffic data.  Remerging it
 will remove this data.  Remerge?</source>
-        <translation>inneheld alt fletta trafikkdata.
+        <translation type="obsolete">inneheld alt fletta trafikkdata.
 Flettar du på nytt, vil du fjerna desse dataa. Flett på nytt?</translation>
     </message>
     <message>
@@ -860,7 +986,67 @@ Flettar du på nytt, vil du fjerna desse dataa. Flett på nytt?</translation>
         <translation>Trafikken eksisterer</translation>
     </message>
     <message>
-        <source>Generate Log - User: </source>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to generate log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to clear traffic links</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to clear music links</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to link music log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to link traffic log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already exists.  Recreating it</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>will remove any merged Music or Traffic events.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recreate?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with this log.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already contains merged music and/or traffic data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remerging it will remove this data.  Remerge?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already contains merged traffic data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cannot be relinked.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No broken rules or validation exceptions found.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -884,15 +1070,15 @@ Flettar du på nytt, vil du fjerna desse dataa. Flett på nytt?</translation>
     </message>
     <message>
         <source>Set PLAY Transition</source>
-        <translation>Set SPEL-overgang</translation>
+        <translation type="obsolete">Set SPEL-overgang</translation>
     </message>
     <message>
         <source>Set SEGUE Transition</source>
-        <translation>Set KRYSSTONING-overgang</translation>
+        <translation type="obsolete">Set KRYSSTONING-overgang</translation>
     </message>
     <message>
         <source>Set STOP Transition</source>
-        <translation>Set STOPP-overgang</translation>
+        <translation type="obsolete">Set STOPP-overgang</translation>
     </message>
     <message>
         <source>Set OVERLAP Transition</source>
@@ -934,12 +1120,24 @@ Flettar du på nytt, vil du fjerna desse dataa. Flett på nytt?</translation>
         <source>OVERLAP</source>
         <translation type="obsolete">OVERLAPP</translation>
     </message>
+    <message>
+        <source>PLAY Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SEGUE Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>STOP Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListClocks</name>
     <message>
         <source>Log Clocks</source>
-        <translation type="obsolete">Loggklokker</translation>
+        <translation type="unfinished">Loggklokker</translation>
     </message>
     <message>
         <source>Filter:</source>
@@ -1008,7 +1206,7 @@ Flettar du på nytt, vil du fjerna desse dataa. Flett på nytt?</translation>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>Er du sikker på at du vil 
+        <translation type="obsolete">Er du sikker på at du vil 
 sletta</translation>
     </message>
     <message>
@@ -1017,7 +1215,7 @@ sletta</translation>
     </message>
     <message>
         <source>is in use in the following grid(s):</source>
-        <translation>er i bruk av desse gitra:</translation>
+        <translation type="obsolete">er i bruk av desse gitra:</translation>
     </message>
     <message>
         <source>Do you still want to delete it?</source>
@@ -1028,7 +1226,11 @@ sletta</translation>
         <translation>Klokka er i bruk</translation>
     </message>
     <message>
-        <source>Log Clocks - User: </source>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use in the following grid(s)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1036,7 +1238,7 @@ sletta</translation>
     <name>ListEvents</name>
     <message>
         <source>Log Events</source>
-        <translation type="obsolete">Logghendingar</translation>
+        <translation type="unfinished">Logghendingar</translation>
     </message>
     <message>
         <source>Filter:</source>
@@ -1101,7 +1303,7 @@ sletta</translation>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>Er du sikker på at du vil
+        <translation type="obsolete">Er du sikker på at du vil
 sletta</translation>
     </message>
     <message>
@@ -1110,7 +1312,7 @@ sletta</translation>
     </message>
     <message>
         <source>is in use in the following clocks:</source>
-        <translation>er i bruk av desse klokkene:</translation>
+        <translation type="obsolete">er i bruk av desse klokkene:</translation>
     </message>
     <message>
         <source>Do you still want to delete it?</source>
@@ -1121,7 +1323,11 @@ sletta</translation>
         <translation>Hendinga er i bruk</translation>
     </message>
     <message>
-        <source>Log Events - User: </source>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use in the following clocks</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1156,11 +1362,11 @@ sletta</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>TENEST</translation>
+        <translation type="obsolete">TENEST</translation>
     </message>
     <message>
         <source>OLDEST REPORT</source>
-        <translation>ELDSTE RAPPORT</translation>
+        <translation type="obsolete">ELDSTE RAPPORT</translation>
     </message>
     <message>
         <source>&amp;Generate
@@ -1182,12 +1388,20 @@ data</translation>
         <source>[none]</source>
         <translation>[ingen]</translation>
     </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Oldest Report</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWidget</name>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>Greier ikkje kopla til</translation>
+        <translation type="obsolete">Greier ikkje kopla til</translation>
     </message>
     <message>
         <source>RDLogManager</source>
@@ -1222,16 +1436,7 @@ data</translation>
         <translation>&amp;Lukk</translation>
     </message>
     <message>
-        <source>RDLogManager - User: </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>RDLogEdit -- Database Skew</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>This version of RDLogManager is incompatible with the version installed on the server.
-See your system administrator for an update!</source>
+        <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1285,14 +1490,26 @@ rapport</translation>
     </message>
     <message>
         <source>Report Complete</source>
-        <translation>Rapporten ferdig</translation>
+        <translation type="obsolete">Rapporten ferdig</translation>
     </message>
     <message>
         <source>Report complete!</source>
         <translation type="obsolete">Rapporten er ferdig!</translation>
     </message>
     <message>
-        <source>Report generated in</source>
+        <source>File Exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open report file at</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The report file already exists.  Overwrite?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1379,35 +1596,31 @@ data</translation>
     <name>editSchedCodeRules</name>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Avbryt</translation>
+        <translation type="obsolete">&amp;Avbryt</translation>
     </message>
     <message>
         <source>Code:</source>
-        <translation>Kode:</translation>
+        <translation type="obsolete">Kode:</translation>
     </message>
     <message>
         <source>Max. in a row:</source>
-        <translation>Maks på ei rad:</translation>
+        <translation type="obsolete">Maks på ei rad:</translation>
     </message>
     <message>
         <source>Min. wait:</source>
-        <translation>Min. venting:</translation>
+        <translation type="obsolete">Min. venting:</translation>
     </message>
     <message>
         <source>Do not schedule after:</source>
-        <translation>Ikkje planlegg etter:</translation>
+        <translation type="obsolete">Ikkje planlegg etter:</translation>
     </message>
     <message>
         <source>Or after:</source>
-        <translation>Eller etter:</translation>
-    </message>
-    <message>
-        <source>Edit Rules for Code</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Eller etter:</translation>
     </message>
 </context>
 </TS>
