@@ -2,9 +2,7 @@
 //
 // A Dedicated Cart Wall Utility for Rivendell.
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdpanel.h,v 1.16.4.1 2013/12/30 21:11:59 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,22 +18,13 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-
 #ifndef RDPANEL_H
 #define RDPANEL_H
 
-#include <qwidget.h>
-#include <qsqldatabase.h>
-#include <qtimer.h>
-#include <qpixmap.h>
-
-#include <rdstereometer.h>
-#include <rdcae.h>
-#include <rdmacro.h>
-#include <rdconfig.h>
-#include <rdsound_panel.h>
-#include <rdevent_player.h>
 #include <rdemptycart.h>
+#include <rdsound_panel.h>
+#include <rdstereometer.h>
+#include <rdwidget.h>
 
 //
 // Settings
@@ -46,15 +35,16 @@
 #define RDPANEL_PANEL_BUTTON_COLUMNS 9
 #define RDPANEL_USAGE "\n"
 
-class MainWidget : public QWidget
+class MainWidget : public RDWidget
 {
   Q_OBJECT
  public:
-  MainWidget(QWidget *parent=0,const char *name=0);
+  MainWidget(RDConfig *c,QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
  private slots:
+  void caeConnectedData(bool state);
   void userData();
   void masterTimerData();
   void meterData();
@@ -66,10 +56,8 @@ class MainWidget : public QWidget
  private:
   void RunLocalMacros(RDMacro *rml);
   void SetCaption();
-  RDConfig *panel_config;
   QSqlDatabase *panel_db;
   QTimer *panel_master_timer;
-  RDCae *panel_cae;
   RDStereoMeter *panel_stereo_meter;
   RDSoundPanel *panel_panel;
   RDEventPlayer *panel_player;
@@ -78,7 +66,6 @@ class MainWidget : public QWidget
   QString panel_filter;
   QString panel_group;
   QString panel_schedcode;
-  QPixmap *panel_skin_pixmap;
   RDEmptyCart *panel_empty_cart;
 };
 
