@@ -2,7 +2,7 @@
 //
 // Rivendell web service portal -- Cart services
 //
-//   (C) Copyright 2010-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2010-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,16 +24,17 @@
 #include <fcntl.h>
 #include <errno.h>
 
-#include <rdformpost.h>
-#include <rdlog_line.h>
-#include <rdweb.h>
-#include <rduser.h>
-#include <rdgroup.h>
+#include <rdapplication.h>
+#include <rdcart_search_text.h>
 #include <rdconf.h>
 #include <rdescape_string.h>
-#include <rdcart_search_text.h>
+#include <rdformpost.h>
+#include <rdgroup.h>
+#include <rdlog_line.h>
+#include <rduser.h>
+#include <rdweb.h>
 
-#include <rdxport.h>
+#include "rdxport.h"
 
 void Xport::AddCart()
 {
@@ -70,7 +71,7 @@ void Xport::AddCart()
   //
   // Verify User Perms
   //
-  if(!xport_user->groupAuthorized(group_name)) {
+  if(!rda->user()->groupAuthorized(group_name)) {
     XmlExit("No such group",404,"carts.cpp",LINE_NUMBER);
   }
   group=new RDGroup(group_name);
@@ -85,7 +86,7 @@ void Xport::AddCart()
     XmlExit("Cart number out of range for group",404,"carts.cpp",LINE_NUMBER);
   }
   delete group;
-  if(!xport_user->createCarts()) {
+  if(!rda->user()->createCarts()) {
     XmlExit("Forbidden",404,"carts.cpp",LINE_NUMBER);
   }
 
@@ -106,7 +107,9 @@ void Xport::AddCart()
   printf("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n");
   printf("<cartAdd>\n");
   if(cart->exists()) {
-    printf("%s",(const char *)cart->xml(false,true));
+    printf("%s",(const char *)cart->xml(false,true).utf8());
+    SendNotification(RDNotification::CartType,RDNotification::AddAction,
+		     QVariant(cart->number()));
   }
   delete cart;
   printf("</cartAdd>\n");
@@ -145,14 +148,12 @@ void Xport::ListCarts()
   // Generate Cart List
   //
   if(group_name.isEmpty()||(group_name==tr("ALL"))) {
-    where=RDAllCartSearchText(filter,"",xport_user->name(),false);
+    where=RDAllCartSearchText(filter,"",rda->user()->name(),false);
   }
   else {
-    sql=QString().
-      sprintf("select GROUP_NAME from USER_PERMS \
-               where (GROUP_NAME=\"%s\")&&(USER_NAME=\"%s\")",
-	      (const char *)RDEscapeString(group_name),
-	      (const char *)RDEscapeString(xport_user->name()));
+    sql=QString("select GROUP_NAME from USER_PERMS where ")+
+      "(GROUP_NAME=\""+RDEscapeString(group_name)+"\")&&"+
+      "(USER_NAME=\""+RDEscapeString(rda->user()->name())+"\")";
     q=new RDSqlQuery(sql);
     if(!q->first()) {
       delete q;
@@ -163,7 +164,7 @@ void Xport::ListCarts()
   if(cart_type!=RDCart::All) {
     where+=QString().sprintf("&&(TYPE=%u)",cart_type);
   }
-  sql=RDCart::xmlSql(include_cuts)+"where "+where+" order by CART.NUMBER";
+  sql=RDCart::xmlSql(include_cuts)+where+" order by CART.NUMBER";
   q=new RDSqlQuery(sql);
 
   //
@@ -173,7 +174,7 @@ void Xport::ListCarts()
   printf("Status: 200\n\n");
   printf("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n");
   printf("<cartList>\n");
-  printf("%s\n",(const char *)RDCart::xml(q,include_cuts,true)); 
+  printf("%s\n",(const char *)RDCart::xml(q,include_cuts,true).utf8()); 
   printf("</cartList>\n");
   delete q;
   Exit(0);
@@ -200,7 +201,7 @@ void Xport::ListCart()
   //
   // Verify User Perms
   //
-  if(!xport_user->cartAuthorized(cart_number)) {
+  if(!rda->user()->cartAuthorized(cart_number)) {
     XmlExit("No such cart",404,"carts.cpp",LINE_NUMBER);
   }
 
@@ -212,7 +213,7 @@ void Xport::ListCart()
   printf("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n");
   printf("<cartList>\n");
   cart=new RDCart(cart_number);
-  printf("%s",(const char *)cart->xml(include_cuts,true));
+  printf("%s",(const char *)cart->xml(include_cuts,true).utf8());
   delete cart;
   printf("</cartList>\n");
 
@@ -246,14 +247,14 @@ void Xport::EditCart()
   //
   // Verify User Perms
   //
-  if(!xport_user->cartAuthorized(cart_number)) {
+  if(!rda->user()->cartAuthorized(cart_number)) {
     XmlExit("No such cart",404,"carts.cpp",LINE_NUMBER);
   }
-  if(!xport_user->modifyCarts()) {
+  if(!rda->user()->modifyCarts()) {
     XmlExit("Unauthorized",404,"carts.cpp",LINE_NUMBER);
   }
   if(xport_post->getValue("GROUP_NAME",&group_name)) {
-    if(!xport_user->groupAuthorized(group_name)) {
+    if(!rda->user()->groupAuthorized(group_name)) {
       XmlExit("No such group",404,"carts.cpp",LINE_NUMBER);
     }
     group=new RDGroup(group_name);
@@ -314,8 +315,8 @@ void Xport::EditCart()
     cart->setGroupName(group_name);
   }
   if(xport_post->getValue("TITLE",&value)) {
-    if((!xport_system->allowDuplicateCartTitles())&&
-       (!xport_system->fixDuplicateCartTitles())&&
+    if((!rda->system()->allowDuplicateCartTitles())&&
+       (!rda->system()->fixDuplicateCartTitles())&&
        (!RDCart::titleIsUnique(cart_number,value))) {
       XmlExit("Duplicate Cart Title Not Allowed",404,"carts.cpp",LINE_NUMBER);
     }
@@ -333,6 +334,9 @@ void Xport::EditCart()
       cart->setYear(number);
     }
   }
+  if(xport_post->getValue("SONG_ID",&value)) {
+    cart->setSongId(value);
+  }
   if(xport_post->getValue("LABEL",&value)) {
     cart->setLabel(value);
   }
@@ -348,6 +352,9 @@ void Xport::EditCart()
   if(xport_post->getValue("COMPOSER",&value)) {
     cart->setComposer(value);
   }
+  if(xport_post->getValue("CONDUCTOR",&value)) {
+    cart->setConductor(value);
+  }
   if(xport_post->getValue("USER_DEFINED",&value)) {
     cart->setUserDefined(value);
   }
@@ -392,7 +399,9 @@ void Xport::EditCart()
   printf("Status: 200\n\n");
   printf("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n");
   printf("<cartList>\n");
-  printf("%s",(const char *)cart->xml(include_cuts,true));
+  printf("%s",(const char *)cart->xml(include_cuts,true).utf8());
+  SendNotification(RDNotification::CartType,RDNotification::ModifyAction,
+		   QVariant(cart->number()));
   delete cart;
   printf("</cartList>\n");
 
@@ -415,10 +424,10 @@ void Xport::RemoveCart()
   //
   // Verify User Perms
   //
-  if(!xport_user->cartAuthorized(cart_number)) {
+  if(!rda->user()->cartAuthorized(cart_number)) {
     XmlExit("No such cart",404,"carts.cpp",LINE_NUMBER);
   }
-  if(!xport_user->deleteCarts()) {
+  if(!rda->user()->deleteCarts()) {
     XmlExit("Unauthorized",404,"carts.cpp",LINE_NUMBER);
   }
 
@@ -430,10 +439,12 @@ void Xport::RemoveCart()
     delete cart;
     XmlExit("No such cart",404,"carts.cpp",LINE_NUMBER);
   }
-  if(!cart->remove(NULL,NULL,xport_config)) {
+  if(!cart->remove(NULL,NULL,rda->config())) {
     delete cart;
     XmlExit("Unable to delete cart",500,"carts.cpp",LINE_NUMBER);
   }
+  SendNotification(RDNotification::CartType,RDNotification::DeleteAction,
+		   QVariant(cart->number()));
   delete cart;
   XmlExit("OK",200,"carts.cpp",LINE_NUMBER);
 }
@@ -450,17 +461,17 @@ void Xport::AddCut()
   // Verify Post
   //
   if(!xport_post->getValue("CART_NUMBER",&cart_number)) {
-    XmlExit("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400,"carts.cpp",LINE_NUMBER);
   }
 
   //
   // Verify User Perms
   //
-  if(!xport_user->cartAuthorized(cart_number)) {
-    XmlExit("No such cart",404);
+  if(!rda->user()->cartAuthorized(cart_number)) {
+    XmlExit("No such cart",404,"carts.cpp",LINE_NUMBER);
   }
-  if(!xport_user->editAudio()) {
-    XmlExit("Forbidden",404);
+  if(!rda->user()->editAudio()) {
+    XmlExit("Forbidden",404,"carts.cpp",LINE_NUMBER);
   }
 
   //
@@ -469,11 +480,11 @@ void Xport::AddCut()
   cart=new RDCart(cart_number);
   if(!cart->exists()) {
     delete cart;
-    XmlExit("No such cart",404);
+    XmlExit("No such cart",404,"carts.cpp",LINE_NUMBER);
   }
   if((cut_number=cart->addCut(0,0,2))<0) {
     delete cart;
-    XmlExit("No new cuts available",500);
+    XmlExit("No new cuts available",500,"carts.cpp",LINE_NUMBER);
   }
   printf("Content-type: application/xml\n");
   printf("Status: 200\n\n");
@@ -481,7 +492,10 @@ void Xport::AddCut()
   printf("<cutAdd>\n");
   cut=new RDCut(cart_number,cut_number);
   if(cut->exists()) {
-    printf("%s",(const char *)RDCart::cutXml(cart_number,cut_number,true));
+    printf("%s",
+	   (const char *)RDCart::cutXml(cart_number,cut_number,true).utf8());
+    SendNotification(RDNotification::CartType,RDNotification::ModifyAction,
+		     QVariant(cart->number()));
   }
   delete cut;
   delete cart;
@@ -501,14 +515,14 @@ void Xport::ListCuts()
   // Verify Post
   //
   if(!xport_post->getValue("CART_NUMBER",&cart_number)) {
-    XmlExit("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400,"carts.cpp",LINE_NUMBER);
   }
 
   //
   // Verify User Perms
   //
-  if(!xport_user->cartAuthorized(cart_number)) {
-    XmlExit("No such cart",404);
+  if(!rda->user()->cartAuthorized(cart_number)) {
+    XmlExit("No such cart",404,"carts.cpp",LINE_NUMBER);
   }
 
   //
@@ -522,7 +536,7 @@ void Xport::ListCuts()
   printf("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n");
   printf("<cutList>\n");
   while(q->next()) {
-    printf("%s\n",(const char *)RDCut::xml(q,false));
+    printf("%s\n",(const char *)RDCut::xml(q,false).utf8());
   }
   printf("</cutList>\n");
   delete q;
@@ -541,17 +555,17 @@ void Xport::ListCut()
   // Verify Post
   //
   if(!xport_post->getValue("CART_NUMBER",&cart_number)) {
-    XmlExit("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400,"carts.cpp",LINE_NUMBER);
   }
   if(!xport_post->getValue("CUT_NUMBER",&cut_number)) {
-    XmlExit("Missing CUT_NUMBER",400);
+    XmlExit("Missing CUT_NUMBER",400,"carts.cpp",LINE_NUMBER);
   }
 
   //
   // Verify User Perms
   //
-  if(!xport_user->cartAuthorized(cart_number)) {
-    XmlExit("No such cart",404);
+  if(!rda->user()->cartAuthorized(cart_number)) {
+    XmlExit("No such cart",404,"carts.cpp",LINE_NUMBER);
   }
 
   //
@@ -560,13 +574,13 @@ void Xport::ListCut()
   cut=new RDCut(cart_number,cut_number);
   if(!cut->exists()) {
     delete cut;
-    XmlExit("No such cut",404);
+    XmlExit("No such cut",404,"carts.cpp",LINE_NUMBER);
   }
   printf("Content-type: application/xml\n");
   printf("Status: 200\n\n");
   printf("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n");
   printf("<cutList>\n");
-  printf("%s",(const char *)RDCart::cutXml(cart_number,cut_number,true));
+  printf("%s",(const char *)RDCart::cutXml(cart_number,cut_number,true).utf8());
   printf("</cutList>\n");
   delete cut;
 
@@ -613,20 +627,20 @@ void Xport::EditCut()
   // Verify Post
   //
   if(!xport_post->getValue("CART_NUMBER",&cart_number)) {
-    XmlExit("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400,"carts.cpp",LINE_NUMBER);
   }
   if(!xport_post->getValue("CUT_NUMBER",&cut_number)) {
-    XmlExit("Missing CUT_NUMBER",400);
+    XmlExit("Missing CUT_NUMBER",400,"carts.cpp",LINE_NUMBER);
   }
 
   //
   // Verify User Perms
   //
-  if(!xport_user->cartAuthorized(cart_number)) {
-    XmlExit("No such cart",404);
+  if(!rda->user()->cartAuthorized(cart_number)) {
+    XmlExit("No such cart",404,"carts.cpp",LINE_NUMBER);
   }
-  if(!xport_user->editAudio()) {
-    XmlExit("Forbidden",404);
+  if(!rda->user()->editAudio()) {
+    XmlExit("Forbidden",404,"carts.cpp",LINE_NUMBER);
   }
 
   //
@@ -635,42 +649,45 @@ void Xport::EditCut()
   if((use_start_datetime=xport_post->
       getValue("START_DATETIME",&start_datetime,&ok))) {
     if(!ok) {
-      XmlExit("invalid START_DATETIME",400);
+      XmlExit("invalid START_DATETIME",400,"carts.cpp",LINE_NUMBER);
     }
   }
   if((use_end_datetime=xport_post->
       getValue("END_DATETIME",&end_datetime,&ok))) {
     if(!ok) {
-      XmlExit("invalid END_DATETIME",400);
+      XmlExit("invalid END_DATETIME",400,"carts.cpp",LINE_NUMBER);
     }
   }
   if(use_start_datetime!=use_end_datetime) {
-    XmlExit("both DATETIME values must be set together",400);
+    XmlExit("both DATETIME values must be set together",400,"carts.cpp",
+	    LINE_NUMBER);
   }
   if(use_start_datetime&&(start_datetime>end_datetime)) {
-    XmlExit("START_DATETIME is later than END_DATETIME",400);
+    XmlExit("START_DATETIME is later than END_DATETIME",400,"carts.cpp",
+	    LINE_NUMBER);
   }
 
   if((use_start_daypart=xport_post->
       getValue("START_DAYPART",&start_daypart,&ok))) {
     if(!ok) {
-      XmlExit("invalid START_DAYPART",400);
+      XmlExit("invalid START_DAYPART",400,"carts.cpp",LINE_NUMBER);
     }
   }
   if((use_end_daypart=xport_post->
       getValue("END_DAYPART",&end_daypart,&ok))) {
     if(!ok) {
-      XmlExit("invalid END_DAYPART",400);
+      XmlExit("invalid END_DAYPART",400,"carts.cpp",LINE_NUMBER);
     }
   }
   if(use_start_daypart!=use_end_daypart) {
-    XmlExit("both DAYPART values must be set together",400);
+    XmlExit("both DAYPART values must be set together",400,"carts.cpp",
+	    LINE_NUMBER);
   }
 
   cut=new RDCut(cart_number,cut_number);
   if(!cut->exists()) {
     delete cut;
-    XmlExit("No such cut",404);
+    XmlExit("No such cut",404,"carts.cpp",LINE_NUMBER);
   }
 
   //
@@ -687,24 +704,27 @@ void Xport::EditCut()
   if((use_fadeup_point=xport_post->
       getValue("FADEUP_POINT",&fadeup_point,&ok))) {
     if(!ok) {
-      XmlExit("invalid FADEUP_POINT",400);
+      XmlExit("invalid FADEUP_POINT",400,"carts.cpp",LINE_NUMBER);
     }
     if(fadeup_point>end_points[1]) {
-      XmlExit("FADEUP_POINT exceeds length of cart",400);
+      XmlExit("FADEUP_POINT exceeds length of cart",400,"carts.cpp",
+	      LINE_NUMBER);
     }
   }
   if((use_fadedown_point=xport_post->
       getValue("FADEDOWN_POINT",&fadedown_point,&ok))) {
     if(!ok) {
-      XmlExit("invalid FADEDOWN_POINT",400);
+      XmlExit("invalid FADEDOWN_POINT",400,"carts.cpp",LINE_NUMBER);
     }
     if(fadeup_point>end_points[1]) {
-      XmlExit("FADEDOWN_POINT exceeds length of cart",400);
+      XmlExit("FADEDOWN_POINT exceeds length of cart",400,"carts.cpp",
+	      LINE_NUMBER);
     }
   }
   if(use_fadeup_point&&use_fadedown_point&&
      (fadeup_point>=0)&&(fadedown_point>=0)&&(fadeup_point>fadedown_point)) {
-    XmlExit("FADEUP_POINT is greater than FADEDOWN_POINT",400);
+    XmlExit("FADEUP_POINT is greater than FADEDOWN_POINT",400,"carts.cpp",
+	    LINE_NUMBER);
   }
 
   //
@@ -712,7 +732,7 @@ void Xport::EditCut()
   //
   if((use_weight=xport_post->getValue("WEIGHT",&weight,&ok))) {
     if((!ok)||(weight<0)) {
-      XmlExit("invalid WEIGHT",400);
+      XmlExit("invalid WEIGHT",400,"carts.cpp",LINE_NUMBER);
     }
   }
 
@@ -840,8 +860,10 @@ void Xport::EditCut()
   printf("Status: 200\n\n");
   printf("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n");
   printf("<cutList>\n");
-  printf("%s",(const char *)RDCart::cutXml(cart_number,cut_number,true));
+  printf("%s",(const char *)RDCart::cutXml(cart_number,cut_number,true).utf8());
   printf("</cutList>\n");
+  SendNotification(RDNotification::CartType,RDNotification::ModifyAction,
+		   QVariant(cut->cartNumber()));
   delete cut;
 
   Exit(0);
@@ -860,31 +882,35 @@ void Xport::CheckPointerValidity(int ptr_values[2],bool use_ptrs[2],
     return;
   }
   if(!start_ok) {
-    XmlExit("invalid "+type+"START_POINT",400);
+    XmlExit("invalid "+type+"START_POINT",400,"carts.cpp",LINE_NUMBER);
   }
   if(!end_ok) {
-    XmlExit("invalid "+type+"END_POINT",400);
+    XmlExit("invalid "+type+"END_POINT",400,"carts.cpp",LINE_NUMBER);
   }
   if(use_ptrs[0]!=use_ptrs[1]) {
-    XmlExit("both "+type+"*_POINT values must be set together",400);
+    XmlExit("both "+type+"*_POINT values must be set together",400,"carts.cpp",
+	    LINE_NUMBER);
   }
   if(use_ptrs[0]) {
     if(((ptr_values[0]<0)&&(ptr_values[1]>=0))||
        ((ptr_values[0]>=0)&&(ptr_values[1]<0))) {
-      XmlExit("inconsistent "+type+"*_POINT values",400);
+      XmlExit("inconsistent "+type+"*_POINT values",400,"carts.cpp",
+	      LINE_NUMBER);
     }
   }
   if(ptr_values[0]>=0) {
     if(ptr_values[0]>ptr_values[1]) {
-      XmlExit(type+"START_POINT greater than "+type+"END_POINT",400);
+      XmlExit(type+"START_POINT greater than "+type+"END_POINT",400,
+	      "carts.cpp",LINE_NUMBER);
     }
     if((max_value>0)&&((unsigned)ptr_values[1]>max_value)) {
-      XmlExit(type+"END_POINT exceeds length of cut",400);
+      XmlExit(type+"END_POINT exceeds length of cut",400,"carts.cpp",
+	      LINE_NUMBER);
     }
   }
   else {
     if(max_value==0) {
-      XmlExit("End markers cannot be removed",400);
+      XmlExit("End markers cannot be removed",400,"carts.cpp",LINE_NUMBER);
     }
     else {
       ptr_values[0]=-1;
@@ -904,20 +930,20 @@ void Xport::RemoveCut()
   // Verify Post
   //
   if(!xport_post->getValue("CART_NUMBER",&cart_number)) {
-    XmlExit("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400,"carts.cpp",LINE_NUMBER);
   }
   if(!xport_post->getValue("CUT_NUMBER",&cut_number)) {
-    XmlExit("Missing CUT_NUMBER",400);
+    XmlExit("Missing CUT_NUMBER",400,"carts.cpp",LINE_NUMBER);
   }
 
   //
   // Verify User Perms
   //
-  if(!xport_user->cartAuthorized(cart_number)) {
-    XmlExit("No such cart",404);
+  if(!rda->user()->cartAuthorized(cart_number)) {
+    XmlExit("No such cart",404,"carts.cpp",LINE_NUMBER);
   }
-  if(!xport_user->editAudio()) {
-    XmlExit("Forbidden",404);
+  if(!rda->user()->editAudio()) {
+    XmlExit("Forbidden",404,"carts.cpp",LINE_NUMBER);
   }
 
   //
@@ -926,13 +952,15 @@ void Xport::RemoveCut()
   cart=new RDCart(cart_number);
   if(!cart->exists()) {
     delete cart;
-    XmlExit("No such cart",404);
+    XmlExit("No such cart",404,"carts.cpp",LINE_NUMBER);
   }
   if(!cart->removeCut(NULL,NULL,RDCut::cutName(cart_number,cut_number),
-		      xport_config)) {
+		      rda->config())) {
     delete cart;
-    XmlExit("No such cut",404);
+    XmlExit("No such cut",404,"carts.cpp",LINE_NUMBER);
   }
+  SendNotification(RDNotification::CartType,RDNotification::ModifyAction,
+		   QVariant(cart->number()));
   delete cart;
   XmlExit("OK",200);
 }
